# dima-sdk
Deel REST API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.25.0
- Package version: 1.0.3
- Generator version: 7.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import dima_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import dima_sdk
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import dima_sdk
from dima_sdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.letsdeel.com/rest/v2
# See configuration.py for a list of all supported configuration parameters.
configuration = dima_sdk.Configuration(
    host = "https://api.letsdeel.com/rest/v2"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): deelToken
configuration = dima_sdk.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with dima_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = dima_sdk.AccountingApi(api_client)
    id = 'abcd1234efgh5678' # str | The invoice ID used to identify the invoice to be downloaded.

    try:
        # Download invoice PDF
        api_response = api_instance.get_billing_invoice_download_link(id)
        print("The response of AccountingApi->get_billing_invoice_download_link:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccountingApi->get_billing_invoice_download_link: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.letsdeel.com/rest/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountingApi* | [**get_billing_invoice_download_link**](docs/AccountingApi.md#get_billing_invoice_download_link) | **GET** /invoices/{id}/download | Download invoice PDF
*AccountingApi* | [**get_invoice_list**](docs/AccountingApi.md#get_invoice_list) | **GET** /invoices | Retrieve invoices
*AccountingApi* | [**get_payment_list**](docs/AccountingApi.md#get_payment_list) | **GET** /payments | Retrieve payment receipts
*AccountingApi* | [**get_payments_break_down_by_id**](docs/AccountingApi.md#get_payments_break_down_by_id) | **GET** /payments/{payment_id}/breakdown | Retrieve a payment breakdown
*AccountingApi* | [**retrieve_deel_invoices**](docs/AccountingApi.md#retrieve_deel_invoices) | **GET** /invoices/deel | Retrieve Deel invoices
*AdjustmentsApi* | [**create_adjustment**](docs/AdjustmentsApi.md#create_adjustment) | **POST** /adjustments | Create a new adjustment
*AdjustmentsApi* | [**delete_adjustment**](docs/AdjustmentsApi.md#delete_adjustment) | **DELETE** /adjustments/{id} | Delete an adjustment
*AdjustmentsApi* | [**get_adjustments**](docs/AdjustmentsApi.md#get_adjustments) | **GET** /contracts/{contract_id}/adjustments | Retrieve adjustments
*AdjustmentsApi* | [**get_adjustments_by_id**](docs/AdjustmentsApi.md#get_adjustments_by_id) | **GET** /adjustments/{id} | Retrieve an adjustment
*AdjustmentsApi* | [**get_categories**](docs/AdjustmentsApi.md#get_categories) | **GET** /adjustments/categories | Retrieve categories
*AdjustmentsApi* | [**update_adjustment**](docs/AdjustmentsApi.md#update_adjustment) | **PATCH** /adjustments/{id} | Update an adjustment
*BackgroundChecksApi* | [**create_background_check_for_contracts**](docs/BackgroundChecksApi.md#create_background_check_for_contracts) | **POST** /background-checks/regular | Create background check
*BackgroundChecksApi* | [**get_background_checks_by_contract_id**](docs/BackgroundChecksApi.md#get_background_checks_by_contract_id) | **GET** /background-checks/{contract_id} | List background checks by contract
*BackgroundChecksApi* | [**get_background_checks_options**](docs/BackgroundChecksApi.md#get_background_checks_options) | **GET** /background-checks/options | List of background check options
*CandidatesApi* | [**add_candidate**](docs/CandidatesApi.md#add_candidate) | **POST** /candidates | Add Candidate
*CandidatesApi* | [**patch_candidate**](docs/CandidatesApi.md#patch_candidate) | **PATCH** /candidates/{candidate_id} | Update Candidate
*CartaApi* | [**get_equity_stakeholders**](docs/CartaApi.md#get_equity_stakeholders) | **GET** /equity/stakeholders | Retrieve stakeholders
*ConsentApi* | [**create_consent_token**](docs/ConsentApi.md#create_consent_token) | **POST** /consent_token | Create a consent token
*ContractorsApi* | [**add_premium**](docs/ContractorsApi.md#add_premium) | **POST** /contracts/{contract_id}/premium | Upgrade to Premium
*ContractorsApi* | [**amend_contract_details**](docs/ContractorsApi.md#amend_contract_details) | **POST** /contracts/{contract_id}/amendments | Amend contract
*ContractorsApi* | [**create_contract**](docs/ContractorsApi.md#create_contract) | **POST** /contracts | Create a new contract
*ContractorsApi* | [**get_contract_preview**](docs/ContractorsApi.md#get_contract_preview) | **GET** /contracts/{contract_id}/preview | Preview a contract agreement
*ContractorsApi* | [**remove_premium_from_contract**](docs/ContractorsApi.md#remove_premium_from_contract) | **DELETE** /contracts/{contract_id}/premium | Downgrade from Premium
*ContractorsApi* | [**terminate_contract**](docs/ContractorsApi.md#terminate_contract) | **POST** /contracts/{contractId}/terminations | Terminate contract
*ContractsApi* | [**add_contract_document**](docs/ContractsApi.md#add_contract_document) | **POST** /contracts/{contract_id}/documents | Attach a file to contract
*ContractsApi* | [**approve_exercise_equity**](docs/ContractsApi.md#approve_exercise_equity) | **PATCH** /equity/exercise/{public_id} | Approve an equity exercise
*ContractsApi* | [**archive_contract**](docs/ContractsApi.md#archive_contract) | **PATCH** /contracts/{contract_id}/archive | Archive a contract
*ContractsApi* | [**edit_contract_document**](docs/ContractsApi.md#edit_contract_document) | **PUT** /contracts/{contract_id}/documents | Edit the file attached to contract document.
*ContractsApi* | [**external_id**](docs/ContractsApi.md#external_id) | **PATCH** /contracts/{contract_id} | External Id
*ContractsApi* | [**get_alternate_emails_by_contract_id**](docs/ContractsApi.md#get_alternate_emails_by_contract_id) | **GET** /contracts/{contract_id}/alternate_emails | Find contract emails by ID
*ContractsApi* | [**get_contract_by_id**](docs/ContractsApi.md#get_contract_by_id) | **GET** /contracts/{contract_id} | Retrieve a single contract
*ContractsApi* | [**get_contract_equity_withholding_amount**](docs/ContractsApi.md#get_contract_equity_withholding_amount) | **GET** /contracts/{contract_id}/equity_withholding_estimate | Get an estimate of withholding amount given an equity event.
*ContractsApi* | [**get_contract_list**](docs/ContractsApi.md#get_contract_list) | **GET** /contracts | List of contracts
*ContractsApi* | [**get_contract_payment_dates**](docs/ContractsApi.md#get_contract_payment_dates) | **GET** /contracts/{contract_id}/payment_cycles | Retrieve contractor payment dates
*ContractsApi* | [**get_contract_templates**](docs/ContractsApi.md#get_contract_templates) | **GET** /contract-templates | Retrieve contract templates
*ContractsApi* | [**get_download_worker_documents_by_id**](docs/ContractsApi.md#get_download_worker_documents_by_id) | **GET** /workers/{worker_id}/documents/{document_id}/download | Download worker document
*ContractsApi* | [**get_invite_link**](docs/ContractsApi.md#get_invite_link) | **GET** /contracts/{contract_id}/invite | Get worker invite link
*ContractsApi* | [**get_worker_documents_by_id**](docs/ContractsApi.md#get_worker_documents_by_id) | **GET** /workers/{worker_id}/documents | List of worker documents
*ContractsApi* | [**invite_to_sign_contract**](docs/ContractsApi.md#invite_to_sign_contract) | **POST** /contracts/{contract_id}/invitations | Send contract to worker
*ContractsApi* | [**request_exercise_equity**](docs/ContractsApi.md#request_exercise_equity) | **POST** /equity/exercise | Create a request to exercise equity.
*ContractsApi* | [**sign_contract**](docs/ContractsApi.md#sign_contract) | **POST** /contracts/{contract_id}/signatures | Sign a contract
*ContractsApi* | [**uninvite_to_sign_contract**](docs/ContractsApi.md#uninvite_to_sign_contract) | **DELETE** /contracts/{contract_id}/invitations | Remove invite
*CustomFieldsApi* | [**delete_contract_custom_field**](docs/CustomFieldsApi.md#delete_contract_custom_field) | **DELETE** /contracts/{contract_id}/custom_fields/{id} | Delete Contract custom field by Id
*CustomFieldsApi* | [**delete_custom_field_value_from_worker**](docs/CustomFieldsApi.md#delete_custom_field_value_from_worker) | **DELETE** /people/{worker_id}/custom_fields/{id} | Delete the custom field value from Worker by Id
*CustomFieldsApi* | [**get_custom_field_from_contracts_by_id**](docs/CustomFieldsApi.md#get_custom_field_from_contracts_by_id) | **GET** /contracts/custom_fields/{id} | Get custom fields from contracts
*CustomFieldsApi* | [**get_custom_field_from_people_by_id**](docs/CustomFieldsApi.md#get_custom_field_from_people_by_id) | **GET** /people/custom_fields/{id} | Get custom field from people by id
*CustomFieldsApi* | [**get_custom_field_values_from_contract**](docs/CustomFieldsApi.md#get_custom_field_values_from_contract) | **GET** /contracts/{contract_id}/custom_fields | Retrieve custom fields for a contract
*CustomFieldsApi* | [**get_custom_field_values_from_worker**](docs/CustomFieldsApi.md#get_custom_field_values_from_worker) | **GET** /people/{worker_id}/custom_fields | Retrieve custom fields for a worker
*CustomFieldsApi* | [**get_custom_fields_from_contracts**](docs/CustomFieldsApi.md#get_custom_fields_from_contracts) | **GET** /contracts/custom_fields | List all custom fields
*CustomFieldsApi* | [**get_custom_fields_from_people**](docs/CustomFieldsApi.md#get_custom_fields_from_people) | **GET** /people/custom_fields | List all custom fields
*CustomFieldsApi* | [**upsert_custom_field_value_from_contracts**](docs/CustomFieldsApi.md#upsert_custom_field_value_from_contracts) | **PUT** /contracts/{contract_id}/custom_fields | Update custom field value
*CustomFieldsApi* | [**upsert_custom_field_value_from_worker**](docs/CustomFieldsApi.md#upsert_custom_field_value_from_worker) | **PUT** /people/{worker_id}/custom_fields | Update custom field value
*DeelAsAServiceApi* | [**add_daas_employee_additional_information**](docs/DeelAsAServiceApi.md#add_daas_employee_additional_information) | **POST** /daas/contracts/{contract_id}/additional-information | Add additional information
*DeelAsAServiceApi* | [**add_eor_bank_account**](docs/DeelAsAServiceApi.md#add_eor_bank_account) | **POST** /daas/banks | Add bank account
*DeelAsAServiceApi* | [**daas_sign_employee_contract**](docs/DeelAsAServiceApi.md#daas_sign_employee_contract) | **POST** /daas/contracts/{contract_id}/signatures | Sign a contract 
*DeelAsAServiceApi* | [**get_daas_employee_agreement_download_link**](docs/DeelAsAServiceApi.md#get_daas_employee_agreement_download_link) | **GET** /daas/contracts/{contract_id}/employee-agreement/download | Download employee agreement PDF
*DeelAsAServiceApi* | [**get_daas_hr_verification_letters_and_documents**](docs/DeelAsAServiceApi.md#get_daas_hr_verification_letters_and_documents) | **GET** /daas/contracts/{contract_id}/hr-documents | List HR verification letters and documents
*DeelAsAServiceApi* | [**get_daas_offer_letter_preview**](docs/DeelAsAServiceApi.md#get_daas_offer_letter_preview) | **GET** /daas/contracts/{contract_id}/offer-letter | Preview job offer letter
*DeelAsAServiceApi* | [**get_eor_bank_account_guide**](docs/DeelAsAServiceApi.md#get_eor_bank_account_guide) | **GET** /daas/banks/guide | Retrieve bank account guide
*DeelAsAServiceApi* | [**get_eor_employee_compliance_document_template**](docs/DeelAsAServiceApi.md#get_eor_employee_compliance_document_template) | **GET** /daas/compliance-documents/{document_id}/templates/download | Download employee compliance document template
*DeelAsAServiceApi* | [**get_eor_employee_compliance_documents**](docs/DeelAsAServiceApi.md#get_eor_employee_compliance_documents) | **GET** /daas/compliance-documents | List of employee compliance documents
*DeelAsAServiceApi* | [**get_eor_employee_payslips**](docs/DeelAsAServiceApi.md#get_eor_employee_payslips) | **GET** /daas/payslips | Get list of payslips for an EOR employee
*DeelAsAServiceApi* | [**get_eor_employee_tax_documents**](docs/DeelAsAServiceApi.md#get_eor_employee_tax_documents) | **GET** /daas/tax-documents | List of tax documents for an employee
*DeelAsAServiceApi* | [**patch_eor_bank_account**](docs/DeelAsAServiceApi.md#patch_eor_bank_account) | **PATCH** /daas/banks/{bank_id} | Modify bank account for an EOR employee
*EORApi* | [**calculate_eor_employment_cost**](docs/EORApi.md#calculate_eor_employment_cost) | **POST** /eor/employment_cost | Calculate Employee Costs Globally
*EORApi* | [**cancel_eor_contract**](docs/EORApi.md#cancel_eor_contract) | **POST** /eor/contract/{oid}/cancel | Cancel EOR Contract
*EORApi* | [**create_eor_contract**](docs/EORApi.md#create_eor_contract) | **POST** /eor | Create an EOR contract
*EORApi* | [**delay_eor_employee_onboarding**](docs/EORApi.md#delay_eor_employee_onboarding) | **PATCH** /eor/contract/{oid}/delay-onboarding | Delay EOR employee onboarding
*EORApi* | [**eor_resignation_request**](docs/EORApi.md#eor_resignation_request) | **POST** /eor/{oid}/terminations/resignation | Request EOR Contract Resignation
*EORApi* | [**eor_termination_request**](docs/EORApi.md#eor_termination_request) | **POST** /eor/{oid}/terminations/regular | Termination Request
*EORApi* | [**get_eor_contract_benefits**](docs/EORApi.md#get_eor_contract_benefits) | **GET** /eor/{contract_id}/benefits | Retrieve Benefits for EOR Contract
*EORApi* | [**get_eor_country_validations**](docs/EORApi.md#get_eor_country_validations) | **GET** /eor/validations/{country_code} | Retrieve detailed hiring guide for a country
*EORApi* | [**get_eor_termination**](docs/EORApi.md#get_eor_termination) | **GET** /eor/{oid}/terminations/{terminationId} | Get termination
*EORApi* | [**get_eor_worker_payslip_download_url**](docs/EORApi.md#get_eor_worker_payslip_download_url) | **GET** /eor/workers/{worker_id}/payslips/{payslip_id}/download | Retrieve payslip PDF download link
*EORApi* | [**get_eor_worker_payslips**](docs/EORApi.md#get_eor_worker_payslips) | **GET** /eor/workers/{worker_id}/payslips | Retrieve employee payslip records
*EORApi* | [**request_eor_contract_resignation_made_by_employee**](docs/EORApi.md#request_eor_contract_resignation_made_by_employee) | **POST** /eor/{oid}/terminations/resignation-by-employee | Request EOR Contract Resignation Made by Employee
*EORApi* | [**update_eor_contract**](docs/EORApi.md#update_eor_contract) | **PATCH** /eor/contract/{oid} | Update EOR Contract
*EmployeesApi* | [**get_benefit_employee**](docs/EmployeesApi.md#get_benefit_employee) | **GET** /benefits/legal-entities/{id}/employees/{employee_id} | Get employee from organization integrated with external benefits vendor
*EmployeesApi* | [**get_benefit_employees**](docs/EmployeesApi.md#get_benefit_employees) | **GET** /benefits/legal-entities/{id}/employees | Get employees from organization integrated with external benefits vendor
*EnrollmentsApi* | [**delete401k_enrollments_definition**](docs/EnrollmentsApi.md#delete401k_enrollments_definition) | **DELETE** /benefits/legal-entities/{id}/contracts/{contract_id}/plans/{plan_id} | Delete enrollment settings from an employee in a 401k plan
*EnrollmentsApi* | [**get401k_enrollments_definition**](docs/EnrollmentsApi.md#get401k_enrollments_definition) | **GET** /benefits/legal-entities/{id}/contracts/{contract_id}/plans/{plan_id} | Get enrollment settings from an employee in a 401k plan
*EnrollmentsApi* | [**post401k_enrollments_definition**](docs/EnrollmentsApi.md#post401k_enrollments_definition) | **POST** /benefits/legal-entities/{id}/contracts/{contract_id}/plans/{plan_id} | Enroll an employee in a 401k plan
*EnrollmentsApi* | [**put401k_enrollments_definition**](docs/EnrollmentsApi.md#put401k_enrollments_definition) | **PUT** /benefits/legal-entities/{id}/contracts/{contract_id}/plans/{plan_id} | Change enrollment settings from an employee in a 401k plan
*EquityApi* | [**equity_tax_events**](docs/EquityApi.md#equity_tax_events) | **POST** /equities/tax-events | Equity Tax Events
*GlobalPayrollApi* | [**add_gp_bank_account**](docs/GlobalPayrollApi.md#add_gp_bank_account) | **POST** /gp/workers/{worker_id}/banks | Add bank account
*GlobalPayrollApi* | [**create_gp_contract**](docs/GlobalPayrollApi.md#create_gp_contract) | **POST** /contracts/gp | Create a contract
*GlobalPayrollApi* | [**download_gross_to_net_gp_report**](docs/GlobalPayrollApi.md#download_gross_to_net_gp_report) | **GET** /gp/reports/{gp_report_id}/gross_to_net/csv | Download gross-to-net report
*GlobalPayrollApi* | [**get_download_url_for_gp_payslip**](docs/GlobalPayrollApi.md#get_download_url_for_gp_payslip) | **GET** /gp/workers/{id}/payslips/{payslipId}/download | Download payslip PDF
*GlobalPayrollApi* | [**get_gp_bank_accounts**](docs/GlobalPayrollApi.md#get_gp_bank_accounts) | **GET** /gp/workers/{worker_id}/banks | Retrieve bank accounts
*GlobalPayrollApi* | [**get_gp_bank_guide**](docs/GlobalPayrollApi.md#get_gp_bank_guide) | **GET** /gp/workers/{worker_id}/banks/guide | Retrieve bank guide
*GlobalPayrollApi* | [**get_gp_legal_entities**](docs/GlobalPayrollApi.md#get_gp_legal_entities) | **GET** /gp/legal-entities/{id}/reports | List payroll events by legal entity
*GlobalPayrollApi* | [**get_gross_to_net_gp_reports**](docs/GlobalPayrollApi.md#get_gross_to_net_gp_reports) | **GET** /gp/reports/{id}/gross_to_net | List gross-to-net report
*GlobalPayrollApi* | [**get_worker_payslips**](docs/GlobalPayrollApi.md#get_worker_payslips) | **GET** /gp/workers/{id}/payslips | Retrieve employee payslips
*GlobalPayrollApi* | [**patch_gp_bank_account**](docs/GlobalPayrollApi.md#patch_gp_bank_account) | **PATCH** /gp/workers/{worker_id}/banks/{bank_id} | Modify bank account
*GlobalPayrollApi* | [**request_termination**](docs/GlobalPayrollApi.md#request_termination) | **POST** /gp/workers/{worker_id}/terminations | Request termination
*GlobalPayrollApi* | [**update_gp_employee_address**](docs/GlobalPayrollApi.md#update_gp_employee_address) | **PATCH** /gp/workers/{worker_id}/address | Update address
*GlobalPayrollApi* | [**update_gp_employee_compensation**](docs/GlobalPayrollApi.md#update_gp_employee_compensation) | **PATCH** /gp/workers/{worker_id}/compensation | Update compensation
*GlobalPayrollApi* | [**update_gp_employee_information**](docs/GlobalPayrollApi.md#update_gp_employee_information) | **PATCH** /gp/workers/{worker_id}/employee-information | Update employee information
*GlobalPayrollApi* | [**update_gp_employee_pto**](docs/GlobalPayrollApi.md#update_gp_employee_pto) | **PATCH** /gp/workers/{worker_id}/pto-policy | Update PTO policy
*GroupsApi* | [**create_group**](docs/GroupsApi.md#create_group) | **POST** /groups | Create a group
*GroupsApi* | [**delete_group**](docs/GroupsApi.md#delete_group) | **DELETE** /groups/{id} | Delete a group
*GroupsApi* | [**edit_group**](docs/GroupsApi.md#edit_group) | **PATCH** /groups/{id} | Edit a group
*GroupsApi* | [**get_groups**](docs/GroupsApi.md#get_groups) | **GET** /groups | Return list of groups
*ImmigrationApi* | [**create_case**](docs/ImmigrationApi.md#create_case) | **POST** /immigration/client/cases | Create an immigration case
*ImmigrationApi* | [**immigration_case_details**](docs/ImmigrationApi.md#immigration_case_details) | **GET** /immigration/client/cases/{id} | Immigration case details
*ImmigrationApi* | [**immigration_document**](docs/ImmigrationApi.md#immigration_document) | **GET** /immigration/documents/{id} | Immigration document
*ImmigrationApi* | [**immigration_visa_types**](docs/ImmigrationApi.md#immigration_visa_types) | **GET** /immigration/visa-types/{country_code} | Immigration visa types
*IntegrationsApi* | [**get_consent**](docs/IntegrationsApi.md#get_consent) | **GET** /integrations/consent | Get integration consent
*InvoicesApi* | [**create_invoice_adjustment**](docs/InvoicesApi.md#create_invoice_adjustment) | **POST** /invoice-adjustments | Create an invoice adjustment
*InvoicesApi* | [**create_invoice_adjustment_reviews**](docs/InvoicesApi.md#create_invoice_adjustment_reviews) | **POST** /invoice-adjustments/many/reviews | Bulk review invoice adjustments
*InvoicesApi* | [**delete_invoice_adjustment**](docs/InvoicesApi.md#delete_invoice_adjustment) | **DELETE** /invoice-adjustments/{id} | Delete adjustment
*InvoicesApi* | [**get_invoice_adjustments**](docs/InvoicesApi.md#get_invoice_adjustments) | **GET** /invoice-adjustments | List invoice adjustments
*InvoicesApi* | [**get_invoice_adjustments_by_contract_id**](docs/InvoicesApi.md#get_invoice_adjustments_by_contract_id) | **GET** /contracts/{contract_id}/invoice-adjustments | Invoice line items by contract
*InvoicesApi* | [**get_invoice_adjustments_by_id**](docs/InvoicesApi.md#get_invoice_adjustments_by_id) | **GET** /invoice-adjustments/{id} | Invoice line item by Id
*InvoicesApi* | [**update_invoice_adjustment**](docs/InvoicesApi.md#update_invoice_adjustment) | **PATCH** /invoice-adjustments/{id} | Update an invoice adjustment
*InvoicesApi* | [**update_invoice_adjustment_by_id**](docs/InvoicesApi.md#update_invoice_adjustment_by_id) | **POST** /invoice-adjustments/{id}/reviews | Review an invoice adjustment
*LegalEntitiesApi* | [**create_legal_entity**](docs/LegalEntitiesApi.md#create_legal_entity) | **POST** /legal-entities | Create a new legal entity
*LegalEntitiesApi* | [**delete_legal_entity**](docs/LegalEntitiesApi.md#delete_legal_entity) | **DELETE** /legal-entities/{id} | Delete a legal entity
*LegalEntitiesApi* | [**edit_legal_entity**](docs/LegalEntitiesApi.md#edit_legal_entity) | **PATCH** /legal-entities/{id} | Edit a legal entity
*LegalEntitiesApi* | [**get_legal_entity**](docs/LegalEntitiesApi.md#get_legal_entity) | **GET** /benefits/legal-entities/{id} | Get legal entity data from organization integrated with external benefits vendor
*LegalEntitiesApi* | [**get_legal_entity_payroll_settings**](docs/LegalEntitiesApi.md#get_legal_entity_payroll_settings) | **GET** /benefits/legal-entities/{id}/payroll-settings | Get legal entity payroll settings from organization integrated with external benefits vendor
*LoansApi* | [**post401k_single_deduction_definition**](docs/LoansApi.md#post401k_single_deduction_definition) | **POST** /benefits/legal-entities/{id}/contracts/{contract_id}/plans/{plan_id}/deductions | Create a single deduction loan
*LookupsApi* | [**get_countries**](docs/LookupsApi.md#get_countries) | **GET** /lookups/countries | Retrieve Country List
*LookupsApi* | [**get_currencies**](docs/LookupsApi.md#get_currencies) | **GET** /lookups/currencies | Retrieve Supported Currency List
*LookupsApi* | [**get_job_title_list**](docs/LookupsApi.md#get_job_title_list) | **GET** /lookups/job-titles | Job titles list
*LookupsApi* | [**get_lookups**](docs/LookupsApi.md#get_lookups) | **GET** /lookups | Retrieve lookup information for currencies, countries, entity types, etc
*LookupsApi* | [**get_seniority_list**](docs/LookupsApi.md#get_seniority_list) | **GET** /lookups/seniorities | Retrieve Seniority Levels
*LookupsApi* | [**get_timeoff_type_list**](docs/LookupsApi.md#get_timeoff_type_list) | **GET** /lookups/time-off-types | Retrieve Time-Off Types
*ManagersApi* | [**create_manager**](docs/ManagersApi.md#create_manager) | **POST** /managers | Create a Manager
*ManagersApi* | [**get_managers**](docs/ManagersApi.md#get_managers) | **GET** /managers | Retrieve List of Managers
*MilestonesApi* | [**create_milestone**](docs/MilestonesApi.md#create_milestone) | **POST** /contracts/{contract_id}/milestones | Create a Milestone
*MilestonesApi* | [**create_milestone_review**](docs/MilestonesApi.md#create_milestone_review) | **POST** /contracts/{contract_id}/milestones/{milestone_id}/reviews | Review a single milestone
*MilestonesApi* | [**create_milestone_reviews**](docs/MilestonesApi.md#create_milestone_reviews) | **POST** /contracts/{contract_id}/milestones/many/reviews | Review multiple milestones
*MilestonesApi* | [**delete_milestone_by_id**](docs/MilestonesApi.md#delete_milestone_by_id) | **DELETE** /contracts/{contract_id}/milestones/{milestone_id} | Delete a Milestone
*MilestonesApi* | [**get_milestones_by_contract**](docs/MilestonesApi.md#get_milestones_by_contract) | **GET** /contracts/{contract_id}/milestones | Retrieve Milestones by Contract
*MilestonesApi* | [**get_milestones_by_contract_and_id**](docs/MilestonesApi.md#get_milestones_by_contract_and_id) | **GET** /contracts/{contract_id}/milestones/{milestone_id} | Retrieve a single milestone
*OffCyclePaymentsApi* | [**create_off_cycle_payment**](docs/OffCyclePaymentsApi.md#create_off_cycle_payment) | **POST** /contracts/{contract_id}/off-cycle-payments | Add off-cycle payment
*OffCyclePaymentsApi* | [**get_off_cycle_payment_by_contract_and_id**](docs/OffCyclePaymentsApi.md#get_off_cycle_payment_by_contract_and_id) | **GET** /contracts/{contract_id}/off-cycle-payments/{id} | Retrieve a single off-cycle payment
*OffCyclePaymentsApi* | [**get_off_cycle_payments_by_contract**](docs/OffCyclePaymentsApi.md#get_off_cycle_payments_by_contract) | **GET** /contracts/{contract_id}/off-cycle-payments | List of off-cycle payments
*OffboardingApi* | [**offboarding_tracker_get**](docs/OffboardingApi.md#offboarding_tracker_get) | **GET** /offboarding/tracker | Retrieve offboarding list
*OffboardingApi* | [**offboarding_tracker_hris_profile_oid_get**](docs/OffboardingApi.md#offboarding_tracker_hris_profile_oid_get) | **GET** /offboarding/tracker/hris_profile/{oid} | Retrieve termination details
*OffboardingApi* | [**offboarding_tracker_id_get**](docs/OffboardingApi.md#offboarding_tracker_id_get) | **GET** /offboarding/tracker/{id} | Retrieve termination details
*OnboardingApi* | [**list_onboarding_tracker**](docs/OnboardingApi.md#list_onboarding_tracker) | **GET** /onboarding/tracker | List onboarding employees
*OnboardingApi* | [**onboarding_tracker_hris_profile_oid_get**](docs/OnboardingApi.md#onboarding_tracker_hris_profile_oid_get) | **GET** /onboarding/tracker/hris_profile/{oid} | Get onboarding details by onboarding hris profile oid
*OnboardingApi* | [**onboarding_tracker_id_get**](docs/OnboardingApi.md#onboarding_tracker_id_get) | **GET** /onboarding/tracker/{id} | Get onboarding details by onboarding tracker ID
*OrganizationStructureApi* | [**create_org_structure**](docs/OrganizationStructureApi.md#create_org_structure) | **POST** /hris/organization_structures | Create a new HRIS Organization Structure.
*OrganizationStructureApi* | [**delete_org_structure**](docs/OrganizationStructureApi.md#delete_org_structure) | **DELETE** /hris/organization_structures/{hrisOrgStr_id} | Delete an Org Structure from the Organization
*OrganizationStructureApi* | [**delete_org_structure_by_external_id**](docs/OrganizationStructureApi.md#delete_org_structure_by_external_id) | **DELETE** /hris/organization_structures/external/{external_id} | Delete an Org Structure from the Organization by external ID
*OrganizationStructureApi* | [**get_all_org_structures**](docs/OrganizationStructureApi.md#get_all_org_structures) | **GET** /hris/organization_structures | Fetch all Org Structures from the Organization.
*OrganizationStructureApi* | [**get_org_structure**](docs/OrganizationStructureApi.md#get_org_structure) | **GET** /hris/organization_structures/{hrisOrgStr_id} | Fetch an Org Structure from the Organization
*OrganizationStructureApi* | [**get_org_structure_by_external_id**](docs/OrganizationStructureApi.md#get_org_structure_by_external_id) | **GET** /hris/organization_structures/external/{external_id} | Fetch an Org Structure from the Organization
*OrganizationStructureApi* | [**update_org_structure**](docs/OrganizationStructureApi.md#update_org_structure) | **PATCH** /hris/organization_structures/{hrisOrgStr_id} | Update an existing HRIS Org Structure
*OrganizationStructureApi* | [**update_org_structure_by_external_id**](docs/OrganizationStructureApi.md#update_org_structure_by_external_id) | **PATCH** /hris/organization_structures/external/{external_id} | Update an existing HRIS Org Structure by external ID
*OrganizationsApi* | [**create_organization_role**](docs/OrganizationsApi.md#create_organization_role) | **POST** /roles | Create organization custom role.
*OrganizationsApi* | [**get_departments**](docs/OrganizationsApi.md#get_departments) | **GET** /departments | Retrieve Departments
*OrganizationsApi* | [**get_legal_entity_list**](docs/OrganizationsApi.md#get_legal_entity_list) | **GET** /legal-entities | List of legal entities
*OrganizationsApi* | [**get_organization_roles**](docs/OrganizationsApi.md#get_organization_roles) | **GET** /roles | Get the roles of the current organization.
*OrganizationsApi* | [**get_organizations**](docs/OrganizationsApi.md#get_organizations) | **GET** /organizations | Get Current Organization
*OrganizationsApi* | [**get_teams**](docs/OrganizationsApi.md#get_teams) | **GET** /teams | Get Team List
*OrganizationsApi* | [**get_working_locations**](docs/OrganizationsApi.md#get_working_locations) | **GET** /working-locations | Retrieve working locations
*OrganizationsApi* | [**update_organization_role**](docs/OrganizationsApi.md#update_organization_role) | **PATCH** /roles/{roleId} | Update organization custom role
*PartnerManagedApi* | [**add_bank_account**](docs/PartnerManagedApi.md#add_bank_account) | **POST** /partner-managed/employees/{employee_id}/banks | Add bank account
*PartnerManagedApi* | [**add_employee_additional_information**](docs/PartnerManagedApi.md#add_employee_additional_information) | **POST** /partner-managed/employees/{employee_id}/contracts/{contract_id}/additional-information | Add additional information
*PartnerManagedApi* | [**download_hr_verification_letters_and_documents**](docs/PartnerManagedApi.md#download_hr_verification_letters_and_documents) | **GET** /partner-managed/employees/{employee_id}/contracts/{contract_id}/hr-documents/{document_id}/download | Download HR verification letters and documents
*PartnerManagedApi* | [**get_bank_account_guide**](docs/PartnerManagedApi.md#get_bank_account_guide) | **GET** /partner-managed/employees/{employee_id}/banks/guide | Bank account form
*PartnerManagedApi* | [**get_employee_agreement_download_link**](docs/PartnerManagedApi.md#get_employee_agreement_download_link) | **GET** /partner-managed/employees/{employee_id}/contracts/{contract_id}/employee-agreement/download | Download employee agreement PDF
*PartnerManagedApi* | [**get_employee_agreement_preview**](docs/PartnerManagedApi.md#get_employee_agreement_preview) | **GET** /partner-managed/employees/{employee_id}/contracts/{contract_id}/employee-agreement | Preview employee agreement
*PartnerManagedApi* | [**get_employee_compliance_document_template**](docs/PartnerManagedApi.md#get_employee_compliance_document_template) | **GET** /partner-managed/employees/{employee_id}/compliance-documents/{document_id}/templates/download | Download employee compliance document template
*PartnerManagedApi* | [**get_employee_compliance_documents**](docs/PartnerManagedApi.md#get_employee_compliance_documents) | **GET** /partner-managed/employees/{employee_id}/compliance-documents | List of employee compliance documents
*PartnerManagedApi* | [**get_employee_payslips**](docs/PartnerManagedApi.md#get_employee_payslips) | **GET** /partner-managed/employees/{employee_id}/payslips | Get list of payslips for an EOR employee
*PartnerManagedApi* | [**get_employee_tax_documents**](docs/PartnerManagedApi.md#get_employee_tax_documents) | **GET** /partner-managed/employees/{employee_id}/tax-documents | List of tax documents for an employee
*PartnerManagedApi* | [**get_hr_verification_letters_and_documents**](docs/PartnerManagedApi.md#get_hr_verification_letters_and_documents) | **GET** /partner-managed/employees/{employee_id}/contracts/{contract_id}/hr-documents | List HR verification letters and documents
*PartnerManagedApi* | [**get_offer_letter_preview**](docs/PartnerManagedApi.md#get_offer_letter_preview) | **GET** /partner-managed/employees/{employee_id}/contracts/{contract_id}/offer-letter | Preview job offer letter
*PartnerManagedApi* | [**patch_bank_account**](docs/PartnerManagedApi.md#patch_bank_account) | **PATCH** /partner-managed/employees/{employee_id}/banks/{bank_id} | Modify bank account for an EOR employee
*PartnerManagedApi* | [**request_custom_verification_letter**](docs/PartnerManagedApi.md#request_custom_verification_letter) | **POST** /partner-managed/employees/{employee_id}/contracts/{contract_id}/custom-verification-letter | Request custom verification letter
*PartnerManagedApi* | [**sign_employee_contract**](docs/PartnerManagedApi.md#sign_employee_contract) | **POST** /partner-managed/employees/{employee_id}/contracts/{contract_id}/signatures | Sign a contract
*PartnerManagedApi* | [**upload_employee_compliance_document**](docs/PartnerManagedApi.md#upload_employee_compliance_document) | **POST** /partner-managed/employees/{employee_id}/compliance-documents/{document_id} | Upload employee compliance document
*PayoutsApi* | [**create_bank_transfer_method**](docs/PayoutsApi.md#create_bank_transfer_method) | **POST** /payouts/contractors/methods | Create a bank transfer method
*PayoutsApi* | [**get_bank_transfer_requirements**](docs/PayoutsApi.md#get_bank_transfer_requirements) | **GET** /payouts/contractors/methods/bank_transfers/requirements | Get bank transfer requirements
*PayoutsApi* | [**get_bank_transfer_supported_routes**](docs/PayoutsApi.md#get_bank_transfer_supported_routes) | **GET** /payouts/contractors/methods/bank_transfers/supported_routes | Get bank transfer supported routes for contractor
*PayoutsApi* | [**get_payout_methods**](docs/PayoutsApi.md#get_payout_methods) | **GET** /payouts/contractors/methods | Fetch all payout methods
*PayoutsApi* | [**update_auto_withdraw_setting**](docs/PayoutsApi.md#update_auto_withdraw_setting) | **POST** /payouts/contractors/settings/auto_withdraw | Update auto withdraw setting for contractor
*PayoutsApi* | [**update_bank_transfer_method**](docs/PayoutsApi.md#update_bank_transfer_method) | **PUT** /payouts/contractors/methods/{id} | Update a bank transfer method
*PayrollApi* | [**get_pay_stub**](docs/PayrollApi.md#get_pay_stub) | **GET** /benefits/legal-entities/{id}/pay-stub | Get pay stub from employees from organization integrated with external benefits vendor
*PayrollApi* | [**get_year_to_date_pay**](docs/PayrollApi.md#get_year_to_date_pay) | **GET** /benefits/legal-entities/{id}/year-to-date-pay | Get year to date payment for benefits 401k.
*PaystubsApi* | [**get_benefit_paystubs**](docs/PaystubsApi.md#get_benefit_paystubs) | **GET** /benefits/legal-entities/{legalEntityId}/paystubs | Get paystubs from legal entity integrated with external benefits vendor
*PeopleApi* | [**create_direct_employee**](docs/PeopleApi.md#create_direct_employee) | **POST** /people | Create a direct employee
*PeopleApi* | [**create_direct_employee_old_tobe_removed**](docs/PeopleApi.md#create_direct_employee_old_tobe_removed) | **POST** /hris/direct-employees-old-to-beremoved | Create a new Hris direct employee
*PeopleApi* | [**get_people**](docs/PeopleApi.md#get_people) | **GET** /people/me | Get my current personal profile
*PeopleApi* | [**get_people_by_id**](docs/PeopleApi.md#get_people_by_id) | **GET** /people/{hrisProfileOid} | Retrieve a single person
*PeopleApi* | [**get_people_list**](docs/PeopleApi.md#get_people_list) | **GET** /people | List of people
*PeopleApi* | [**get_people_personal_information_by_external_id**](docs/PeopleApi.md#get_people_personal_information_by_external_id) | **GET** /people/external/{worker_id}/personal | Get personal information by external id
*PeopleApi* | [**get_people_personal_information_by_id**](docs/PeopleApi.md#get_people_personal_information_by_id) | **GET** /people/{worker_id}/personal | Get personal information by id
*PeopleApi* | [**update_people_department**](docs/PeopleApi.md#update_people_department) | **PUT** /people/{id}/department | Update department
*PeopleApi* | [**update_people_personal_information_by_external_id**](docs/PeopleApi.md#update_people_personal_information_by_external_id) | **PATCH** /people/external/{worker_id}/personal | Update personal information by external id
*PeopleApi* | [**update_people_personal_information_by_id**](docs/PeopleApi.md#update_people_personal_information_by_id) | **PATCH** /people/{worker_id}/personal | Update personal information
*PeopleApi* | [**update_people_working_location**](docs/PeopleApi.md#update_people_working_location) | **PUT** /people/{id}/working-location | Update working location
*Plans401KApi* | [**clean_up_plan**](docs/Plans401KApi.md#clean_up_plan) | **POST** /benefits/legal-entities/{id}/401k/plans/clean-up | Clean up plan for a given legal entity
*Plans401KApi* | [**create_benefit_provider_integration_client**](docs/Plans401KApi.md#create_benefit_provider_integration_client) | **POST** /benefits/legal-entities/{id}/benefits/401k/activate | Activate the 401k integration for the legal entity
*Plans401KApi* | [**delete401k_plan_definition**](docs/Plans401KApi.md#delete401k_plan_definition) | **DELETE** /benefits/legal-entities/{id}/401k/plans/{plan_id} | Delete a 401k plan
*Plans401KApi* | [**get401k_plans_definition**](docs/Plans401KApi.md#get401k_plans_definition) | **GET** /benefits/legal-entities/{id}/401k/plans | Get 401k plans for legal entity
*Plans401KApi* | [**post401k_plans_definition**](docs/Plans401KApi.md#post401k_plans_definition) | **POST** /benefits/legal-entities/{id}/401k/plans | Create 401k plan for legal entity
*Plans401KApi* | [**put401k_plans_definition**](docs/Plans401KApi.md#put401k_plans_definition) | **PUT** /benefits/legal-entities/{id}/401k/plans/{plan_id} | Update 401k plan
*PositionsApi* | [**apply_changes_positions**](docs/PositionsApi.md#apply_changes_positions) | **POST** /hris/positions/apply_changes | Apply changes to positions.
*PositionsApi* | [**get_hris_positions**](docs/PositionsApi.md#get_hris_positions) | **GET** /hris/positions/profile/{hrisProfileId} | Fetch HrisPositions from a HrisProfile
*ReportsApi* | [**get_detailed_payments_report**](docs/ReportsApi.md#get_detailed_payments_report) | **GET** /reports/detailed-payments | Detailed payments report
*ScreeningsApi* | [**create_manual_verification_screening**](docs/ScreeningsApi.md#create_manual_verification_screening) | **POST** /screenings/manual-verification | Create manual verification screening
*ScreeningsApi* | [**create_veriff_session**](docs/ScreeningsApi.md#create_veriff_session) | **POST** /veriff/session | Create Veriff session
*ScreeningsApi* | [**get_verification_method**](docs/ScreeningsApi.md#get_verification_method) | **GET** /screenings/verification-method | Get verification method
*TasksApi* | [**create_contract_pgo_tak**](docs/TasksApi.md#create_contract_pgo_tak) | **POST** /contracts/{contract_id}/tasks | Create a new task
*TasksApi* | [**create_task_many_review**](docs/TasksApi.md#create_task_many_review) | **POST** /contracts/{contract_id}/tasks/many/reviews | Review multiple tasks
*TasksApi* | [**create_task_review_by_id**](docs/TasksApi.md#create_task_review_by_id) | **POST** /contracts/{contract_id}/tasks/{task_id}/reviews | Review a single task
*TasksApi* | [**delete_contract_task_by_id**](docs/TasksApi.md#delete_contract_task_by_id) | **DELETE** /contracts/{contract_id}/tasks/{task_id} | Delete task
*TasksApi* | [**get_tasks_by_contract**](docs/TasksApi.md#get_tasks_by_contract) | **GET** /contracts/{contract_id}/tasks | List of tasks
*TimeOffApi* | [**create_time_off**](docs/TimeOffApi.md#create_time_off) | **POST** /time_offs | Create time-off request
*TimeOffApi* | [**delete_time_off**](docs/TimeOffApi.md#delete_time_off) | **DELETE** /time_offs/{time_off_id} | Delete time-off request
*TimeOffApi* | [**get_policies_for_profile**](docs/TimeOffApi.md#get_policies_for_profile) | **GET** /time_offs/profile/{hris_profile_id}/policies | List policies
*TimeOffApi* | [**get_profile_entitlements**](docs/TimeOffApi.md#get_profile_entitlements) | **GET** /time_offs/profile/{hris_profile_id}/entitlements | Get Profile Entitlements
*TimeOffApi* | [**get_time_offs_query**](docs/TimeOffApi.md#get_time_offs_query) | **GET** /time_offs/profile/{hris_profile_id} | List time-off requests
*TimeOffApi* | [**get_time_offs_query_for_organization**](docs/TimeOffApi.md#get_time_offs_query_for_organization) | **GET** /time_offs | List time-off requests for Organization
*TimeOffApi* | [**update_time_off**](docs/TimeOffApi.md#update_time_off) | **PATCH** /time_offs/{time_off_id} | Update time-off request
*TimeTrackingRatesApi* | [**create_shift_rate**](docs/TimeTrackingRatesApi.md#create_shift_rate) | **POST** /time_tracking/shift_rates | Create a New Shift Rate
*TimeTrackingRatesApi* | [**delete_shift_rate_external_id**](docs/TimeTrackingRatesApi.md#delete_shift_rate_external_id) | **DELETE** /time_tracking/shift_rates/{external_id} | Delete a ShiftRate by external ID
*TimeTrackingRatesApi* | [**get_shift_rate**](docs/TimeTrackingRatesApi.md#get_shift_rate) | **GET** /time_tracking/shift_rates/{external_id} | Retrieve a Shift Rate by External ID
*TimeTrackingRatesApi* | [**get_shift_rates**](docs/TimeTrackingRatesApi.md#get_shift_rates) | **GET** /time_tracking/shift_rates | Retrieve a Paginated List of Shift Rates
*TimeTrackingRatesApi* | [**update_shift_rate**](docs/TimeTrackingRatesApi.md#update_shift_rate) | **PATCH** /time_tracking/shift_rates/{external_id} | Update a shift rate
*TimeTrackingShiftsApi* | [**create_shifts**](docs/TimeTrackingShiftsApi.md#create_shifts) | **POST** /time_tracking/shifts | Create shifts
*TimeTrackingShiftsApi* | [**delete_shift_external_id**](docs/TimeTrackingShiftsApi.md#delete_shift_external_id) | **DELETE** /time_tracking/shifts/{external_id} | Delete a Shift by External ID
*TimeTrackingShiftsApi* | [**get_shift_details**](docs/TimeTrackingShiftsApi.md#get_shift_details) | **GET** /time_tracking/shifts/{external_id} | Get shift details
*TimeTrackingShiftsApi* | [**get_shifts**](docs/TimeTrackingShiftsApi.md#get_shifts) | **GET** /time_tracking/shifts | List of shifts
*TimeTrackingShiftsApi* | [**update_shift**](docs/TimeTrackingShiftsApi.md#update_shift) | **PATCH** /time_tracking/shifts/{external_id} | Update a shift
*TimesheetsApi* | [**create_timesheet**](docs/TimesheetsApi.md#create_timesheet) | **POST** /timesheets | Create a timesheet entry
*TimesheetsApi* | [**create_timesheet_review**](docs/TimesheetsApi.md#create_timesheet_review) | **POST** /timesheets/{id}/reviews | Review a single timesheet
*TimesheetsApi* | [**create_timesheet_reviews**](docs/TimesheetsApi.md#create_timesheet_reviews) | **POST** /timesheets/many/reviews | Review multiple timesheets
*TimesheetsApi* | [**delete_timesheet_by_id**](docs/TimesheetsApi.md#delete_timesheet_by_id) | **DELETE** /timesheets/{id} | Delete a timesheet entry
*TimesheetsApi* | [**get_timesheet_by_id**](docs/TimesheetsApi.md#get_timesheet_by_id) | **GET** /timesheets/{id} | Retrieve a single timesheet entry
*TimesheetsApi* | [**get_timesheets**](docs/TimesheetsApi.md#get_timesheets) | **GET** /timesheets | List of timesheets
*TimesheetsApi* | [**get_timesheets_by_contract**](docs/TimesheetsApi.md#get_timesheets_by_contract) | **GET** /contracts/{contract_id}/timesheets | List of timesheets by contract
*TimesheetsApi* | [**update_timesheet_by_id**](docs/TimesheetsApi.md#update_timesheet_by_id) | **PATCH** /timesheets/{id} | Update a timesheet entry
*TokenApi* | [**create_public_token**](docs/TokenApi.md#create_public_token) | **POST** /public-tokens | Create a public token
*WebhooksApi* | [**create_webhook**](docs/WebhooksApi.md#create_webhook) | **POST** /webhooks | Create a webhook
*WebhooksApi* | [**get_all_webhook_event_types**](docs/WebhooksApi.md#get_all_webhook_event_types) | **GET** /webhooks/events/types | List of webhook event types
*WebhooksApi* | [**get_all_webhooks**](docs/WebhooksApi.md#get_all_webhooks) | **GET** /webhooks | List of webhooks
*WebhooksApi* | [**webhook_controller_delete_by_id**](docs/WebhooksApi.md#webhook_controller_delete_by_id) | **DELETE** /webhooks/{id} | Delete a webhook
*WebhooksApi* | [**webhook_controller_edit_by_id**](docs/WebhooksApi.md#webhook_controller_edit_by_id) | **PATCH** /webhooks/{id} | Edit a webhook
*WebhooksApi* | [**webhook_controller_get_by_id**](docs/WebhooksApi.md#webhook_controller_get_by_id) | **GET** /webhooks/{id} | Retrieve a single webhook
*WorkerRelationsApi* | [**create_or_update_parent_relation_between_profiles**](docs/WorkerRelationsApi.md#create_or_update_parent_relation_between_profiles) | **PUT** /hris/worker_relations/profile/external/{hrisProfileExternalId}/parent | Create a parent worker relation with external id
*WorkerRelationsApi* | [**create_worker_relation**](docs/WorkerRelationsApi.md#create_worker_relation) | **POST** /hris/worker_relations/profile | Create a worker relation
*WorkerRelationsApi* | [**create_worker_relation_external_id**](docs/WorkerRelationsApi.md#create_worker_relation_external_id) | **POST** /hris/worker_relations/profile/external | Create worker relation with external Ids
*WorkerRelationsApi* | [**create_worker_relation_type**](docs/WorkerRelationsApi.md#create_worker_relation_type) | **POST** /hris/worker_relations/types | Create worker relation type
*WorkerRelationsApi* | [**delete_worker_relation**](docs/WorkerRelationsApi.md#delete_worker_relation) | **DELETE** /hris/worker_relations/profile/{hrisProfileOid} | Delete a worker relation
*WorkerRelationsApi* | [**delete_worker_relation_external_id**](docs/WorkerRelationsApi.md#delete_worker_relation_external_id) | **DELETE** /hris/worker_relations/profile/external/{profileId} | Delete a worker relation by external id
*WorkerRelationsApi* | [**delete_worker_relation_type**](docs/WorkerRelationsApi.md#delete_worker_relation_type) | **DELETE** /hris/worker_relations/types/{typeId} | Delete a worker relation type
*WorkerRelationsApi* | [**delete_worker_relation_type_external_id**](docs/WorkerRelationsApi.md#delete_worker_relation_type_external_id) | **DELETE** /hris/worker_relations/types/external/{externalId} | Delete a worker relation type by external id
*WorkerRelationsApi* | [**get_all_profile_worker_relations**](docs/WorkerRelationsApi.md#get_all_profile_worker_relations) | **GET** /hris/worker_relations/profile/{hrisProfileOid} | List of worker relations
*WorkerRelationsApi* | [**get_all_profile_worker_relations_external_id**](docs/WorkerRelationsApi.md#get_all_profile_worker_relations_external_id) | **GET** /hris/worker_relations/profile/external/{profileId} | Fetch Worker Relations of a given HrisProfile by external id
*WorkerRelationsApi* | [**get_all_worker_relation_types**](docs/WorkerRelationsApi.md#get_all_worker_relation_types) | **GET** /hris/worker_relations/types | Retrieve all worker relation types
*WorkerRelationsApi* | [**update_worker_relation_type**](docs/WorkerRelationsApi.md#update_worker_relation_type) | **PATCH** /hris/worker_relations/types/{typeId} | Update a worker relation type
*WorkerRelationsApi* | [**update_worker_relation_type_external_id**](docs/WorkerRelationsApi.md#update_worker_relation_type_external_id) | **PATCH** /hris/worker_relations/types/external/{externalId} | Update a worker relation type by external id
*WorkerRelationsApi* | [**upsert_child_worker_relations**](docs/WorkerRelationsApi.md#upsert_child_worker_relations) | **PUT** /hris/worker_relations/profile/{hrisProfileOid}/child | Create child worker relation
*WorkerRelationsApi* | [**upsert_child_worker_relations_external_id**](docs/WorkerRelationsApi.md#upsert_child_worker_relations_external_id) | **PUT** /hris/worker_relations/profile/external/{profileId}/child | Create child worker relation with external Id
*WorkerRelationsApi* | [**upsert_parent_worker_relations**](docs/WorkerRelationsApi.md#upsert_parent_worker_relations) | **PUT** /hris/worker_relations/profile/{hrisProfileOid}/parent | Create a parent worker relation
*WorkersApi* | [**create_worker**](docs/WorkersApi.md#create_worker) | **POST** /worker | Create a new worker
*DefaultApi* | [**add_edit_bank_details**](docs/DefaultApi.md#add_edit_bank_details) | **POST** /payouts/employees/methods | Add/Edit Bank Details
*DefaultApi* | [**delete_bank_details**](docs/DefaultApi.md#delete_bank_details) | **DELETE** /payouts/employees/methods/{id} | Delete Bank Details
*DefaultApi* | [**dynamic_requirements**](docs/DefaultApi.md#dynamic_requirements) | **POST** /payouts/employees/methods/bank_transfers/requirements | Dynamic Requirements
*DefaultApi* | [**get_bank_details**](docs/DefaultApi.md#get_bank_details) | **GET** /payouts/employees/methods | Get Bank Details
*DefaultApi* | [**profiles**](docs/DefaultApi.md#profiles) | **PATCH** /profiles | Profiles


## Documentation For Models

 - [AddContractDocument201Response](docs/AddContractDocument201Response.md)
 - [AddContractDocument201ResponseData](docs/AddContractDocument201ResponseData.md)
 - [AddDaasEmployeeAdditionalInformation200Response](docs/AddDaasEmployeeAdditionalInformation200Response.md)
 - [AddDaasEmployeeAdditionalInformation200ResponseData](docs/AddDaasEmployeeAdditionalInformation200ResponseData.md)
 - [AddDaasEmployeeAdditionalInformationRequest](docs/AddDaasEmployeeAdditionalInformationRequest.md)
 - [AddEORBankAccount201Response](docs/AddEORBankAccount201Response.md)
 - [AddEORBankAccount201ResponseData](docs/AddEORBankAccount201ResponseData.md)
 - [AddEditBankDetails200Response](docs/AddEditBankDetails200Response.md)
 - [AddEditBankDetails200ResponseData](docs/AddEditBankDetails200ResponseData.md)
 - [AddEditBankDetails200ResponseDataData](docs/AddEditBankDetails200ResponseDataData.md)
 - [AddEditBankDetailsRequest](docs/AddEditBankDetailsRequest.md)
 - [AddEditBankDetailsRequestData](docs/AddEditBankDetailsRequestData.md)
 - [AddEditBankDetailsRequestDataPayload](docs/AddEditBankDetailsRequestDataPayload.md)
 - [AddGpBankAccount201Response](docs/AddGpBankAccount201Response.md)
 - [AddGpBankAccount201ResponseData](docs/AddGpBankAccount201ResponseData.md)
 - [AddGpBankAccountRequest](docs/AddGpBankAccountRequest.md)
 - [AddGpBankAccountRequestData](docs/AddGpBankAccountRequestData.md)
 - [AddWorkerBankAccountContainer](docs/AddWorkerBankAccountContainer.md)
 - [AdditionalEORInfoContainer](docs/AdditionalEORInfoContainer.md)
 - [Address](docs/Address.md)
 - [AdjustmentCategory](docs/AdjustmentCategory.md)
 - [AdjustmentCreatedContainer](docs/AdjustmentCreatedContainer.md)
 - [AdjustmentStatusEnum](docs/AdjustmentStatusEnum.md)
 - [AdjustmentToCreate](docs/AdjustmentToCreate.md)
 - [AdjustmentToCreateContainer](docs/AdjustmentToCreateContainer.md)
 - [AdjustmentToUpdate](docs/AdjustmentToUpdate.md)
 - [AdjustmentToUpdateContainer](docs/AdjustmentToUpdateContainer.md)
 - [AdjustmentsCategoriesContainer](docs/AdjustmentsCategoriesContainer.md)
 - [AdjustmentsContainer](docs/AdjustmentsContainer.md)
 - [AdjustmentsContainerPage](docs/AdjustmentsContainerPage.md)
 - [AdminUser](docs/AdminUser.md)
 - [AdminUserCreateContainer](docs/AdminUserCreateContainer.md)
 - [AdminUserCreateRequest](docs/AdminUserCreateRequest.md)
 - [AdminUsersContainer](docs/AdminUsersContainer.md)
 - [Agreement](docs/Agreement.md)
 - [AgreementClientLegalEntity](docs/AgreementClientLegalEntity.md)
 - [AgreementListContainer](docs/AgreementListContainer.md)
 - [AgreementMsa](docs/AgreementMsa.md)
 - [AgreementProviderLegalEntity](docs/AgreementProviderLegalEntity.md)
 - [AgreementsSearchForm](docs/AgreementsSearchForm.md)
 - [AlternateEmailItem](docs/AlternateEmailItem.md)
 - [AmendContractDetails201Response](docs/AmendContractDetails201Response.md)
 - [AmendContractDetails201ResponseData](docs/AmendContractDetails201ResponseData.md)
 - [AmendContractDetailsRequest](docs/AmendContractDetailsRequest.md)
 - [AmendContractDetailsRequestJobTitleId](docs/AmendContractDetailsRequestJobTitleId.md)
 - [ApiError](docs/ApiError.md)
 - [ApiErrorContainer](docs/ApiErrorContainer.md)
 - [ApiErrorRequest](docs/ApiErrorRequest.md)
 - [ApplyChangesPositionsRequest](docs/ApplyChangesPositionsRequest.md)
 - [ApplyChangesPositionsRequestData](docs/ApplyChangesPositionsRequestData.md)
 - [ApplyChangesPositionsRequestDataAddInner](docs/ApplyChangesPositionsRequestDataAddInner.md)
 - [ApplyChangesPositionsRequestDataDeleteInner](docs/ApplyChangesPositionsRequestDataDeleteInner.md)
 - [ApplyChangesPositionsRequestDataEditInner](docs/ApplyChangesPositionsRequestDataEditInner.md)
 - [ApproveExerciseEquity200Response](docs/ApproveExerciseEquity200Response.md)
 - [ApproveExerciseEquityRequest](docs/ApproveExerciseEquityRequest.md)
 - [Attachment](docs/Attachment.md)
 - [BankAccountAdded](docs/BankAccountAdded.md)
 - [BankAccountAddedContainer](docs/BankAccountAddedContainer.md)
 - [BankAccountGuide](docs/BankAccountGuide.md)
 - [BankAccountGuideContainer](docs/BankAccountGuideContainer.md)
 - [BankAccountStatus](docs/BankAccountStatus.md)
 - [BankAccountToAddContainer](docs/BankAccountToAddContainer.md)
 - [BankAccountToAddInner](docs/BankAccountToAddInner.md)
 - [BankAccountUpdated](docs/BankAccountUpdated.md)
 - [BankAccountUpdatedContainer](docs/BankAccountUpdatedContainer.md)
 - [BankAccountValueAllowed](docs/BankAccountValueAllowed.md)
 - [BasicContract](docs/BasicContract.md)
 - [BasicInvoiceAdjustment](docs/BasicInvoiceAdjustment.md)
 - [BasicInvoiceAdjustmentPaymentCycle](docs/BasicInvoiceAdjustmentPaymentCycle.md)
 - [BasicLegalEntity](docs/BasicLegalEntity.md)
 - [BasicOrganization](docs/BasicOrganization.md)
 - [BasicTeam](docs/BasicTeam.md)
 - [BasicTimesheet](docs/BasicTimesheet.md)
 - [BasicTimesheetContract](docs/BasicTimesheetContract.md)
 - [BasicTimesheetPaymentCycle](docs/BasicTimesheetPaymentCycle.md)
 - [BasicTimesheetReportedBy](docs/BasicTimesheetReportedBy.md)
 - [BasicTimesheetReviewedBy](docs/BasicTimesheetReviewedBy.md)
 - [BasicTimesheetWorksheet](docs/BasicTimesheetWorksheet.md)
 - [BenefitContributionTypeEnum](docs/BenefitContributionTypeEnum.md)
 - [BenefitQuote](docs/BenefitQuote.md)
 - [BenefitStatusEnum](docs/BenefitStatusEnum.md)
 - [BgCheckForContract](docs/BgCheckForContract.md)
 - [BgCheckForContractCreated](docs/BgCheckForContractCreated.md)
 - [BgCheckForContractToCreate](docs/BgCheckForContractToCreate.md)
 - [BgCheckForContractToCreateContainer](docs/BgCheckForContractToCreateContainer.md)
 - [BgCheckIndividualCheck](docs/BgCheckIndividualCheck.md)
 - [BgCheckOptions](docs/BgCheckOptions.md)
 - [BgCheckOptionsContainer](docs/BgCheckOptionsContainer.md)
 - [BgCheckPackage](docs/BgCheckPackage.md)
 - [BgChecksForContractContainer](docs/BgChecksForContractContainer.md)
 - [BreakdownCostsQuote](docs/BreakdownCostsQuote.md)
 - [BreakdownCostsQuoteMonthly](docs/BreakdownCostsQuoteMonthly.md)
 - [CalculateEorEmploymentCost200Response](docs/CalculateEorEmploymentCost200Response.md)
 - [CalculateEorEmploymentCost200ResponseAdditionalData](docs/CalculateEorEmploymentCost200ResponseAdditionalData.md)
 - [CalculateEorEmploymentCost200ResponseBenefitsDataInner](docs/CalculateEorEmploymentCost200ResponseBenefitsDataInner.md)
 - [CalculateEorEmploymentCost200ResponseCostsInner](docs/CalculateEorEmploymentCost200ResponseCostsInner.md)
 - [CalculateEorEmploymentCostRequest](docs/CalculateEorEmploymentCostRequest.md)
 - [CalculateEorEmploymentCostRequestData](docs/CalculateEorEmploymentCostRequestData.md)
 - [CalculateEorEmploymentCostRequestDataBenefitsInner](docs/CalculateEorEmploymentCostRequestDataBenefitsInner.md)
 - [CancelEorContract400Response](docs/CancelEorContract400Response.md)
 - [CancelEorContract404Response](docs/CancelEorContract404Response.md)
 - [CancelEorContractRequest](docs/CancelEorContractRequest.md)
 - [CancelEorContractRequestData](docs/CancelEorContractRequestData.md)
 - [CandidateStatusEnum](docs/CandidateStatusEnum.md)
 - [CandidateToCreate](docs/CandidateToCreate.md)
 - [CandidateToCreateContainer](docs/CandidateToCreateContainer.md)
 - [CandidateToPatch](docs/CandidateToPatch.md)
 - [CandidateToPatchContainer](docs/CandidateToPatchContainer.md)
 - [ClientLegalEntity](docs/ClientLegalEntity.md)
 - [ClientOfBasicContract](docs/ClientOfBasicContract.md)
 - [ClientOfContract](docs/ClientOfContract.md)
 - [CompensationDetailsOfContract](docs/CompensationDetailsOfContract.md)
 - [CompensationDetailsOfContractToCreateOngoingTimeBased](docs/CompensationDetailsOfContractToCreateOngoingTimeBased.md)
 - [CompensationDetailsOfContractToCreatePayAsYouGoTimeBased](docs/CompensationDetailsOfContractToCreatePayAsYouGoTimeBased.md)
 - [CompensationDetailsOfContractToCreateShared](docs/CompensationDetailsOfContractToCreateShared.md)
 - [Contract](docs/Contract.md)
 - [ContractAmendmentSentToClient](docs/ContractAmendmentSentToClient.md)
 - [ContractContainer](docs/ContractContainer.md)
 - [ContractContainerOngoingTimeBased](docs/ContractContainerOngoingTimeBased.md)
 - [ContractContainerPayAsYouGoTimeBased](docs/ContractContainerPayAsYouGoTimeBased.md)
 - [ContractContainerPaygMilestones](docs/ContractContainerPaygMilestones.md)
 - [ContractContainerPaygTasks](docs/ContractContainerPaygTasks.md)
 - [ContractCustomField](docs/ContractCustomField.md)
 - [ContractDetailsToAmend](docs/ContractDetailsToAmend.md)
 - [ContractDocumentContainer](docs/ContractDocumentContainer.md)
 - [ContractExternalIdToPatch](docs/ContractExternalIdToPatch.md)
 - [ContractFirstSignEnum](docs/ContractFirstSignEnum.md)
 - [ContractInvitationToCreate](docs/ContractInvitationToCreate.md)
 - [ContractInvitationToCreateContainer](docs/ContractInvitationToCreateContainer.md)
 - [ContractListContainer](docs/ContractListContainer.md)
 - [ContractSearchForm](docs/ContractSearchForm.md)
 - [ContractSearchFormWithCursor](docs/ContractSearchFormWithCursor.md)
 - [ContractSearchFormWithoutCursor](docs/ContractSearchFormWithoutCursor.md)
 - [ContractSearchFormWithoutCursorCountries](docs/ContractSearchFormWithoutCursorCountries.md)
 - [ContractSearchFormWithoutCursorCurrencies](docs/ContractSearchFormWithoutCursorCurrencies.md)
 - [ContractSearchFormWithoutCursorStatuses](docs/ContractSearchFormWithoutCursorStatuses.md)
 - [ContractSearchFormWithoutCursorTypes](docs/ContractSearchFormWithoutCursorTypes.md)
 - [ContractSignatureToCreate](docs/ContractSignatureToCreate.md)
 - [ContractSignatureToCreateContainer](docs/ContractSignatureToCreateContainer.md)
 - [ContractSignatureToCreateContractTemplateId](docs/ContractSignatureToCreateContractTemplateId.md)
 - [ContractStatusEnum](docs/ContractStatusEnum.md)
 - [ContractTemplate](docs/ContractTemplate.md)
 - [ContractTemplateListContainer](docs/ContractTemplateListContainer.md)
 - [ContractTemplateSummary](docs/ContractTemplateSummary.md)
 - [ContractTerminationResult](docs/ContractTerminationResult.md)
 - [ContractTerminationResultContainer](docs/ContractTerminationResultContainer.md)
 - [ContractToAmendDetailsContainer](docs/ContractToAmendDetailsContainer.md)
 - [ContractToCreate](docs/ContractToCreate.md)
 - [ContractToCreateContainer](docs/ContractToCreateContainer.md)
 - [ContractToCreateContainerOngoingTimeBased](docs/ContractToCreateContainerOngoingTimeBased.md)
 - [ContractToCreateContainerPayAsYouGoTimeBased](docs/ContractToCreateContainerPayAsYouGoTimeBased.md)
 - [ContractToCreateContainerPaygMilestones](docs/ContractToCreateContainerPaygMilestones.md)
 - [ContractToCreateContainerPaygTasks](docs/ContractToCreateContainerPaygTasks.md)
 - [ContractToCreateOngoingTimeBased](docs/ContractToCreateOngoingTimeBased.md)
 - [ContractToCreateOngoingTimeBasedAllOfCompensationDetails](docs/ContractToCreateOngoingTimeBasedAllOfCompensationDetails.md)
 - [ContractToCreatePayAsYouGoTimeBased](docs/ContractToCreatePayAsYouGoTimeBased.md)
 - [ContractToCreatePayAsYouGoTimeBasedAllOfCompensationDetails](docs/ContractToCreatePayAsYouGoTimeBasedAllOfCompensationDetails.md)
 - [ContractToCreatePaygMilestones](docs/ContractToCreatePaygMilestones.md)
 - [ContractToCreatePaygTasks](docs/ContractToCreatePaygTasks.md)
 - [ContractToCreateShared](docs/ContractToCreateShared.md)
 - [ContractToCreateSharedClient](docs/ContractToCreateSharedClient.md)
 - [ContractToCreateSharedClientLegalEntity](docs/ContractToCreateSharedClientLegalEntity.md)
 - [ContractToCreateSharedClientTeam](docs/ContractToCreateSharedClientTeam.md)
 - [ContractToCreateSharedJobTitle](docs/ContractToCreateSharedJobTitle.md)
 - [ContractToCreateSharedSeniority](docs/ContractToCreateSharedSeniority.md)
 - [ContractToCreateSharedSeniorityId](docs/ContractToCreateSharedSeniorityId.md)
 - [ContractToCreateSharedWorker](docs/ContractToCreateSharedWorker.md)
 - [ContractToTerminate](docs/ContractToTerminate.md)
 - [ContractToTerminateContainer](docs/ContractToTerminateContainer.md)
 - [ContractTypeEnum](docs/ContractTypeEnum.md)
 - [ContractWhoReportsEnum](docs/ContractWhoReportsEnum.md)
 - [ContractsSortByEnum](docs/ContractsSortByEnum.md)
 - [Contribution](docs/Contribution.md)
 - [CostQuote](docs/CostQuote.md)
 - [Country](docs/Country.md)
 - [CountryListContainer](docs/CountryListContainer.md)
 - [CreateAdjustment201Response](docs/CreateAdjustment201Response.md)
 - [CreateAdjustment201ResponseData](docs/CreateAdjustment201ResponseData.md)
 - [CreateAdjustment201ResponseDataFile](docs/CreateAdjustment201ResponseDataFile.md)
 - [CreateAdjustmentRequestData](docs/CreateAdjustmentRequestData.md)
 - [CreateAdjustmentRequestDataAmount](docs/CreateAdjustmentRequestDataAmount.md)
 - [CreateAdminUserResponseContainer](docs/CreateAdminUserResponseContainer.md)
 - [CreateBackgroundCheckForContracts201Response](docs/CreateBackgroundCheckForContracts201Response.md)
 - [CreateBackgroundCheckForContracts201ResponseData](docs/CreateBackgroundCheckForContracts201ResponseData.md)
 - [CreateBackgroundCheckForContractsRequest](docs/CreateBackgroundCheckForContractsRequest.md)
 - [CreateBankTransferMethod201Response](docs/CreateBankTransferMethod201Response.md)
 - [CreateBankTransferMethod201ResponseData](docs/CreateBankTransferMethod201ResponseData.md)
 - [CreateBankTransferMethodRequest](docs/CreateBankTransferMethodRequest.md)
 - [CreateBankTransferMethodRequestData](docs/CreateBankTransferMethodRequestData.md)
 - [CreateBenefitProviderIntegrationClient200Response](docs/CreateBenefitProviderIntegrationClient200Response.md)
 - [CreateCase201Response](docs/CreateCase201Response.md)
 - [CreateCase201ResponseData](docs/CreateCase201ResponseData.md)
 - [CreateCase201ResponseDataProcess](docs/CreateCase201ResponseDataProcess.md)
 - [CreateCaseRequest](docs/CreateCaseRequest.md)
 - [CreateCaseRequestData](docs/CreateCaseRequestData.md)
 - [CreateConsentToken201Response](docs/CreateConsentToken201Response.md)
 - [CreateConsentToken201ResponseData](docs/CreateConsentToken201ResponseData.md)
 - [CreateConsentToken400Response](docs/CreateConsentToken400Response.md)
 - [CreateConsentTokenRequest](docs/CreateConsentTokenRequest.md)
 - [CreateConsentTokenRequestData](docs/CreateConsentTokenRequestData.md)
 - [CreateContract201Response](docs/CreateContract201Response.md)
 - [CreateContract201ResponseData](docs/CreateContract201ResponseData.md)
 - [CreateContract201ResponseDataClient](docs/CreateContract201ResponseDataClient.md)
 - [CreateContract201ResponseDataClientLegalEntity](docs/CreateContract201ResponseDataClientLegalEntity.md)
 - [CreateContract201ResponseDataClientTeam](docs/CreateContract201ResponseDataClientTeam.md)
 - [CreateContract201ResponseDataCompensationDetails](docs/CreateContract201ResponseDataCompensationDetails.md)
 - [CreateContract201ResponseDataCustomFieldsInner](docs/CreateContract201ResponseDataCustomFieldsInner.md)
 - [CreateContract201ResponseDataEmploymentDetails](docs/CreateContract201ResponseDataEmploymentDetails.md)
 - [CreateContract201ResponseDataInvitations](docs/CreateContract201ResponseDataInvitations.md)
 - [CreateContract201ResponseDataQuote](docs/CreateContract201ResponseDataQuote.md)
 - [CreateContract201ResponseDataQuoteBenefitsInner](docs/CreateContract201ResponseDataQuoteBenefitsInner.md)
 - [CreateContract201ResponseDataQuoteBreakdownCosts](docs/CreateContract201ResponseDataQuoteBreakdownCosts.md)
 - [CreateContract201ResponseDataQuoteBreakdownCostsMonthly](docs/CreateContract201ResponseDataQuoteBreakdownCostsMonthly.md)
 - [CreateContract201ResponseDataQuoteBreakdownCostsMonthlyCostsInner](docs/CreateContract201ResponseDataQuoteBreakdownCostsMonthlyCostsInner.md)
 - [CreateContract201ResponseDataSeniority](docs/CreateContract201ResponseDataSeniority.md)
 - [CreateContract201ResponseDataSignatures](docs/CreateContract201ResponseDataSignatures.md)
 - [CreateContract201ResponseDataWorker](docs/CreateContract201ResponseDataWorker.md)
 - [CreateContract201ResponseDataWorkerLegalEntity](docs/CreateContract201ResponseDataWorkerLegalEntity.md)
 - [CreateContractPgoTak201Response](docs/CreateContractPgoTak201Response.md)
 - [CreateContractPgoTak201ResponseData](docs/CreateContractPgoTak201ResponseData.md)
 - [CreateContractPgoTak400Response](docs/CreateContractPgoTak400Response.md)
 - [CreateContractPgoTak401Response](docs/CreateContractPgoTak401Response.md)
 - [CreateContractPgoTak500Response](docs/CreateContractPgoTak500Response.md)
 - [CreateContractPgoTakRequest](docs/CreateContractPgoTakRequest.md)
 - [CreateContractPgoTakRequestData](docs/CreateContractPgoTakRequestData.md)
 - [CreateContractPgoTakRequestDataDateSubmitted](docs/CreateContractPgoTakRequestDataDateSubmitted.md)
 - [CreateContractRequest](docs/CreateContractRequest.md)
 - [CreateContractRequestData](docs/CreateContractRequestData.md)
 - [CreateDirectEmployee201Response](docs/CreateDirectEmployee201Response.md)
 - [CreateDirectEmployee201ResponseData](docs/CreateDirectEmployee201ResponseData.md)
 - [CreateDirectEmployee201ResponseDataCompensationDetails](docs/CreateDirectEmployee201ResponseDataCompensationDetails.md)
 - [CreateDirectEmployee201ResponseDataEmployee](docs/CreateDirectEmployee201ResponseDataEmployee.md)
 - [CreateDirectEmployee201ResponseDataEmployment](docs/CreateDirectEmployee201ResponseDataEmployment.md)
 - [CreateDirectEmployeeRequest](docs/CreateDirectEmployeeRequest.md)
 - [CreateDirectEmployeeRequestData](docs/CreateDirectEmployeeRequestData.md)
 - [CreateDirectEmployeeRequestDataClient](docs/CreateDirectEmployeeRequestDataClient.md)
 - [CreateDirectEmployeeRequestDataClientDepartment](docs/CreateDirectEmployeeRequestDataClientDepartment.md)
 - [CreateDirectEmployeeRequestDataClientLegalEntity](docs/CreateDirectEmployeeRequestDataClientLegalEntity.md)
 - [CreateDirectEmployeeRequestDataClientTeam](docs/CreateDirectEmployeeRequestDataClientTeam.md)
 - [CreateDirectEmployeeRequestDataCompensationDetails](docs/CreateDirectEmployeeRequestDataCompensationDetails.md)
 - [CreateDirectEmployeeRequestDataEmployee](docs/CreateDirectEmployeeRequestDataEmployee.md)
 - [CreateDirectEmployeeRequestDataEmployment](docs/CreateDirectEmployeeRequestDataEmployment.md)
 - [CreateDirectEmployeeRequestDataEmploymentOneOf](docs/CreateDirectEmployeeRequestDataEmploymentOneOf.md)
 - [CreateDirectEmployeeRequestDataEmploymentOneOf1](docs/CreateDirectEmployeeRequestDataEmploymentOneOf1.md)
 - [CreateEorContract200Response](docs/CreateEorContract200Response.md)
 - [CreateEorContract200ResponseData](docs/CreateEorContract200ResponseData.md)
 - [CreateEorContractRequest](docs/CreateEorContractRequest.md)
 - [CreateEorContractRequestData](docs/CreateEorContractRequestData.md)
 - [CreateEorContractRequestDataBenefitsInner](docs/CreateEorContractRequestDataBenefitsInner.md)
 - [CreateEorContractRequestDataClient](docs/CreateEorContractRequestDataClient.md)
 - [CreateEorContractRequestDataClientLegalEntity](docs/CreateEorContractRequestDataClientLegalEntity.md)
 - [CreateEorContractRequestDataClientLegalEntityId](docs/CreateEorContractRequestDataClientLegalEntityId.md)
 - [CreateEorContractRequestDataClientTeam](docs/CreateEorContractRequestDataClientTeam.md)
 - [CreateEorContractRequestDataClientTeamId](docs/CreateEorContractRequestDataClientTeamId.md)
 - [CreateEorContractRequestDataCompensationDetails](docs/CreateEorContractRequestDataCompensationDetails.md)
 - [CreateEorContractRequestDataEmployee](docs/CreateEorContractRequestDataEmployee.md)
 - [CreateEorContractRequestDataEmployeeAddress](docs/CreateEorContractRequestDataEmployeeAddress.md)
 - [CreateEorContractRequestDataEmployment](docs/CreateEorContractRequestDataEmployment.md)
 - [CreateEorContractRequestDataPension](docs/CreateEorContractRequestDataPension.md)
 - [CreateEorContractRequestDataQuoteAdditionalFields](docs/CreateEorContractRequestDataQuoteAdditionalFields.md)
 - [CreateEorContractRequestDataSeniority](docs/CreateEorContractRequestDataSeniority.md)
 - [CreateEorContractRequestDataSeniorityId](docs/CreateEorContractRequestDataSeniorityId.md)
 - [CreateGPContract201Response](docs/CreateGPContract201Response.md)
 - [CreateGPContract201ResponseData](docs/CreateGPContract201ResponseData.md)
 - [CreateGPContract201ResponseDataClient](docs/CreateGPContract201ResponseDataClient.md)
 - [CreateGPContract201ResponseDataClientLegalEntity](docs/CreateGPContract201ResponseDataClientLegalEntity.md)
 - [CreateGPContract201ResponseDataCompensationDetails](docs/CreateGPContract201ResponseDataCompensationDetails.md)
 - [CreateGPContract201ResponseDataEmployee](docs/CreateGPContract201ResponseDataEmployee.md)
 - [CreateGPContract201ResponseDataEmployment](docs/CreateGPContract201ResponseDataEmployment.md)
 - [CreateGPContract201ResponseDataEmploymentHolidays](docs/CreateGPContract201ResponseDataEmploymentHolidays.md)
 - [CreateGPContractRequest](docs/CreateGPContractRequest.md)
 - [CreateGPContractRequestData](docs/CreateGPContractRequestData.md)
 - [CreateGPContractRequestDataClient](docs/CreateGPContractRequestDataClient.md)
 - [CreateGPContractRequestDataClientLegalEntity](docs/CreateGPContractRequestDataClientLegalEntity.md)
 - [CreateGPContractRequestDataClientTeam](docs/CreateGPContractRequestDataClientTeam.md)
 - [CreateGPContractRequestDataCompensationDetails](docs/CreateGPContractRequestDataCompensationDetails.md)
 - [CreateGPContractRequestDataEmployee](docs/CreateGPContractRequestDataEmployee.md)
 - [CreateGPContractRequestDataEmployeeAddress](docs/CreateGPContractRequestDataEmployeeAddress.md)
 - [CreateGPContractRequestDataEmployment](docs/CreateGPContractRequestDataEmployment.md)
 - [CreateGPContractRequestDataEmploymentHolidays](docs/CreateGPContractRequestDataEmploymentHolidays.md)
 - [CreateGroup200Response](docs/CreateGroup200Response.md)
 - [CreateGroup200ResponseData](docs/CreateGroup200ResponseData.md)
 - [CreateGroupRequest](docs/CreateGroupRequest.md)
 - [CreateGroupRequestData](docs/CreateGroupRequestData.md)
 - [CreateInvoiceAdjustment201Response](docs/CreateInvoiceAdjustment201Response.md)
 - [CreateInvoiceAdjustment201ResponseData](docs/CreateInvoiceAdjustment201ResponseData.md)
 - [CreateInvoiceAdjustmentRequest](docs/CreateInvoiceAdjustmentRequest.md)
 - [CreateLegalEntity200Response](docs/CreateLegalEntity200Response.md)
 - [CreateLegalEntity200ResponseData](docs/CreateLegalEntity200ResponseData.md)
 - [CreateLegalEntity200ResponseDataAddress](docs/CreateLegalEntity200ResponseDataAddress.md)
 - [CreateLegalEntity403Response](docs/CreateLegalEntity403Response.md)
 - [CreateLegalEntityRequest](docs/CreateLegalEntityRequest.md)
 - [CreateLegalEntityRequestData](docs/CreateLegalEntityRequestData.md)
 - [CreateLegalEntityRequestDataAddress](docs/CreateLegalEntityRequestDataAddress.md)
 - [CreateLegalEntityRequestDataCompanyIdentifiers](docs/CreateLegalEntityRequestDataCompanyIdentifiers.md)
 - [CreateManager201Response](docs/CreateManager201Response.md)
 - [CreateManager201ResponseData](docs/CreateManager201ResponseData.md)
 - [CreateManager400Response](docs/CreateManager400Response.md)
 - [CreateManager409Response](docs/CreateManager409Response.md)
 - [CreateManagerRequest](docs/CreateManagerRequest.md)
 - [CreateManualVerificationScreening201Response](docs/CreateManualVerificationScreening201Response.md)
 - [CreateManualVerificationScreening201ResponseData](docs/CreateManualVerificationScreening201ResponseData.md)
 - [CreateMilestone201Response](docs/CreateMilestone201Response.md)
 - [CreateMilestone201ResponseData](docs/CreateMilestone201ResponseData.md)
 - [CreateMilestone400Response](docs/CreateMilestone400Response.md)
 - [CreateMilestone404Response](docs/CreateMilestone404Response.md)
 - [CreateMilestoneRequest](docs/CreateMilestoneRequest.md)
 - [CreateMilestoneRequestAmount](docs/CreateMilestoneRequestAmount.md)
 - [CreateOffCyclePayment201Response](docs/CreateOffCyclePayment201Response.md)
 - [CreateOffCyclePayment201ResponseData](docs/CreateOffCyclePayment201ResponseData.md)
 - [CreateOffCyclePaymentRequest](docs/CreateOffCyclePaymentRequest.md)
 - [CreateOffCyclePaymentRequestData](docs/CreateOffCyclePaymentRequestData.md)
 - [CreateOrUpdateParentRelationBetweenProfilesRequest](docs/CreateOrUpdateParentRelationBetweenProfilesRequest.md)
 - [CreateOrUpdateParentRelationBetweenProfilesRequestData](docs/CreateOrUpdateParentRelationBetweenProfilesRequestData.md)
 - [CreateOrUpdateParentRelationBetweenProfilesRequestDataEditReason](docs/CreateOrUpdateParentRelationBetweenProfilesRequestDataEditReason.md)
 - [CreateOrgStructure200Response](docs/CreateOrgStructure200Response.md)
 - [CreateOrgStructure200ResponseData](docs/CreateOrgStructure200ResponseData.md)
 - [CreateOrgStructureRequest](docs/CreateOrgStructureRequest.md)
 - [CreateOrgStructureRequestData](docs/CreateOrgStructureRequestData.md)
 - [CreateOrgStructureRequestDataTeamsInner](docs/CreateOrgStructureRequestDataTeamsInner.md)
 - [CreateOrganizationRole200Response](docs/CreateOrganizationRole200Response.md)
 - [CreateOrganizationRoleRequest](docs/CreateOrganizationRoleRequest.md)
 - [CreateOrganizationRoleRequestData](docs/CreateOrganizationRoleRequestData.md)
 - [CreatePeopleTimeoff](docs/CreatePeopleTimeoff.md)
 - [CreatePublicToken](docs/CreatePublicToken.md)
 - [CreatePublicTokenContainer](docs/CreatePublicTokenContainer.md)
 - [CreateShiftRate201Response](docs/CreateShiftRate201Response.md)
 - [CreateShiftRate201ResponseData](docs/CreateShiftRate201ResponseData.md)
 - [CreateShiftRateRequest](docs/CreateShiftRateRequest.md)
 - [CreateShiftRateRequestBodyContainer](docs/CreateShiftRateRequestBodyContainer.md)
 - [CreateShiftRateRequestBodyContainerData](docs/CreateShiftRateRequestBodyContainerData.md)
 - [CreateShiftRateRequestData](docs/CreateShiftRateRequestData.md)
 - [CreateShiftRequestBodyContainer](docs/CreateShiftRequestBodyContainer.md)
 - [CreateShiftRequestBodyContainerData](docs/CreateShiftRequestBodyContainerData.md)
 - [CreateShiftSchema](docs/CreateShiftSchema.md)
 - [CreateShifts201Response](docs/CreateShifts201Response.md)
 - [CreateShifts201ResponseDataInner](docs/CreateShifts201ResponseDataInner.md)
 - [CreateShifts201ResponseDataInnerMeta](docs/CreateShifts201ResponseDataInnerMeta.md)
 - [CreateShifts201ResponseDataInnerMetaBreaksInner](docs/CreateShifts201ResponseDataInnerMetaBreaksInner.md)
 - [CreateShifts201ResponseDataInnerMetaBreaksInnerEnd](docs/CreateShifts201ResponseDataInnerMetaBreaksInnerEnd.md)
 - [CreateShifts201ResponseDataInnerMetaBreaksInnerStart](docs/CreateShifts201ResponseDataInnerMetaBreaksInnerStart.md)
 - [CreateShifts201ResponseDataInnerMetaEnd](docs/CreateShifts201ResponseDataInnerMetaEnd.md)
 - [CreateShifts201ResponseDataInnerMetaStart](docs/CreateShifts201ResponseDataInnerMetaStart.md)
 - [CreateShifts201ResponseDataInnerSummary](docs/CreateShifts201ResponseDataInnerSummary.md)
 - [CreateShiftsRequest](docs/CreateShiftsRequest.md)
 - [CreateShiftsRequestData](docs/CreateShiftsRequestData.md)
 - [CreateShiftsRequestDataShiftsInner](docs/CreateShiftsRequestDataShiftsInner.md)
 - [CreateShiftsRequestDataShiftsInnerMeta](docs/CreateShiftsRequestDataShiftsInnerMeta.md)
 - [CreateShiftsRequestDataShiftsInnerMetaBreaksInner](docs/CreateShiftsRequestDataShiftsInnerMetaBreaksInner.md)
 - [CreateShiftsRequestDataShiftsInnerMetaBreaksInnerEnd](docs/CreateShiftsRequestDataShiftsInnerMetaBreaksInnerEnd.md)
 - [CreateShiftsRequestDataShiftsInnerMetaBreaksInnerStart](docs/CreateShiftsRequestDataShiftsInnerMetaBreaksInnerStart.md)
 - [CreateShiftsRequestDataShiftsInnerMetaEnd](docs/CreateShiftsRequestDataShiftsInnerMetaEnd.md)
 - [CreateShiftsRequestDataShiftsInnerMetaStart](docs/CreateShiftsRequestDataShiftsInnerMetaStart.md)
 - [CreateShiftsRequestDataShiftsInnerSummary](docs/CreateShiftsRequestDataShiftsInnerSummary.md)
 - [CreateTaskManyReview201Response](docs/CreateTaskManyReview201Response.md)
 - [CreateTaskManyReview201ResponseDataInner](docs/CreateTaskManyReview201ResponseDataInner.md)
 - [CreateTaskManyReview201ResponseDataInnerAttachment](docs/CreateTaskManyReview201ResponseDataInnerAttachment.md)
 - [CreateTaskManyReview400Response](docs/CreateTaskManyReview400Response.md)
 - [CreateTaskManyReview404Response](docs/CreateTaskManyReview404Response.md)
 - [CreateTaskManyReview500Response](docs/CreateTaskManyReview500Response.md)
 - [CreateTaskManyReviewRequest](docs/CreateTaskManyReviewRequest.md)
 - [CreateTaskManyReviewRequestData](docs/CreateTaskManyReviewRequestData.md)
 - [CreateTaskReviewById201Response](docs/CreateTaskReviewById201Response.md)
 - [CreateTaskReviewById201ResponseDataInner](docs/CreateTaskReviewById201ResponseDataInner.md)
 - [CreateTaskReviewById404Response](docs/CreateTaskReviewById404Response.md)
 - [CreateTaskReviewById500Response](docs/CreateTaskReviewById500Response.md)
 - [CreateTaskReviewByIdRequest](docs/CreateTaskReviewByIdRequest.md)
 - [CreateTaskReviewByIdRequestData](docs/CreateTaskReviewByIdRequestData.md)
 - [CreateTimeOff201Response](docs/CreateTimeOff201Response.md)
 - [CreateTimeOff201ResponseTimeOffsInner](docs/CreateTimeOff201ResponseTimeOffsInner.md)
 - [CreateTimeOff201ResponseTimeOffsInnerRecipientProfile](docs/CreateTimeOff201ResponseTimeOffsInnerRecipientProfile.md)
 - [CreateTimeOff201ResponseTimeOffsInnerRequesterProfile](docs/CreateTimeOff201ResponseTimeOffsInnerRequesterProfile.md)
 - [CreateTimeOff201ResponseTimeOffsInnerTimeOffDailiesInner](docs/CreateTimeOff201ResponseTimeOffsInnerTimeOffDailiesInner.md)
 - [CreateTimeOffRequest](docs/CreateTimeOffRequest.md)
 - [CreateTimeOffRequestBody](docs/CreateTimeOffRequestBody.md)
 - [CreateTimeOffRequestBodyData](docs/CreateTimeOffRequestBodyData.md)
 - [CreateTimeOffRequestData](docs/CreateTimeOffRequestData.md)
 - [CreateTimeOffRequestDataAttachmentsInner](docs/CreateTimeOffRequestDataAttachmentsInner.md)
 - [CreateTimeOffRequestDataDatesInner](docs/CreateTimeOffRequestDataDatesInner.md)
 - [CreateTimeoff](docs/CreateTimeoff.md)
 - [CreateTimeoffContainer](docs/CreateTimeoffContainer.md)
 - [CreateTimesheet201Response](docs/CreateTimesheet201Response.md)
 - [CreateTimesheet201ResponseData](docs/CreateTimesheet201ResponseData.md)
 - [CreateTimesheetRequest](docs/CreateTimesheetRequest.md)
 - [CreateTimesheetRequestData](docs/CreateTimesheetRequestData.md)
 - [CreateTimesheetReviewRequest](docs/CreateTimesheetReviewRequest.md)
 - [CreateTimesheetReviewRequestData](docs/CreateTimesheetReviewRequestData.md)
 - [CreateVeriffSession201Response](docs/CreateVeriffSession201Response.md)
 - [CreateVeriffSession201ResponseData](docs/CreateVeriffSession201ResponseData.md)
 - [CreateVeriffSessionRequest](docs/CreateVeriffSessionRequest.md)
 - [CreateVeriffSessionRequestData](docs/CreateVeriffSessionRequestData.md)
 - [CreateVeriffSessionRequestDataUserInput](docs/CreateVeriffSessionRequestDataUserInput.md)
 - [CreateWebhookRequest](docs/CreateWebhookRequest.md)
 - [CreateWorker201Response](docs/CreateWorker201Response.md)
 - [CreateWorker201ResponseData](docs/CreateWorker201ResponseData.md)
 - [CreateWorkerRelationContainer](docs/CreateWorkerRelationContainer.md)
 - [CreateWorkerRelationContainerData](docs/CreateWorkerRelationContainerData.md)
 - [CreateWorkerRelationExternalIdContainer](docs/CreateWorkerRelationExternalIdContainer.md)
 - [CreateWorkerRelationExternalIdContainerData](docs/CreateWorkerRelationExternalIdContainerData.md)
 - [CreateWorkerRelationExternalIdContainerDataChildHrisProfileIdsInner](docs/CreateWorkerRelationExternalIdContainerDataChildHrisProfileIdsInner.md)
 - [CreateWorkerRelationExternalIdRequest](docs/CreateWorkerRelationExternalIdRequest.md)
 - [CreateWorkerRelationExternalIdRequestData](docs/CreateWorkerRelationExternalIdRequestData.md)
 - [CreateWorkerRelationExternalIdRequestDataChildHrisProfileIdsInner](docs/CreateWorkerRelationExternalIdRequestDataChildHrisProfileIdsInner.md)
 - [CreateWorkerRelationRequest](docs/CreateWorkerRelationRequest.md)
 - [CreateWorkerRelationRequestData](docs/CreateWorkerRelationRequestData.md)
 - [CreateWorkerRelationType201Response](docs/CreateWorkerRelationType201Response.md)
 - [CreateWorkerRelationType201ResponseData](docs/CreateWorkerRelationType201ResponseData.md)
 - [CreateWorkerRelationTypeContainer](docs/CreateWorkerRelationTypeContainer.md)
 - [CreateWorkerRelationTypeContainerData](docs/CreateWorkerRelationTypeContainerData.md)
 - [CreateWorkerRelationTypeRequest](docs/CreateWorkerRelationTypeRequest.md)
 - [CreateWorkerRelationTypeRequestData](docs/CreateWorkerRelationTypeRequestData.md)
 - [CreateWorkerRelationTypeResponseContainer](docs/CreateWorkerRelationTypeResponseContainer.md)
 - [CreateWorkerRelationTypeResponseContainerData](docs/CreateWorkerRelationTypeResponseContainerData.md)
 - [CreateWorkerRequest](docs/CreateWorkerRequest.md)
 - [CreateWorkerRequestData](docs/CreateWorkerRequestData.md)
 - [CreateWorkerRequestDataCompany](docs/CreateWorkerRequestDataCompany.md)
 - [CreateWorkerRequestDataCompanyPersonal](docs/CreateWorkerRequestDataCompanyPersonal.md)
 - [CreatedExerciseEquityContainer](docs/CreatedExerciseEquityContainer.md)
 - [CreatedHrisDirectEmployeeContainer](docs/CreatedHrisDirectEmployeeContainer.md)
 - [CreatedHrisDirectEmployeeContainerData](docs/CreatedHrisDirectEmployeeContainerData.md)
 - [CreatedHrisDirectEmployeeContainerDataCompensationDetails](docs/CreatedHrisDirectEmployeeContainerDataCompensationDetails.md)
 - [CreatedHrisDirectEmployeeContainerDataEmployee](docs/CreatedHrisDirectEmployeeContainerDataEmployee.md)
 - [CreatedHrisDirectEmployeeContainerDataEmployment](docs/CreatedHrisDirectEmployeeContainerDataEmployment.md)
 - [CreatedOrgStructuresContainer](docs/CreatedOrgStructuresContainer.md)
 - [CreatedOrgStructuresContainerData](docs/CreatedOrgStructuresContainerData.md)
 - [CreatedRoleContainer](docs/CreatedRoleContainer.md)
 - [Currency](docs/Currency.md)
 - [CurrencyListContainer](docs/CurrencyListContainer.md)
 - [CustomFieldItemContainer](docs/CustomFieldItemContainer.md)
 - [CustomFieldToUpdateContainer](docs/CustomFieldToUpdateContainer.md)
 - [CustomFieldToUpdateContainerData](docs/CustomFieldToUpdateContainerData.md)
 - [CustomFieldToUpdateContainerDataOneOf](docs/CustomFieldToUpdateContainerDataOneOf.md)
 - [CustomFieldToUpdateContainerDataOneOf1](docs/CustomFieldToUpdateContainerDataOneOf1.md)
 - [CustomFieldValue](docs/CustomFieldValue.md)
 - [CustomFieldValueData](docs/CustomFieldValueData.md)
 - [CustomFieldValuesContainer](docs/CustomFieldValuesContainer.md)
 - [CustomFieldValuesContainerDataInner](docs/CustomFieldValuesContainerDataInner.md)
 - [CustomFieldValuesContainerDataInnerData](docs/CustomFieldValuesContainerDataInnerData.md)
 - [CustomFieldValuesContainerDataInnerDataOneOf](docs/CustomFieldValuesContainerDataInnerDataOneOf.md)
 - [CustomFieldValuesContainerDataInnerDataOneOf1](docs/CustomFieldValuesContainerDataInnerDataOneOf1.md)
 - [CustomFieldsListContainer](docs/CustomFieldsListContainer.md)
 - [CustomFieldsObject](docs/CustomFieldsObject.md)
 - [CustomFieldsObjectSettings](docs/CustomFieldsObjectSettings.md)
 - [CustomFieldsObjectSettingsAccess](docs/CustomFieldsObjectSettingsAccess.md)
 - [CustomFieldsObjectType](docs/CustomFieldsObjectType.md)
 - [CustomFieldsObjectTypeOneOf](docs/CustomFieldsObjectTypeOneOf.md)
 - [CustomFieldsObjectTypeOneOf1](docs/CustomFieldsObjectTypeOneOf1.md)
 - [CustomFieldsObjectTypeOneOf2](docs/CustomFieldsObjectTypeOneOf2.md)
 - [DaasSignEmployeeContractRequest](docs/DaasSignEmployeeContractRequest.md)
 - [DaasSignEmployeeContractRequestData](docs/DaasSignEmployeeContractRequestData.md)
 - [DeelInvoice](docs/DeelInvoice.md)
 - [DeelInvoiceListContainer](docs/DeelInvoiceListContainer.md)
 - [DelayEorEmployeeOnboarding200Response](docs/DelayEorEmployeeOnboarding200Response.md)
 - [DelayEorEmployeeOnboarding400Response](docs/DelayEorEmployeeOnboarding400Response.md)
 - [DelayEorEmployeeOnboardingRequest](docs/DelayEorEmployeeOnboardingRequest.md)
 - [DelayEorEmployeeOnboardingRequestData](docs/DelayEorEmployeeOnboardingRequestData.md)
 - [Delete401kEnrollmentsDefinitionRequest](docs/Delete401kEnrollmentsDefinitionRequest.md)
 - [DeleteAdjustment200Response](docs/DeleteAdjustment200Response.md)
 - [DeleteAdjustment200ResponseData](docs/DeleteAdjustment200ResponseData.md)
 - [DeleteContractTaskById200Response](docs/DeleteContractTaskById200Response.md)
 - [DeleteContractTaskById200ResponseData](docs/DeleteContractTaskById200ResponseData.md)
 - [DeleteGroup200Response](docs/DeleteGroup200Response.md)
 - [DeleteGroup200ResponseData](docs/DeleteGroup200ResponseData.md)
 - [DeleteGroup400Response](docs/DeleteGroup400Response.md)
 - [DeleteGroup404Response](docs/DeleteGroup404Response.md)
 - [DeleteGroup404ResponseError](docs/DeleteGroup404ResponseError.md)
 - [DeleteLegalEntity200Response](docs/DeleteLegalEntity200Response.md)
 - [DeleteLegalEntity400Response](docs/DeleteLegalEntity400Response.md)
 - [DeleteLegalEntity403Response](docs/DeleteLegalEntity403Response.md)
 - [DeleteMilestoneById200Response](docs/DeleteMilestoneById200Response.md)
 - [DeleteMilestoneById200ResponseData](docs/DeleteMilestoneById200ResponseData.md)
 - [DeleteMilestoneById400Response](docs/DeleteMilestoneById400Response.md)
 - [DeleteMilestoneById404Response](docs/DeleteMilestoneById404Response.md)
 - [DeleteMilestoneById500Response](docs/DeleteMilestoneById500Response.md)
 - [Departments](docs/Departments.md)
 - [DepartmentsContainer](docs/DepartmentsContainer.md)
 - [DownloadWorkerDocumentsByIdContainer](docs/DownloadWorkerDocumentsByIdContainer.md)
 - [DynamicRequirements200Response](docs/DynamicRequirements200Response.md)
 - [DynamicRequirements200ResponseData](docs/DynamicRequirements200ResponseData.md)
 - [DynamicRequirements200ResponseDataStepsInner](docs/DynamicRequirements200ResponseDataStepsInner.md)
 - [DynamicRequirements200ResponseDataStepsInnerCategoriesInner](docs/DynamicRequirements200ResponseDataStepsInnerCategoriesInner.md)
 - [DynamicRequirements200ResponseDataStepsInnerCategoriesInnerAlert](docs/DynamicRequirements200ResponseDataStepsInnerCategoriesInnerAlert.md)
 - [DynamicRequirements200ResponseDataStepsInnerCategoriesInnerFieldsInner](docs/DynamicRequirements200ResponseDataStepsInnerCategoriesInnerFieldsInner.md)
 - [DynamicRequirementsRequest](docs/DynamicRequirementsRequest.md)
 - [DynamicRequirementsRequestData](docs/DynamicRequirementsRequestData.md)
 - [DynamicRequirementsRequestDataCurrentState](docs/DynamicRequirementsRequestDataCurrentState.md)
 - [EORContractBenefitsContainer](docs/EORContractBenefitsContainer.md)
 - [EORContractBenefitsInner](docs/EORContractBenefitsInner.md)
 - [EORContractBenefitsInnerEnrollmentDetails](docs/EORContractBenefitsInnerEnrollmentDetails.md)
 - [EORContractBenefitsInnerEnrollmentDetailsCurrent](docs/EORContractBenefitsInnerEnrollmentDetailsCurrent.md)
 - [EORContractBenefitsInnerEnrollmentDetailsStandard](docs/EORContractBenefitsInnerEnrollmentDetailsStandard.md)
 - [EORContractBenefitsInnerPlan](docs/EORContractBenefitsInnerPlan.md)
 - [EORContractBenefitsInnerProvider](docs/EORContractBenefitsInnerProvider.md)
 - [EORPayslipDownloadUrlContainer](docs/EORPayslipDownloadUrlContainer.md)
 - [EORPayslipsListContainer](docs/EORPayslipsListContainer.md)
 - [EditGroup200Response](docs/EditGroup200Response.md)
 - [EditGroup200ResponseData](docs/EditGroup200ResponseData.md)
 - [EditGroupRequest](docs/EditGroupRequest.md)
 - [EditGroupRequestData](docs/EditGroupRequestData.md)
 - [EditLegalEntity200Response](docs/EditLegalEntity200Response.md)
 - [EditLegalEntity200ResponseData](docs/EditLegalEntity200ResponseData.md)
 - [EditLegalEntity200ResponseDataCompanyIdentifiers](docs/EditLegalEntity200ResponseDataCompanyIdentifiers.md)
 - [EditLegalEntity403Response](docs/EditLegalEntity403Response.md)
 - [EditLegalEntityRequest](docs/EditLegalEntityRequest.md)
 - [EditLegalEntityRequestAddress](docs/EditLegalEntityRequestAddress.md)
 - [EditLegalEntityRequestCompanyIdentifiers](docs/EditLegalEntityRequestCompanyIdentifiers.md)
 - [Email](docs/Email.md)
 - [Employee](docs/Employee.md)
 - [EmployeeAgreementDownloadContainer](docs/EmployeeAgreementDownloadContainer.md)
 - [EmployeeAgreementDownloadObject](docs/EmployeeAgreementDownloadObject.md)
 - [EmployeeContractSignatureToCreate](docs/EmployeeContractSignatureToCreate.md)
 - [EmployeeContractSignatureToCreateContainer](docs/EmployeeContractSignatureToCreateContainer.md)
 - [EmployeeDepartment](docs/EmployeeDepartment.md)
 - [EmployeeDirectManager](docs/EmployeeDirectManager.md)
 - [EmployeePayslipsList](docs/EmployeePayslipsList.md)
 - [EmployeePayslipsListContainer](docs/EmployeePayslipsListContainer.md)
 - [EmployeeTaxDocumentsList](docs/EmployeeTaxDocumentsList.md)
 - [EmployeeTaxDocumentsListContainer](docs/EmployeeTaxDocumentsListContainer.md)
 - [EmployeeTimeoffsContainer](docs/EmployeeTimeoffsContainer.md)
 - [EmployeeTimeoffsCreationContainer](docs/EmployeeTimeoffsCreationContainer.md)
 - [EmployeeTimeoffsEntitlementsContainer](docs/EmployeeTimeoffsEntitlementsContainer.md)
 - [EmployeeTimeoffsEntitlementsItem](docs/EmployeeTimeoffsEntitlementsItem.md)
 - [EmployeeTimeoffsItem](docs/EmployeeTimeoffsItem.md)
 - [EmployeeTimeoffsItemAttachmentsInner](docs/EmployeeTimeoffsItemAttachmentsInner.md)
 - [EmployeeTimeoffsItemRequester](docs/EmployeeTimeoffsItemRequester.md)
 - [EmployeeTimeoffsItemResponse](docs/EmployeeTimeoffsItemResponse.md)
 - [EmployeeTimeoffsItemResponseAttachmentsInner](docs/EmployeeTimeoffsItemResponseAttachmentsInner.md)
 - [EmployeeTimeoffsItemReviewer](docs/EmployeeTimeoffsItemReviewer.md)
 - [EmployeeTimeoffsPoliciesContainer](docs/EmployeeTimeoffsPoliciesContainer.md)
 - [EmployeeTimeoffsPoliciesItem](docs/EmployeeTimeoffsPoliciesItem.md)
 - [EmployeeTimeoffsPoliciesItemEntitlement](docs/EmployeeTimeoffsPoliciesItemEntitlement.md)
 - [Employment](docs/Employment.md)
 - [EmploymentDetail](docs/EmploymentDetail.md)
 - [EmploymentDetailTeam](docs/EmploymentDetailTeam.md)
 - [EmploymentDetailsOfContract](docs/EmploymentDetailsOfContract.md)
 - [Entitlements](docs/Entitlements.md)
 - [EntitlementsFutureEventsInner](docs/EntitlementsFutureEventsInner.md)
 - [EntitlementsPolicy](docs/EntitlementsPolicy.md)
 - [EntitlementsPolicyTimeOffTypesInner](docs/EntitlementsPolicyTimeOffTypesInner.md)
 - [EntitlementsRolloversInner](docs/EntitlementsRolloversInner.md)
 - [EorClientTimeoffRequests](docs/EorClientTimeoffRequests.md)
 - [EorClientTimeoffs](docs/EorClientTimeoffs.md)
 - [EorClientTimeoffsContainer](docs/EorClientTimeoffsContainer.md)
 - [EorContractCreated](docs/EorContractCreated.md)
 - [EorContractCreatedCompensationDetails](docs/EorContractCreatedCompensationDetails.md)
 - [EorContractCreatedContainer](docs/EorContractCreatedContainer.md)
 - [EorContractCreatedEmployee](docs/EorContractCreatedEmployee.md)
 - [EorContractCreatedEmployment](docs/EorContractCreatedEmployment.md)
 - [EorContractCreatedHealthPlan](docs/EorContractCreatedHealthPlan.md)
 - [EorContractToCreate](docs/EorContractToCreate.md)
 - [EorContractToCreateClient](docs/EorContractToCreateClient.md)
 - [EorContractToCreateClientTeam](docs/EorContractToCreateClientTeam.md)
 - [EorContractToCreateCompensationDetails](docs/EorContractToCreateCompensationDetails.md)
 - [EorContractToCreateContainer](docs/EorContractToCreateContainer.md)
 - [EorContractToCreateEmployee](docs/EorContractToCreateEmployee.md)
 - [EorContractToCreateEmployeeAddress](docs/EorContractToCreateEmployeeAddress.md)
 - [EorContractToCreateEmployment](docs/EorContractToCreateEmployment.md)
 - [EorContractToCreateQuoteAdditionalFields](docs/EorContractToCreateQuoteAdditionalFields.md)
 - [EorContractToCreateSeniority](docs/EorContractToCreateSeniority.md)
 - [EorCountryValidations](docs/EorCountryValidations.md)
 - [EorCountryValidationsContainer](docs/EorCountryValidationsContainer.md)
 - [EorCountryValidationsDefiniteContract](docs/EorCountryValidationsDefiniteContract.md)
 - [EorCountryValidationsHealthInsurance](docs/EorCountryValidationsHealthInsurance.md)
 - [EorCountryValidationsHoliday](docs/EorCountryValidationsHoliday.md)
 - [EorCountryValidationsPartTimeHoliday](docs/EorCountryValidationsPartTimeHoliday.md)
 - [EorCountryValidationsPartTimeProbation](docs/EorCountryValidationsPartTimeProbation.md)
 - [EorCountryValidationsPension](docs/EorCountryValidationsPension.md)
 - [EorCountryValidationsProbation](docs/EorCountryValidationsProbation.md)
 - [EorCountryValidationsSalary](docs/EorCountryValidationsSalary.md)
 - [EorCountryValidationsSickDays](docs/EorCountryValidationsSickDays.md)
 - [EorCountryValidationsWorkSchedule](docs/EorCountryValidationsWorkSchedule.md)
 - [EorCountryValidationsWorkScheduleDays](docs/EorCountryValidationsWorkScheduleDays.md)
 - [EorCountryValidationsWorkScheduleHours](docs/EorCountryValidationsWorkScheduleHours.md)
 - [EorEmployeeCostCalculationRequestBody](docs/EorEmployeeCostCalculationRequestBody.md)
 - [EorEmployeeCostCalculationRequestBodyBenefitsInner](docs/EorEmployeeCostCalculationRequestBodyBenefitsInner.md)
 - [EorEmployeeCostCalculationRequestBodyContainer](docs/EorEmployeeCostCalculationRequestBodyContainer.md)
 - [EorEmployeeCostCalculationResponse](docs/EorEmployeeCostCalculationResponse.md)
 - [EorEmployeeCostCalculationResponseAdditionalData](docs/EorEmployeeCostCalculationResponseAdditionalData.md)
 - [EorEmployeeCostCalculationResponseBenefitsDataInner](docs/EorEmployeeCostCalculationResponseBenefitsDataInner.md)
 - [EorEmployeeCostCalculationResponseCostsInner](docs/EorEmployeeCostCalculationResponseCostsInner.md)
 - [EorEntitlementListItem](docs/EorEntitlementListItem.md)
 - [EorEntitlements](docs/EorEntitlements.md)
 - [EorEntitlementsContainer](docs/EorEntitlementsContainer.md)
 - [EorField](docs/EorField.md)
 - [EorHolidaysRolloverType](docs/EorHolidaysRolloverType.md)
 - [EorQuoteBase](docs/EorQuoteBase.md)
 - [EorQuotePayload](docs/EorQuotePayload.md)
 - [EorResignationRequestRequest](docs/EorResignationRequestRequest.md)
 - [EorResignationRequestRequestUsedTimeOff](docs/EorResignationRequestRequestUsedTimeOff.md)
 - [EorTerminationRequest200Response](docs/EorTerminationRequest200Response.md)
 - [EorTerminationRequest200ResponseRequestData](docs/EorTerminationRequest200ResponseRequestData.md)
 - [EorTerminationRequest200ResponseRequestDataTerminationImpact](docs/EorTerminationRequest200ResponseRequestDataTerminationImpact.md)
 - [EorTerminationRequestRequest](docs/EorTerminationRequestRequest.md)
 - [EorTerminationRequestRequestAdditionalCountryDataInner](docs/EorTerminationRequestRequestAdditionalCountryDataInner.md)
 - [EorTerminationRequestRequestAttachmentsInner](docs/EorTerminationRequestRequestAttachmentsInner.md)
 - [EorTerminationRequestRequestUsedTimeOff](docs/EorTerminationRequestRequestUsedTimeOff.md)
 - [EorTerminationRequestRequestUsedTimeOffTimeOffsInner](docs/EorTerminationRequestRequestUsedTimeOffTimeOffsInner.md)
 - [EorTerminationRequestRequestUsedTimeOffTimeOffsInnerTrackingPeriodsInner](docs/EorTerminationRequestRequestUsedTimeOffTimeOffsInnerTrackingPeriodsInner.md)
 - [EorTimeoffsBaseItem](docs/EorTimeoffsBaseItem.md)
 - [EorTimeoffsContainer](docs/EorTimeoffsContainer.md)
 - [EorTimeoffsEmployeeItem](docs/EorTimeoffsEmployeeItem.md)
 - [EorTimeoffsItem](docs/EorTimeoffsItem.md)
 - [EorTimeoffsItemContainer](docs/EorTimeoffsItemContainer.md)
 - [EquityStakeholder](docs/EquityStakeholder.md)
 - [EquityStakeholdersContainer](docs/EquityStakeholdersContainer.md)
 - [EquityTaxEvents201Response](docs/EquityTaxEvents201Response.md)
 - [EquityTaxEvents201ResponseData](docs/EquityTaxEvents201ResponseData.md)
 - [EquityTaxEvents400Response](docs/EquityTaxEvents400Response.md)
 - [EquityTaxEvents400ResponseErrorsInner](docs/EquityTaxEvents400ResponseErrorsInner.md)
 - [EquityTaxEventsRequest](docs/EquityTaxEventsRequest.md)
 - [EquityTaxEventsRequestData](docs/EquityTaxEventsRequestData.md)
 - [ExchangeRates](docs/ExchangeRates.md)
 - [ExerciseEquityToCreateContainer](docs/ExerciseEquityToCreateContainer.md)
 - [ExerciseEquityToUpdateContainer](docs/ExerciseEquityToUpdateContainer.md)
 - [ExternalId200Response](docs/ExternalId200Response.md)
 - [ExternalId200ResponseData](docs/ExternalId200ResponseData.md)
 - [ExternalIdRequest](docs/ExternalIdRequest.md)
 - [ExternalIdRequestData](docs/ExternalIdRequestData.md)
 - [FileAttachment](docs/FileAttachment.md)
 - [FileAttachmentInfo](docs/FileAttachmentInfo.md)
 - [FileObject](docs/FileObject.md)
 - [FileRefTypeEnum](docs/FileRefTypeEnum.md)
 - [FinalPaymentCalculated](docs/FinalPaymentCalculated.md)
 - [FinalPaymentCalculatedContainer](docs/FinalPaymentCalculatedContainer.md)
 - [FinalPaymentCalculatedLastCycle](docs/FinalPaymentCalculatedLastCycle.md)
 - [GPClient](docs/GPClient.md)
 - [GPClientLegalEntity](docs/GPClientLegalEntity.md)
 - [GPContractCreated](docs/GPContractCreated.md)
 - [GPContractCreatedCompensationDetails](docs/GPContractCreatedCompensationDetails.md)
 - [GPContractCreatedContainer](docs/GPContractCreatedContainer.md)
 - [GPContractCreatedEmployee](docs/GPContractCreatedEmployee.md)
 - [GPContractCreatedEmployment](docs/GPContractCreatedEmployment.md)
 - [GPContractCreatedEmploymentHolidays](docs/GPContractCreatedEmploymentHolidays.md)
 - [GPContractSalaryScaleEnum](docs/GPContractSalaryScaleEnum.md)
 - [GPContractSalaryStatusEnum](docs/GPContractSalaryStatusEnum.md)
 - [GPContractStatusTypeEnum](docs/GPContractStatusTypeEnum.md)
 - [GPContractToCreate](docs/GPContractToCreate.md)
 - [GPContractToCreateCompensationDetails](docs/GPContractToCreateCompensationDetails.md)
 - [GPContractToCreateContainer](docs/GPContractToCreateContainer.md)
 - [GPContractToCreateEmployee](docs/GPContractToCreateEmployee.md)
 - [GPContractToCreateEmployeeAddress](docs/GPContractToCreateEmployeeAddress.md)
 - [GPContractToCreateEmployment](docs/GPContractToCreateEmployment.md)
 - [GPContractToCreateEmploymentHolidays](docs/GPContractToCreateEmploymentHolidays.md)
 - [GPEmployeeAddressToUpdateContainer](docs/GPEmployeeAddressToUpdateContainer.md)
 - [GPEmployeeAddressUpdateData](docs/GPEmployeeAddressUpdateData.md)
 - [GPEmployeeAddressUpdated](docs/GPEmployeeAddressUpdated.md)
 - [GPEmployeeAddressUpdatedContainer](docs/GPEmployeeAddressUpdatedContainer.md)
 - [GPEmployeeCompensationToUpdateContainer](docs/GPEmployeeCompensationToUpdateContainer.md)
 - [GPEmployeeCompensationUpdateData](docs/GPEmployeeCompensationUpdateData.md)
 - [GPEmployeeCompensationUpdatedContainer](docs/GPEmployeeCompensationUpdatedContainer.md)
 - [GPEmployeeCompensationUpdatedInner](docs/GPEmployeeCompensationUpdatedInner.md)
 - [GPEmployeeInformationToUpdateContainer](docs/GPEmployeeInformationToUpdateContainer.md)
 - [GPEmployeeInformationUpdateData](docs/GPEmployeeInformationUpdateData.md)
 - [GPEmployeeInformationUpdatedContainer](docs/GPEmployeeInformationUpdatedContainer.md)
 - [GPEmployeePTOToUpdateContainer](docs/GPEmployeePTOToUpdateContainer.md)
 - [GPEmployeePTOUpdateData](docs/GPEmployeePTOUpdateData.md)
 - [GPPayrollEventReportContainer](docs/GPPayrollEventReportContainer.md)
 - [GPPayrollEventReportsInner](docs/GPPayrollEventReportsInner.md)
 - [GPPayslipDownloadUrlContainer](docs/GPPayslipDownloadUrlContainer.md)
 - [GPPayslipsListContainer](docs/GPPayslipsListContainer.md)
 - [GenericReportReviewCreated](docs/GenericReportReviewCreated.md)
 - [GenericReportReviewCreatedContainer](docs/GenericReportReviewCreatedContainer.md)
 - [GenericResultCreated](docs/GenericResultCreated.md)
 - [GenericResultCreatedWithId](docs/GenericResultCreatedWithId.md)
 - [GenericResultCreatedWithIdData](docs/GenericResultCreatedWithIdData.md)
 - [GenericResultDeleted](docs/GenericResultDeleted.md)
 - [GenericResultUpdated](docs/GenericResultUpdated.md)
 - [Get401kEnrollmentsDefinition200ResponseInner](docs/Get401kEnrollmentsDefinition200ResponseInner.md)
 - [Get401kEnrollmentsDefinition200ResponseInnerDetails](docs/Get401kEnrollmentsDefinition200ResponseInnerDetails.md)
 - [Get401kPlansDefinition200ResponseInner](docs/Get401kPlansDefinition200ResponseInner.md)
 - [Get401kPlansDefinition200ResponseInnerContributionValueForMatchRateInner](docs/Get401kPlansDefinition200ResponseInnerContributionValueForMatchRateInner.md)
 - [Get401kPlansDefinition200ResponseInnerDetails](docs/Get401kPlansDefinition200ResponseInnerDetails.md)
 - [GetAdjustments200Response](docs/GetAdjustments200Response.md)
 - [GetAllOrgStructures200Response](docs/GetAllOrgStructures200Response.md)
 - [GetAllOrgStructures200ResponseDataInner](docs/GetAllOrgStructures200ResponseDataInner.md)
 - [GetAllOrgStructures200ResponseDataInnerRolesInner](docs/GetAllOrgStructures200ResponseDataInnerRolesInner.md)
 - [GetAllOrgStructuresContainer](docs/GetAllOrgStructuresContainer.md)
 - [GetAllOrgStructuresContainerDataInner](docs/GetAllOrgStructuresContainerDataInner.md)
 - [GetAllOrgStructuresContainerDataInnerRolesInner](docs/GetAllOrgStructuresContainerDataInnerRolesInner.md)
 - [GetAllProfileWorkerRelations200Response](docs/GetAllProfileWorkerRelations200Response.md)
 - [GetAllProfileWorkerRelations200ResponseDataInner](docs/GetAllProfileWorkerRelations200ResponseDataInner.md)
 - [GetAllProfileWorkerRelations200ResponseDataInnerChildRelationshipsInner](docs/GetAllProfileWorkerRelations200ResponseDataInnerChildRelationshipsInner.md)
 - [GetAllProfileWorkerRelations200ResponseDataInnerParentRelationship](docs/GetAllProfileWorkerRelations200ResponseDataInnerParentRelationship.md)
 - [GetAllProfileWorkerRelationsExternalId200Response](docs/GetAllProfileWorkerRelationsExternalId200Response.md)
 - [GetAllProfileWorkerRelationsExternalId200ResponseDataInner](docs/GetAllProfileWorkerRelationsExternalId200ResponseDataInner.md)
 - [GetAllProfileWorkerRelationsExternalId200ResponseDataInnerChildRelationshipsInner](docs/GetAllProfileWorkerRelationsExternalId200ResponseDataInnerChildRelationshipsInner.md)
 - [GetAllProfileWorkerRelationsExternalId200ResponseDataInnerParentRelationship](docs/GetAllProfileWorkerRelationsExternalId200ResponseDataInnerParentRelationship.md)
 - [GetAllProfileWorkerRelationsExternalIdResponseContainer](docs/GetAllProfileWorkerRelationsExternalIdResponseContainer.md)
 - [GetAllProfileWorkerRelationsExternalIdResponseContainerDataInner](docs/GetAllProfileWorkerRelationsExternalIdResponseContainerDataInner.md)
 - [GetAllProfileWorkerRelationsExternalIdResponseContainerDataInnerChildRelationshipsInner](docs/GetAllProfileWorkerRelationsExternalIdResponseContainerDataInnerChildRelationshipsInner.md)
 - [GetAllProfileWorkerRelationsExternalIdResponseContainerDataInnerParentRelationship](docs/GetAllProfileWorkerRelationsExternalIdResponseContainerDataInnerParentRelationship.md)
 - [GetAllProfileWorkerRelationsResponseContainer](docs/GetAllProfileWorkerRelationsResponseContainer.md)
 - [GetAllWorkerRelationTypes200Response](docs/GetAllWorkerRelationTypes200Response.md)
 - [GetAllWorkerRelationTypes200ResponseDataInner](docs/GetAllWorkerRelationTypes200ResponseDataInner.md)
 - [GetAllWorkerRelationTypesResponseContainer](docs/GetAllWorkerRelationTypesResponseContainer.md)
 - [GetAllWorkerRelationTypesResponseContainerDataInner](docs/GetAllWorkerRelationTypesResponseContainerDataInner.md)
 - [GetBackgroundChecksByContractId200Response](docs/GetBackgroundChecksByContractId200Response.md)
 - [GetBackgroundChecksByContractId200ResponseData](docs/GetBackgroundChecksByContractId200ResponseData.md)
 - [GetBackgroundChecksByContractId200ResponseDataPackage](docs/GetBackgroundChecksByContractId200ResponseDataPackage.md)
 - [GetBackgroundChecksOptions200Response](docs/GetBackgroundChecksOptions200Response.md)
 - [GetBackgroundChecksOptions200ResponseData](docs/GetBackgroundChecksOptions200ResponseData.md)
 - [GetBackgroundChecksOptions200ResponseDataIndividualChecksInner](docs/GetBackgroundChecksOptions200ResponseDataIndividualChecksInner.md)
 - [GetBackgroundChecksOptions200ResponseDataPackagesInner](docs/GetBackgroundChecksOptions200ResponseDataPackagesInner.md)
 - [GetBankDetails200Response](docs/GetBankDetails200Response.md)
 - [GetBankDetails200ResponseDataInner](docs/GetBankDetails200ResponseDataInner.md)
 - [GetBankDetails200ResponseDataInnerData](docs/GetBankDetails200ResponseDataInnerData.md)
 - [GetBankTransferRequirements200Response](docs/GetBankTransferRequirements200Response.md)
 - [GetBankTransferRequirements200ResponseDataInner](docs/GetBankTransferRequirements200ResponseDataInner.md)
 - [GetBankTransferRequirements200ResponseDataInnerFieldsInner](docs/GetBankTransferRequirements200ResponseDataInnerFieldsInner.md)
 - [GetBankTransferRequirements200ResponseDataInnerFieldsInnerGroupInner](docs/GetBankTransferRequirements200ResponseDataInnerFieldsInnerGroupInner.md)
 - [GetBankTransferRequirements200ResponseDataInnerFieldsInnerGroupInnerValuesAllowedInner](docs/GetBankTransferRequirements200ResponseDataInnerFieldsInnerGroupInnerValuesAllowedInner.md)
 - [GetBankTransferRequirements200ResponseDataInnerIntermediaryInner](docs/GetBankTransferRequirements200ResponseDataInnerIntermediaryInner.md)
 - [GetBankTransferRequirements200ResponseDataInnerIntermediaryInnerGroupInner](docs/GetBankTransferRequirements200ResponseDataInnerIntermediaryInnerGroupInner.md)
 - [GetBankTransferSupportedRoutes200Response](docs/GetBankTransferSupportedRoutes200Response.md)
 - [GetBenefitEmployee200Response](docs/GetBenefitEmployee200Response.md)
 - [GetBenefitEmployee200ResponseAddressesInner](docs/GetBenefitEmployee200ResponseAddressesInner.md)
 - [GetBenefitEmployee200ResponseContractsInner](docs/GetBenefitEmployee200ResponseContractsInner.md)
 - [GetBenefitEmployee200ResponseContractsInnerCompensationsInner](docs/GetBenefitEmployee200ResponseContractsInnerCompensationsInner.md)
 - [GetBenefitEmployee200ResponsePhonesInner](docs/GetBenefitEmployee200ResponsePhonesInner.md)
 - [GetBenefitEmployees200Response](docs/GetBenefitEmployees200Response.md)
 - [GetBenefitEmployees200ResponseDataInner](docs/GetBenefitEmployees200ResponseDataInner.md)
 - [GetBenefitEmployees200ResponseDataInnerPhonesInner](docs/GetBenefitEmployees200ResponseDataInnerPhonesInner.md)
 - [GetBenefitEmployees200ResponsePage](docs/GetBenefitEmployees200ResponsePage.md)
 - [GetBenefitPaystubs200Response](docs/GetBenefitPaystubs200Response.md)
 - [GetBenefitPaystubs200ResponseDataInner](docs/GetBenefitPaystubs200ResponseDataInner.md)
 - [GetBenefitPaystubs200ResponseDataInnerEmployeesInner](docs/GetBenefitPaystubs200ResponseDataInnerEmployeesInner.md)
 - [GetBenefitPaystubs200ResponseDataInnerEmployeesInnerContributionsInner](docs/GetBenefitPaystubs200ResponseDataInnerEmployeesInnerContributionsInner.md)
 - [GetBenefitPaystubs200ResponseDataInnerEmployeesInnerEmployerContributionsInner](docs/GetBenefitPaystubs200ResponseDataInnerEmployeesInnerEmployerContributionsInner.md)
 - [GetBenefitPaystubs200ResponsePage](docs/GetBenefitPaystubs200ResponsePage.md)
 - [GetBillingInvoiceDownloadLink200Response](docs/GetBillingInvoiceDownloadLink200Response.md)
 - [GetBillingInvoiceDownloadLink200ResponseData](docs/GetBillingInvoiceDownloadLink200ResponseData.md)
 - [GetCategories200Response](docs/GetCategories200Response.md)
 - [GetCategories200ResponseDataInner](docs/GetCategories200ResponseDataInner.md)
 - [GetConsent200Response](docs/GetConsent200Response.md)
 - [GetConsent200ResponseData](docs/GetConsent200ResponseData.md)
 - [GetContractById200Response](docs/GetContractById200Response.md)
 - [GetContractById200ResponseData](docs/GetContractById200ResponseData.md)
 - [GetContractById200ResponseDataClient](docs/GetContractById200ResponseDataClient.md)
 - [GetContractById200ResponseDataClientLegalEntity](docs/GetContractById200ResponseDataClientLegalEntity.md)
 - [GetContractById200ResponseDataClientTeam](docs/GetContractById200ResponseDataClientTeam.md)
 - [GetContractById200ResponseDataCompensationDetails](docs/GetContractById200ResponseDataCompensationDetails.md)
 - [GetContractById200ResponseDataContractTemplate](docs/GetContractById200ResponseDataContractTemplate.md)
 - [GetContractById200ResponseDataEmploymentDetails](docs/GetContractById200ResponseDataEmploymentDetails.md)
 - [GetContractById200ResponseDataInvitations](docs/GetContractById200ResponseDataInvitations.md)
 - [GetContractById200ResponseDataQuote](docs/GetContractById200ResponseDataQuote.md)
 - [GetContractById200ResponseDataQuoteBenefitsInner](docs/GetContractById200ResponseDataQuoteBenefitsInner.md)
 - [GetContractById200ResponseDataSeniority](docs/GetContractById200ResponseDataSeniority.md)
 - [GetContractById200ResponseDataSignatures](docs/GetContractById200ResponseDataSignatures.md)
 - [GetContractById200ResponseDataWorker](docs/GetContractById200ResponseDataWorker.md)
 - [GetContractEquityWithholdingAmount200Response](docs/GetContractEquityWithholdingAmount200Response.md)
 - [GetContractEquityWithholdingAmount200ResponseData](docs/GetContractEquityWithholdingAmount200ResponseData.md)
 - [GetContractEquityWithholdingAmount200ResponseDataBreakdownInner](docs/GetContractEquityWithholdingAmount200ResponseDataBreakdownInner.md)
 - [GetContractList200Response](docs/GetContractList200Response.md)
 - [GetContractList200ResponseDataInner](docs/GetContractList200ResponseDataInner.md)
 - [GetContractList200ResponseDataInnerClient](docs/GetContractList200ResponseDataInnerClient.md)
 - [GetContractList200ResponseDataInnerClientTeam](docs/GetContractList200ResponseDataInnerClientTeam.md)
 - [GetContractList200ResponseDataInnerInvitations](docs/GetContractList200ResponseDataInnerInvitations.md)
 - [GetContractList200ResponseDataInnerSignatures](docs/GetContractList200ResponseDataInnerSignatures.md)
 - [GetContractList200ResponseDataInnerWorker](docs/GetContractList200ResponseDataInnerWorker.md)
 - [GetContractList200ResponseDataInnerWorkerAlternateEmailInner](docs/GetContractList200ResponseDataInnerWorkerAlternateEmailInner.md)
 - [GetContractList200ResponsePage](docs/GetContractList200ResponsePage.md)
 - [GetContractListCurrenciesParameter](docs/GetContractListCurrenciesParameter.md)
 - [GetContractPaymentDates200Response](docs/GetContractPaymentDates200Response.md)
 - [GetContractPaymentDates200ResponseDataInner](docs/GetContractPaymentDates200ResponseDataInner.md)
 - [GetContractTemplates200Response](docs/GetContractTemplates200Response.md)
 - [GetContractTemplates200ResponseDataInner](docs/GetContractTemplates200ResponseDataInner.md)
 - [GetCountries200Response](docs/GetCountries200Response.md)
 - [GetCountries200ResponseDataInner](docs/GetCountries200ResponseDataInner.md)
 - [GetCountries200ResponseDataInnerStatesInner](docs/GetCountries200ResponseDataInnerStatesInner.md)
 - [GetCurrencies200Response](docs/GetCurrencies200Response.md)
 - [GetCurrencies200ResponseDataInner](docs/GetCurrencies200ResponseDataInner.md)
 - [GetCustomFieldFromContractsById200Response](docs/GetCustomFieldFromContractsById200Response.md)
 - [GetCustomFieldFromContractsById200ResponseData](docs/GetCustomFieldFromContractsById200ResponseData.md)
 - [GetCustomFieldFromContractsById200ResponseDataSettings](docs/GetCustomFieldFromContractsById200ResponseDataSettings.md)
 - [GetCustomFieldFromContractsById200ResponseDataSettingsAccess](docs/GetCustomFieldFromContractsById200ResponseDataSettingsAccess.md)
 - [GetCustomFieldFromContractsById200ResponseDataType](docs/GetCustomFieldFromContractsById200ResponseDataType.md)
 - [GetCustomFieldFromContractsById200ResponseDataTypeOneOf](docs/GetCustomFieldFromContractsById200ResponseDataTypeOneOf.md)
 - [GetCustomFieldFromPeopleById200Response](docs/GetCustomFieldFromPeopleById200Response.md)
 - [GetCustomFieldFromPeopleById200ResponseData](docs/GetCustomFieldFromPeopleById200ResponseData.md)
 - [GetCustomFieldValuesFromWorker200Response](docs/GetCustomFieldValuesFromWorker200Response.md)
 - [GetCustomFieldValuesFromWorker200ResponseDataInner](docs/GetCustomFieldValuesFromWorker200ResponseDataInner.md)
 - [GetCustomFieldValuesFromWorker200ResponseDataInnerData](docs/GetCustomFieldValuesFromWorker200ResponseDataInnerData.md)
 - [GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf](docs/GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf.md)
 - [GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf1](docs/GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf1.md)
 - [GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf2](docs/GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf2.md)
 - [GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf3](docs/GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf3.md)
 - [GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf4](docs/GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf4.md)
 - [GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf5](docs/GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf5.md)
 - [GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf6](docs/GetCustomFieldValuesFromWorker200ResponseDataInnerDataOneOf6.md)
 - [GetCustomFieldsFromContracts200Response](docs/GetCustomFieldsFromContracts200Response.md)
 - [GetCustomFieldsFromContracts200ResponseData](docs/GetCustomFieldsFromContracts200ResponseData.md)
 - [GetCustomFieldsFromContracts200ResponseDataSettings](docs/GetCustomFieldsFromContracts200ResponseDataSettings.md)
 - [GetCustomFieldsFromContracts200ResponseDataSettingsAccess](docs/GetCustomFieldsFromContracts200ResponseDataSettingsAccess.md)
 - [GetCustomFieldsFromPeople200Response](docs/GetCustomFieldsFromPeople200Response.md)
 - [GetCustomFieldsFromPeople200ResponseData](docs/GetCustomFieldsFromPeople200ResponseData.md)
 - [GetCustomFieldsFromPeople200ResponseDataSettings](docs/GetCustomFieldsFromPeople200ResponseDataSettings.md)
 - [GetCustomFieldsFromPeople200ResponseDataSettingsAccess](docs/GetCustomFieldsFromPeople200ResponseDataSettingsAccess.md)
 - [GetCustomFieldsFromPeople200ResponseDataType](docs/GetCustomFieldsFromPeople200ResponseDataType.md)
 - [GetCustomFieldsFromPeople200ResponseDataTypeOneOf](docs/GetCustomFieldsFromPeople200ResponseDataTypeOneOf.md)
 - [GetCustomFieldsFromPeople200ResponseDataTypeOneOf1](docs/GetCustomFieldsFromPeople200ResponseDataTypeOneOf1.md)
 - [GetCustomFieldsFromPeople200ResponseDataTypeOneOf2](docs/GetCustomFieldsFromPeople200ResponseDataTypeOneOf2.md)
 - [GetDaasEmployeeAgreementDownloadLink200Response](docs/GetDaasEmployeeAgreementDownloadLink200Response.md)
 - [GetDaasEmployeeAgreementDownloadLink200ResponseData](docs/GetDaasEmployeeAgreementDownloadLink200ResponseData.md)
 - [GetDaasHrVerificationLettersAndDocuments200Response](docs/GetDaasHrVerificationLettersAndDocuments200Response.md)
 - [GetDaasHrVerificationLettersAndDocuments200ResponseDataInner](docs/GetDaasHrVerificationLettersAndDocuments200ResponseDataInner.md)
 - [GetDepartments200Response](docs/GetDepartments200Response.md)
 - [GetDepartments200ResponseDataInner](docs/GetDepartments200ResponseDataInner.md)
 - [GetDepartments404Response](docs/GetDepartments404Response.md)
 - [GetDownloadUrlForGPPayslip200Response](docs/GetDownloadUrlForGPPayslip200Response.md)
 - [GetDownloadUrlForGPPayslip200ResponseData](docs/GetDownloadUrlForGPPayslip200ResponseData.md)
 - [GetEORBankAccountGuide200Response](docs/GetEORBankAccountGuide200Response.md)
 - [GetEORBankAccountGuide200ResponseDataInner](docs/GetEORBankAccountGuide200ResponseDataInner.md)
 - [GetEORBankAccountGuide200ResponseDataInnerValidationsInner](docs/GetEORBankAccountGuide200ResponseDataInnerValidationsInner.md)
 - [GetEORBankAccountGuide200ResponseDataInnerValidationsInnerValue](docs/GetEORBankAccountGuide200ResponseDataInnerValidationsInnerValue.md)
 - [GetEORBankAccountGuide200ResponseDataInnerValuesAllowedInner](docs/GetEORBankAccountGuide200ResponseDataInnerValuesAllowedInner.md)
 - [GetEORContractBenefits200Response](docs/GetEORContractBenefits200Response.md)
 - [GetEORContractBenefits200ResponseDataInner](docs/GetEORContractBenefits200ResponseDataInner.md)
 - [GetEORContractBenefits200ResponseDataInnerEnrollmentDetails](docs/GetEORContractBenefits200ResponseDataInnerEnrollmentDetails.md)
 - [GetEORContractBenefits200ResponseDataInnerEnrollmentDetailsCurrent](docs/GetEORContractBenefits200ResponseDataInnerEnrollmentDetailsCurrent.md)
 - [GetEORContractBenefits200ResponseDataInnerEnrollmentDetailsPlan](docs/GetEORContractBenefits200ResponseDataInnerEnrollmentDetailsPlan.md)
 - [GetEORContractBenefits200ResponseDataInnerEnrollmentDetailsStandard](docs/GetEORContractBenefits200ResponseDataInnerEnrollmentDetailsStandard.md)
 - [GetEORContractBenefits200ResponseDataInnerPlan](docs/GetEORContractBenefits200ResponseDataInnerPlan.md)
 - [GetEORContractBenefits200ResponseDataInnerProvider](docs/GetEORContractBenefits200ResponseDataInnerProvider.md)
 - [GetEOREmployeeComplianceDocumentTemplate200Response](docs/GetEOREmployeeComplianceDocumentTemplate200Response.md)
 - [GetEOREmployeeComplianceDocumentTemplate200ResponseData](docs/GetEOREmployeeComplianceDocumentTemplate200ResponseData.md)
 - [GetEORWorkerPayslipDownloadUrl200Response](docs/GetEORWorkerPayslipDownloadUrl200Response.md)
 - [GetEORWorkerPayslipDownloadUrl200ResponseData](docs/GetEORWorkerPayslipDownloadUrl200ResponseData.md)
 - [GetEORWorkerPayslips200Response](docs/GetEORWorkerPayslips200Response.md)
 - [GetEORWorkerPayslips200ResponseDataInner](docs/GetEORWorkerPayslips200ResponseDataInner.md)
 - [GetEmployeeComplianceDocumentTemplateDownloadLinkContainer](docs/GetEmployeeComplianceDocumentTemplateDownloadLinkContainer.md)
 - [GetEmployeeComplianceDocumentsContainer](docs/GetEmployeeComplianceDocumentsContainer.md)
 - [GetEmployeeComplianceDocumentsContainerData](docs/GetEmployeeComplianceDocumentsContainerData.md)
 - [GetEmployeeComplianceDocumentsContainerDataDocumentsInner](docs/GetEmployeeComplianceDocumentsContainerDataDocumentsInner.md)
 - [GetEorCountryValidations200Response](docs/GetEorCountryValidations200Response.md)
 - [GetEorCountryValidations200ResponseData](docs/GetEorCountryValidations200ResponseData.md)
 - [GetEorCountryValidations200ResponseDataHealthInsurance](docs/GetEorCountryValidations200ResponseDataHealthInsurance.md)
 - [GetEorCountryValidations200ResponseDataHealthInsuranceProvidersInner](docs/GetEorCountryValidations200ResponseDataHealthInsuranceProvidersInner.md)
 - [GetEorCountryValidations200ResponseDataHoliday](docs/GetEorCountryValidations200ResponseDataHoliday.md)
 - [GetEorCountryValidations200ResponseDataProbation](docs/GetEorCountryValidations200ResponseDataProbation.md)
 - [GetEorCountryValidations200ResponseDataSalary](docs/GetEorCountryValidations200ResponseDataSalary.md)
 - [GetEorEmployeeComplianceDocuments200Response](docs/GetEorEmployeeComplianceDocuments200Response.md)
 - [GetEorEmployeeComplianceDocuments200ResponseData](docs/GetEorEmployeeComplianceDocuments200ResponseData.md)
 - [GetEorEmployeeComplianceDocuments200ResponseDataDocumentsInner](docs/GetEorEmployeeComplianceDocuments200ResponseDataDocumentsInner.md)
 - [GetEorEmployeePayslips200Response](docs/GetEorEmployeePayslips200Response.md)
 - [GetEorEmployeePayslips200ResponseDataInner](docs/GetEorEmployeePayslips200ResponseDataInner.md)
 - [GetEorEmployeeTaxDocuments200Response](docs/GetEorEmployeeTaxDocuments200Response.md)
 - [GetEorEmployeeTaxDocuments200ResponseDataInner](docs/GetEorEmployeeTaxDocuments200ResponseDataInner.md)
 - [GetGPLegalEntities200Response](docs/GetGPLegalEntities200Response.md)
 - [GetGPLegalEntities200ResponseDataInner](docs/GetGPLegalEntities200ResponseDataInner.md)
 - [GetGpBankAccounts200Response](docs/GetGpBankAccounts200Response.md)
 - [GetGpBankAccounts200ResponseDataInner](docs/GetGpBankAccounts200ResponseDataInner.md)
 - [GetGpBankGuide200Response](docs/GetGpBankGuide200Response.md)
 - [GetGpBankGuide200ResponseDataInner](docs/GetGpBankGuide200ResponseDataInner.md)
 - [GetGpBankGuide200ResponseDataInnerValidationsInner](docs/GetGpBankGuide200ResponseDataInnerValidationsInner.md)
 - [GetGpBankGuide200ResponseDataInnerValidationsInnerValue](docs/GetGpBankGuide200ResponseDataInnerValidationsInnerValue.md)
 - [GetGpBankGuide200ResponseDataInnerValuesAllowedInner](docs/GetGpBankGuide200ResponseDataInnerValuesAllowedInner.md)
 - [GetGrossToNetGPReports200Response](docs/GetGrossToNetGPReports200Response.md)
 - [GetGrossToNetGPReports200ResponseDataInner](docs/GetGrossToNetGPReports200ResponseDataInner.md)
 - [GetGroups200Response](docs/GetGroups200Response.md)
 - [GetGroups200ResponseDataInner](docs/GetGroups200ResponseDataInner.md)
 - [GetGroups200ResponsePage](docs/GetGroups200ResponsePage.md)
 - [GetGroups400Response](docs/GetGroups400Response.md)
 - [GetHrisPositionContainer](docs/GetHrisPositionContainer.md)
 - [GetHrisPositionContainerDataInner](docs/GetHrisPositionContainerDataInner.md)
 - [GetHrisPositionContainerDataInnerTeam](docs/GetHrisPositionContainerDataInnerTeam.md)
 - [GetHrisPositions200Response](docs/GetHrisPositions200Response.md)
 - [GetHrisPositions200ResponseDataInner](docs/GetHrisPositions200ResponseDataInner.md)
 - [GetHrisPositions200ResponseDataInnerRole](docs/GetHrisPositions200ResponseDataInnerRole.md)
 - [GetHrisPositions200ResponseDataInnerTeam](docs/GetHrisPositions200ResponseDataInnerTeam.md)
 - [GetHrisPositions200ResponseDataInnerTeamOrganizationStructure](docs/GetHrisPositions200ResponseDataInnerTeamOrganizationStructure.md)
 - [GetInviteLink200Response](docs/GetInviteLink200Response.md)
 - [GetInvoiceAdjustments200Response](docs/GetInvoiceAdjustments200Response.md)
 - [GetInvoiceAdjustments200ResponsePage](docs/GetInvoiceAdjustments200ResponsePage.md)
 - [GetInvoiceAdjustmentsByContractId200Response](docs/GetInvoiceAdjustmentsByContractId200Response.md)
 - [GetInvoiceAdjustmentsByContractId200ResponseDataInner](docs/GetInvoiceAdjustmentsByContractId200ResponseDataInner.md)
 - [GetInvoiceAdjustmentsByContractId200ResponseDataInnerPaymentCycle](docs/GetInvoiceAdjustmentsByContractId200ResponseDataInnerPaymentCycle.md)
 - [GetInvoiceAdjustmentsByContractId200ResponseDataInnerReviewedBy](docs/GetInvoiceAdjustmentsByContractId200ResponseDataInnerReviewedBy.md)
 - [GetInvoiceAdjustmentsByContractId200ResponsePage](docs/GetInvoiceAdjustmentsByContractId200ResponsePage.md)
 - [GetInvoiceAdjustmentsByContractIdTypesParameter](docs/GetInvoiceAdjustmentsByContractIdTypesParameter.md)
 - [GetInvoiceAdjustmentsById200Response](docs/GetInvoiceAdjustmentsById200Response.md)
 - [GetInvoiceAdjustmentsById200ResponseData](docs/GetInvoiceAdjustmentsById200ResponseData.md)
 - [GetInvoiceList200Response](docs/GetInvoiceList200Response.md)
 - [GetInvoiceList200ResponseData](docs/GetInvoiceList200ResponseData.md)
 - [GetInvoiceList200ResponseDataRowsInner](docs/GetInvoiceList200ResponseDataRowsInner.md)
 - [GetInvoiceList200ResponsePage](docs/GetInvoiceList200ResponsePage.md)
 - [GetInvoiceListEntitiesParameter](docs/GetInvoiceListEntitiesParameter.md)
 - [GetJobTitleList200Response](docs/GetJobTitleList200Response.md)
 - [GetJobTitleList200ResponseDataInner](docs/GetJobTitleList200ResponseDataInner.md)
 - [GetJobTitleList200ResponsePage](docs/GetJobTitleList200ResponsePage.md)
 - [GetLegalEntity200Response](docs/GetLegalEntity200Response.md)
 - [GetLegalEntity200ResponseAddress](docs/GetLegalEntity200ResponseAddress.md)
 - [GetLegalEntity200ResponseRegistrationAddress](docs/GetLegalEntity200ResponseRegistrationAddress.md)
 - [GetLegalEntityList200Response](docs/GetLegalEntityList200Response.md)
 - [GetLegalEntityList200ResponseDataInner](docs/GetLegalEntityList200ResponseDataInner.md)
 - [GetLegalEntityPayrollSettings200ResponseInner](docs/GetLegalEntityPayrollSettings200ResponseInner.md)
 - [GetLookups200Response](docs/GetLookups200Response.md)
 - [GetLookups200ResponseDataInner](docs/GetLookups200ResponseDataInner.md)
 - [GetManagers200Response](docs/GetManagers200Response.md)
 - [GetManagers200ResponseDataInner](docs/GetManagers200ResponseDataInner.md)
 - [GetManagers200ResponsePage](docs/GetManagers200ResponsePage.md)
 - [GetMilestonesByContract200Response](docs/GetMilestonesByContract200Response.md)
 - [GetMilestonesByContract200ResponseDataInner](docs/GetMilestonesByContract200ResponseDataInner.md)
 - [GetMilestonesByContract200ResponseDataInnerId](docs/GetMilestonesByContract200ResponseDataInnerId.md)
 - [GetMilestonesByContract200ResponseDataInnerReportedBy](docs/GetMilestonesByContract200ResponseDataInnerReportedBy.md)
 - [GetMilestonesByContract200ResponseDataInnerReportedById](docs/GetMilestonesByContract200ResponseDataInnerReportedById.md)
 - [GetMilestonesByContract200ResponseDataInnerReviewedBy](docs/GetMilestonesByContract200ResponseDataInnerReviewedBy.md)
 - [GetMilestonesByContract200ResponseDataInnerReviewedById](docs/GetMilestonesByContract200ResponseDataInnerReviewedById.md)
 - [GetMilestonesByContractAndId200Response](docs/GetMilestonesByContractAndId200Response.md)
 - [GetMilestonesByContractAndId200ResponseData](docs/GetMilestonesByContractAndId200ResponseData.md)
 - [GetMilestonesByContractAndId200ResponseDataId](docs/GetMilestonesByContractAndId200ResponseDataId.md)
 - [GetMilestonesByContractAndId200ResponseDataReportedBy](docs/GetMilestonesByContractAndId200ResponseDataReportedBy.md)
 - [GetMilestonesByContractAndId200ResponseDataReviewedBy](docs/GetMilestonesByContractAndId200ResponseDataReviewedBy.md)
 - [GetOffCyclePaymentByContractAndId200Response](docs/GetOffCyclePaymentByContractAndId200Response.md)
 - [GetOffCyclePaymentByContractAndId200ResponseData](docs/GetOffCyclePaymentByContractAndId200ResponseData.md)
 - [GetOffCyclePaymentByContractAndId200ResponseDataReportedBy](docs/GetOffCyclePaymentByContractAndId200ResponseDataReportedBy.md)
 - [GetOffCyclePaymentsByContract200Response](docs/GetOffCyclePaymentsByContract200Response.md)
 - [GetOffCyclePaymentsByContract200ResponseDataInner](docs/GetOffCyclePaymentsByContract200ResponseDataInner.md)
 - [GetOffCyclePaymentsByContract200ResponseDataInnerReportedBy](docs/GetOffCyclePaymentsByContract200ResponseDataInnerReportedBy.md)
 - [GetOrgStructure200Response](docs/GetOrgStructure200Response.md)
 - [GetOrgStructure200ResponseData](docs/GetOrgStructure200ResponseData.md)
 - [GetOrgStructure200ResponseDataRolesInner](docs/GetOrgStructure200ResponseDataRolesInner.md)
 - [GetOrgStructureByExternalId200Response](docs/GetOrgStructureByExternalId200Response.md)
 - [GetOrgStructureByExternalId200ResponseData](docs/GetOrgStructureByExternalId200ResponseData.md)
 - [GetOrgStructureByExternalId200ResponseDataRolesInner](docs/GetOrgStructureByExternalId200ResponseDataRolesInner.md)
 - [GetOrgStructureContainer](docs/GetOrgStructureContainer.md)
 - [GetOrganizationRoles200ResponseInner](docs/GetOrganizationRoles200ResponseInner.md)
 - [GetOrganizationRoles400Response](docs/GetOrganizationRoles400Response.md)
 - [GetOrganizationRoles401Response](docs/GetOrganizationRoles401Response.md)
 - [GetOrganizationRoles500Response](docs/GetOrganizationRoles500Response.md)
 - [GetOrganizations200Response](docs/GetOrganizations200Response.md)
 - [GetOrganizations200ResponseDataInner](docs/GetOrganizations200ResponseDataInner.md)
 - [GetOrganizations401Response](docs/GetOrganizations401Response.md)
 - [GetOrganizations404Response](docs/GetOrganizations404Response.md)
 - [GetOrganizations500Response](docs/GetOrganizations500Response.md)
 - [GetPayStub200Response](docs/GetPayStub200Response.md)
 - [GetPayStub200ResponseDataInner](docs/GetPayStub200ResponseDataInner.md)
 - [GetPayStub200ResponseDataInnerEmployeesInner](docs/GetPayStub200ResponseDataInnerEmployeesInner.md)
 - [GetPayStub200ResponseDataInnerEmployeesInnerContributionsInner](docs/GetPayStub200ResponseDataInnerEmployeesInnerContributionsInner.md)
 - [GetPayStub200ResponseDataInnerEmployeesInnerEmployerContributionsInner](docs/GetPayStub200ResponseDataInnerEmployeesInnerEmployerContributionsInner.md)
 - [GetPaymentList200Response](docs/GetPaymentList200Response.md)
 - [GetPaymentList200ResponseData](docs/GetPaymentList200ResponseData.md)
 - [GetPaymentList200ResponseDataRowsInner](docs/GetPaymentList200ResponseDataRowsInner.md)
 - [GetPaymentList200ResponseDataRowsInnerPaymentMethod](docs/GetPaymentList200ResponseDataRowsInnerPaymentMethod.md)
 - [GetPaymentsBreakDownById200Response](docs/GetPaymentsBreakDownById200Response.md)
 - [GetPaymentsBreakDownById200ResponseDataInner](docs/GetPaymentsBreakDownById200ResponseDataInner.md)
 - [GetPayoutMethods200Response](docs/GetPayoutMethods200Response.md)
 - [GetPayoutMethods200ResponseData](docs/GetPayoutMethods200ResponseData.md)
 - [GetPayoutMethods200ResponseDataAddress](docs/GetPayoutMethods200ResponseDataAddress.md)
 - [GetPeople200Response](docs/GetPeople200Response.md)
 - [GetPeopleById200Response](docs/GetPeopleById200Response.md)
 - [GetPeopleById200ResponseData](docs/GetPeopleById200ResponseData.md)
 - [GetPeopleById200ResponseDataAllOfCustomFieldsInner](docs/GetPeopleById200ResponseDataAllOfCustomFieldsInner.md)
 - [GetPeopleById200ResponseDataAllOfDepartment](docs/GetPeopleById200ResponseDataAllOfDepartment.md)
 - [GetPeopleById200ResponseDataAllOfDirectManager](docs/GetPeopleById200ResponseDataAllOfDirectManager.md)
 - [GetPeopleById200ResponseDataAllOfDirectReportsInner](docs/GetPeopleById200ResponseDataAllOfDirectReportsInner.md)
 - [GetPeopleById200ResponseDataAllOfEmploymentsInner](docs/GetPeopleById200ResponseDataAllOfEmploymentsInner.md)
 - [GetPeopleById200ResponseDataAllOfEmploymentsInnerPayment](docs/GetPeopleById200ResponseDataAllOfEmploymentsInnerPayment.md)
 - [GetPeopleById200ResponseDataAllOfEmploymentsInnerTeam](docs/GetPeopleById200ResponseDataAllOfEmploymentsInnerTeam.md)
 - [GetPeopleList200Response](docs/GetPeopleList200Response.md)
 - [GetPeopleList200ResponseDataInner](docs/GetPeopleList200ResponseDataInner.md)
 - [GetPeopleList200ResponseDataInnerAddressesInner](docs/GetPeopleList200ResponseDataInnerAddressesInner.md)
 - [GetPeopleList200ResponseDataInnerDepartment](docs/GetPeopleList200ResponseDataInnerDepartment.md)
 - [GetPeopleList200ResponseDataInnerDirectManager](docs/GetPeopleList200ResponseDataInnerDirectManager.md)
 - [GetPeopleList200ResponseDataInnerDirectReportsInner](docs/GetPeopleList200ResponseDataInnerDirectReportsInner.md)
 - [GetPeopleList200ResponseDataInnerEmailsInner](docs/GetPeopleList200ResponseDataInnerEmailsInner.md)
 - [GetPeopleList200ResponseDataInnerEmploymentsInner](docs/GetPeopleList200ResponseDataInnerEmploymentsInner.md)
 - [GetPeopleList200ResponseDataInnerEmploymentsInnerClientLegalEntity](docs/GetPeopleList200ResponseDataInnerEmploymentsInnerClientLegalEntity.md)
 - [GetPeopleList200ResponseDataInnerEmploymentsInnerPayment](docs/GetPeopleList200ResponseDataInnerEmploymentsInnerPayment.md)
 - [GetPeopleList200ResponseDataInnerEmploymentsInnerTeam](docs/GetPeopleList200ResponseDataInnerEmploymentsInnerTeam.md)
 - [GetPeopleList200ResponsePage](docs/GetPeopleList200ResponsePage.md)
 - [GetPeoplePersonalInformationByExternalId200Response](docs/GetPeoplePersonalInformationByExternalId200Response.md)
 - [GetPeoplePersonalInformationByExternalId200ResponseData](docs/GetPeoplePersonalInformationByExternalId200ResponseData.md)
 - [GetPeoplePersonalInformationByExternalId200ResponseDataAddressesInner](docs/GetPeoplePersonalInformationByExternalId200ResponseDataAddressesInner.md)
 - [GetPeoplePersonalInformationByExternalId200ResponseDataDemographics](docs/GetPeoplePersonalInformationByExternalId200ResponseDataDemographics.md)
 - [GetPeoplePersonalInformationByExternalId200ResponseDataDemographicsEthnicity](docs/GetPeoplePersonalInformationByExternalId200ResponseDataDemographicsEthnicity.md)
 - [GetPeoplePersonalInformationByExternalId200ResponseDataDemographicsGender](docs/GetPeoplePersonalInformationByExternalId200ResponseDataDemographicsGender.md)
 - [GetPeoplePersonalInformationByExternalId200ResponseDataEmergencyContactsInner](docs/GetPeoplePersonalInformationByExternalId200ResponseDataEmergencyContactsInner.md)
 - [GetPeoplePersonalInformationById200Response](docs/GetPeoplePersonalInformationById200Response.md)
 - [GetPeoplePersonalInformationById200ResponseData](docs/GetPeoplePersonalInformationById200ResponseData.md)
 - [GetPeoplePersonalInformationById200ResponseDataAddressesInner](docs/GetPeoplePersonalInformationById200ResponseDataAddressesInner.md)
 - [GetPeoplePersonalInformationById200ResponseDataDemographics](docs/GetPeoplePersonalInformationById200ResponseDataDemographics.md)
 - [GetPeoplePersonalInformationById200ResponseDataDemographicsEthnicity](docs/GetPeoplePersonalInformationById200ResponseDataDemographicsEthnicity.md)
 - [GetPeoplePersonalInformationById200ResponseDataDemographicsGender](docs/GetPeoplePersonalInformationById200ResponseDataDemographicsGender.md)
 - [GetPeoplePersonalInformationById200ResponseDataEmergencyContactsInner](docs/GetPeoplePersonalInformationById200ResponseDataEmergencyContactsInner.md)
 - [GetPeoplePersonalInformationById200ResponseDataEmergencyContactsInnerPreferredLanguage](docs/GetPeoplePersonalInformationById200ResponseDataEmergencyContactsInnerPreferredLanguage.md)
 - [GetPeoplePersonalInformationById200ResponseDataKyc](docs/GetPeoplePersonalInformationById200ResponseDataKyc.md)
 - [GetPeoplePersonalInformationById200ResponseDataNationalitiesInner](docs/GetPeoplePersonalInformationById200ResponseDataNationalitiesInner.md)
 - [GetPeoplePersonalInformationById200ResponseDataOoo](docs/GetPeoplePersonalInformationById200ResponseDataOoo.md)
 - [GetPeoplePersonalInformationById200ResponseDataPhoneNumbersInner](docs/GetPeoplePersonalInformationById200ResponseDataPhoneNumbersInner.md)
 - [GetPoliciesForProfile200Response](docs/GetPoliciesForProfile200Response.md)
 - [GetPoliciesForProfile200ResponsePoliciesInner](docs/GetPoliciesForProfile200ResponsePoliciesInner.md)
 - [GetPoliciesForProfile200ResponsePoliciesInnerPolicyType](docs/GetPoliciesForProfile200ResponsePoliciesInnerPolicyType.md)
 - [GetPoliciesForProfile200ResponsePoliciesInnerTimeOffTypesInner](docs/GetPoliciesForProfile200ResponsePoliciesInnerTimeOffTypesInner.md)
 - [GetProfileEntitlements200Response](docs/GetProfileEntitlements200Response.md)
 - [GetProfileEntitlements200ResponseEntitlementsInner](docs/GetProfileEntitlements200ResponseEntitlementsInner.md)
 - [GetProfileEntitlements200ResponseEntitlementsInnerEventsInner](docs/GetProfileEntitlements200ResponseEntitlementsInnerEventsInner.md)
 - [GetProfileEntitlements200ResponseEntitlementsInnerPolicy](docs/GetProfileEntitlements200ResponseEntitlementsInnerPolicy.md)
 - [GetProfileEntitlements200ResponseEntitlementsInnerPolicyPolicyType](docs/GetProfileEntitlements200ResponseEntitlementsInnerPolicyPolicyType.md)
 - [GetProfileEntitlements200ResponseEntitlementsInnerPolicyTimeOffTypesInner](docs/GetProfileEntitlements200ResponseEntitlementsInnerPolicyTimeOffTypesInner.md)
 - [GetProfileEntitlements200ResponseEntitlementsInnerRolloversInner](docs/GetProfileEntitlements200ResponseEntitlementsInnerRolloversInner.md)
 - [GetProfileEntitlements200ResponseEntitlementsInnerRolloversInnerAmount](docs/GetProfileEntitlements200ResponseEntitlementsInnerRolloversInnerAmount.md)
 - [GetRolesContainer](docs/GetRolesContainer.md)
 - [GetRolesItem](docs/GetRolesItem.md)
 - [GetSeniorityList200Response](docs/GetSeniorityList200Response.md)
 - [GetSeniorityList200ResponseDataInner](docs/GetSeniorityList200ResponseDataInner.md)
 - [GetShiftDetails200Response](docs/GetShiftDetails200Response.md)
 - [GetShiftDetails200ResponseData](docs/GetShiftDetails200ResponseData.md)
 - [GetShiftDetails400Response](docs/GetShiftDetails400Response.md)
 - [GetShiftDetails400ResponseError](docs/GetShiftDetails400ResponseError.md)
 - [GetShiftRate200Response](docs/GetShiftRate200Response.md)
 - [GetShiftRate200ResponseData](docs/GetShiftRate200ResponseData.md)
 - [GetShiftRates200Response](docs/GetShiftRates200Response.md)
 - [GetShiftRates200ResponseDataInner](docs/GetShiftRates200ResponseDataInner.md)
 - [GetShiftRates200ResponsePage](docs/GetShiftRates200ResponsePage.md)
 - [GetShifts200Response](docs/GetShifts200Response.md)
 - [GetShifts200ResponseDataInner](docs/GetShifts200ResponseDataInner.md)
 - [GetShifts200ResponseDataInnerMeta](docs/GetShifts200ResponseDataInnerMeta.md)
 - [GetShifts200ResponseDataInnerMetaBreaksInner](docs/GetShifts200ResponseDataInnerMetaBreaksInner.md)
 - [GetShifts200ResponseDataInnerMetaBreaksInnerEnd](docs/GetShifts200ResponseDataInnerMetaBreaksInnerEnd.md)
 - [GetShifts200ResponseDataInnerMetaBreaksInnerStart](docs/GetShifts200ResponseDataInnerMetaBreaksInnerStart.md)
 - [GetShifts200ResponseDataInnerMetaEnd](docs/GetShifts200ResponseDataInnerMetaEnd.md)
 - [GetShifts200ResponseDataInnerMetaStart](docs/GetShifts200ResponseDataInnerMetaStart.md)
 - [GetShifts200ResponseDataInnerSummary](docs/GetShifts200ResponseDataInnerSummary.md)
 - [GetShifts200ResponsePage](docs/GetShifts200ResponsePage.md)
 - [GetTasksByContract200Response](docs/GetTasksByContract200Response.md)
 - [GetTasksByContract200ResponseData](docs/GetTasksByContract200ResponseData.md)
 - [GetTasksByContract200ResponseDataAttachment](docs/GetTasksByContract200ResponseDataAttachment.md)
 - [GetTeams200Response](docs/GetTeams200Response.md)
 - [GetTeams200ResponseDataInner](docs/GetTeams200ResponseDataInner.md)
 - [GetTeams404Response](docs/GetTeams404Response.md)
 - [GetTimeOffsQuery200Response](docs/GetTimeOffsQuery200Response.md)
 - [GetTimeOffsQuery200ResponseDataInner](docs/GetTimeOffsQuery200ResponseDataInner.md)
 - [GetTimeOffsQuery200ResponseDataInnerRecipientProfile](docs/GetTimeOffsQuery200ResponseDataInnerRecipientProfile.md)
 - [GetTimeOffsQuery200ResponseDataInnerRequesterProfile](docs/GetTimeOffsQuery200ResponseDataInnerRequesterProfile.md)
 - [GetTimeOffsQuery200ResponseDataInnerTimeOffDailiesInner](docs/GetTimeOffsQuery200ResponseDataInnerTimeOffDailiesInner.md)
 - [GetTimeOffsQueryForOrganization200Response](docs/GetTimeOffsQueryForOrganization200Response.md)
 - [GetTimeOffsQueryForOrganization200ResponseDataInner](docs/GetTimeOffsQueryForOrganization200ResponseDataInner.md)
 - [GetTimeOffsQueryForOrganization200ResponseDataInnerTimeOffType](docs/GetTimeOffsQueryForOrganization200ResponseDataInnerTimeOffType.md)
 - [GetTimeOffsQueryForOrganization200ResponseDataInnerTimeOffTypePolicy](docs/GetTimeOffsQueryForOrganization200ResponseDataInnerTimeOffTypePolicy.md)
 - [GetTimeOffsQueryForOrganization200ResponseDataInnerTimeOffTypePolicyPolicyType](docs/GetTimeOffsQueryForOrganization200ResponseDataInnerTimeOffTypePolicyPolicyType.md)
 - [GetTimeoffTypeList200Response](docs/GetTimeoffTypeList200Response.md)
 - [GetTimesheetById200Response](docs/GetTimesheetById200Response.md)
 - [GetTimesheetById200ResponseData](docs/GetTimesheetById200ResponseData.md)
 - [GetTimesheetById200ResponseDataAllOfApproversInner](docs/GetTimesheetById200ResponseDataAllOfApproversInner.md)
 - [GetTimesheetById200ResponseDataAllOfReportedBy](docs/GetTimesheetById200ResponseDataAllOfReportedBy.md)
 - [GetTimesheetById200ResponseDataAllOfReviewedBy](docs/GetTimesheetById200ResponseDataAllOfReviewedBy.md)
 - [GetTimesheets200Response](docs/GetTimesheets200Response.md)
 - [GetTimesheets200ResponseDataInner](docs/GetTimesheets200ResponseDataInner.md)
 - [GetTimesheets200ResponseDataInnerAttachment](docs/GetTimesheets200ResponseDataInnerAttachment.md)
 - [GetTimesheets200ResponseDataInnerContract](docs/GetTimesheets200ResponseDataInnerContract.md)
 - [GetTimesheets200ResponseDataInnerPaymentCycle](docs/GetTimesheets200ResponseDataInnerPaymentCycle.md)
 - [GetTimesheets200ResponseDataInnerReportedBy](docs/GetTimesheets200ResponseDataInnerReportedBy.md)
 - [GetTimesheets200ResponseDataInnerReviewedBy](docs/GetTimesheets200ResponseDataInnerReviewedBy.md)
 - [GetTimesheets200ResponseDataInnerWorksheet](docs/GetTimesheets200ResponseDataInnerWorksheet.md)
 - [GetTimesheets200ResponsePage](docs/GetTimesheets200ResponsePage.md)
 - [GetTimesheetsByContract200Response](docs/GetTimesheetsByContract200Response.md)
 - [GetTimesheetsByContract200ResponseDataInner](docs/GetTimesheetsByContract200ResponseDataInner.md)
 - [GetTimesheetsByContract200ResponseDataInnerContract](docs/GetTimesheetsByContract200ResponseDataInnerContract.md)
 - [GetTimesheetsByContract200ResponseDataInnerPaymentCycle](docs/GetTimesheetsByContract200ResponseDataInnerPaymentCycle.md)
 - [GetTimesheetsByContract200ResponseDataInnerReportedBy](docs/GetTimesheetsByContract200ResponseDataInnerReportedBy.md)
 - [GetTimesheetsByContract200ResponseDataInnerReviewedBy](docs/GetTimesheetsByContract200ResponseDataInnerReviewedBy.md)
 - [GetTimesheetsByContract200ResponseDataInnerWorksheet](docs/GetTimesheetsByContract200ResponseDataInnerWorksheet.md)
 - [GetTimesheetsByContract200ResponsePage](docs/GetTimesheetsByContract200ResponsePage.md)
 - [GetTimesheetsByContractContractTypesParameter](docs/GetTimesheetsByContractContractTypesParameter.md)
 - [GetTimesheetsByContractStatusesParameter](docs/GetTimesheetsByContractStatusesParameter.md)
 - [GetTimesheetsStatusesParameter](docs/GetTimesheetsStatusesParameter.md)
 - [GetVerificationMethod200Response](docs/GetVerificationMethod200Response.md)
 - [GetVerificationMethod200ResponseData](docs/GetVerificationMethod200ResponseData.md)
 - [GetWorkerPayslips200Response](docs/GetWorkerPayslips200Response.md)
 - [GetWorkerPayslips200ResponseDataInner](docs/GetWorkerPayslips200ResponseDataInner.md)
 - [GetYearToDatePay200Response](docs/GetYearToDatePay200Response.md)
 - [GetYearToDatePay200ResponseEmployeesInner](docs/GetYearToDatePay200ResponseEmployeesInner.md)
 - [GetYearToDatePay200ResponseEmployeesInnerContributionsInner](docs/GetYearToDatePay200ResponseEmployeesInnerContributionsInner.md)
 - [GetYearToDatePay200ResponseEmployeesInnerEmployerContributionsInner](docs/GetYearToDatePay200ResponseEmployeesInnerEmployerContributionsInner.md)
 - [GlobalPayrollG2NReport](docs/GlobalPayrollG2NReport.md)
 - [GlobalPayrollG2NReportContainer](docs/GlobalPayrollG2NReportContainer.md)
 - [HRDocumentInfo](docs/HRDocumentInfo.md)
 - [HealthInsuranceProvider](docs/HealthInsuranceProvider.md)
 - [HealthInsuranceProviderAttachmentsInner](docs/HealthInsuranceProviderAttachmentsInner.md)
 - [HealthInsuranceProviderPlansInner](docs/HealthInsuranceProviderPlansInner.md)
 - [HiringStatusEnum](docs/HiringStatusEnum.md)
 - [HrVerificationLettersAndDocumentsListContainer](docs/HrVerificationLettersAndDocumentsListContainer.md)
 - [HrisCompensation](docs/HrisCompensation.md)
 - [HrisContractBase](docs/HrisContractBase.md)
 - [HrisContractFullTime](docs/HrisContractFullTime.md)
 - [HrisContractPartTime](docs/HrisContractPartTime.md)
 - [HrisDirectEmployee](docs/HrisDirectEmployee.md)
 - [HrisDirectEmployeeContainer](docs/HrisDirectEmployeeContainer.md)
 - [HrisDirectEmployeeContract](docs/HrisDirectEmployeeContract.md)
 - [HrisDirectEmployeeContractBase](docs/HrisDirectEmployeeContractBase.md)
 - [HrisDirectEmployeeContractFullTime](docs/HrisDirectEmployeeContractFullTime.md)
 - [HrisDirectEmployeeContractPartTime](docs/HrisDirectEmployeeContractPartTime.md)
 - [HrisDirectEmployeeDetails](docs/HrisDirectEmployeeDetails.md)
 - [HrisDirectEmployeeJobInformation](docs/HrisDirectEmployeeJobInformation.md)
 - [HrisDirectEmployeeResponse](docs/HrisDirectEmployeeResponse.md)
 - [HrisDirectEmployeeToCreateContainer](docs/HrisDirectEmployeeToCreateContainer.md)
 - [HrisDirectEmployeeToCreateContainerData](docs/HrisDirectEmployeeToCreateContainerData.md)
 - [HrisDirectEmployeeToCreateContainerDataClient](docs/HrisDirectEmployeeToCreateContainerDataClient.md)
 - [HrisDirectEmployeeToCreateContainerDataClientLegalEntity](docs/HrisDirectEmployeeToCreateContainerDataClientLegalEntity.md)
 - [HrisDirectEmployeeToCreateContainerDataClientTeam](docs/HrisDirectEmployeeToCreateContainerDataClientTeam.md)
 - [HrisDirectEmployeeToCreateContainerDataCompensationDetails](docs/HrisDirectEmployeeToCreateContainerDataCompensationDetails.md)
 - [HrisDirectEmployeeToCreateContainerDataEmployee](docs/HrisDirectEmployeeToCreateContainerDataEmployee.md)
 - [HrisDirectEmployeeToCreateContainerDataEmployment](docs/HrisDirectEmployeeToCreateContainerDataEmployment.md)
 - [HrisDirectEmployeeToCreateContainerDataSeniority](docs/HrisDirectEmployeeToCreateContainerDataSeniority.md)
 - [HrisDirectEmployeeVacationInfo](docs/HrisDirectEmployeeVacationInfo.md)
 - [HrisJobInformationBase](docs/HrisJobInformationBase.md)
 - [HrisJobInformationTitleId](docs/HrisJobInformationTitleId.md)
 - [HrisJobInformationTitleName](docs/HrisJobInformationTitleName.md)
 - [HrisPositionToChangeContainer](docs/HrisPositionToChangeContainer.md)
 - [HrisPositionToChangeContainerData](docs/HrisPositionToChangeContainerData.md)
 - [HrisPositionToChangeContainerDataAddInner](docs/HrisPositionToChangeContainerDataAddInner.md)
 - [HrisPositionToChangeContainerDataEditInner](docs/HrisPositionToChangeContainerDataEditInner.md)
 - [HrisTeamInformation](docs/HrisTeamInformation.md)
 - [IdentifierValueForFilter](docs/IdentifierValueForFilter.md)
 - [ImmigrationCaseDetails200Response](docs/ImmigrationCaseDetails200Response.md)
 - [ImmigrationCaseDetails200ResponseDataInner](docs/ImmigrationCaseDetails200ResponseDataInner.md)
 - [ImmigrationCaseDetails200ResponseDataInnerApplicant](docs/ImmigrationCaseDetails200ResponseDataInnerApplicant.md)
 - [ImmigrationCaseDetails200ResponseDataInnerDocumentsInner](docs/ImmigrationCaseDetails200ResponseDataInnerDocumentsInner.md)
 - [ImmigrationCaseDetails200ResponseDataInnerProcess](docs/ImmigrationCaseDetails200ResponseDataInnerProcess.md)
 - [ImmigrationDocument200Response](docs/ImmigrationDocument200Response.md)
 - [ImmigrationDocument200ResponseDataInner](docs/ImmigrationDocument200ResponseDataInner.md)
 - [ImmigrationVisaTypes200Response](docs/ImmigrationVisaTypes200Response.md)
 - [ImmigrationVisaTypes200ResponseDataInner](docs/ImmigrationVisaTypes200ResponseDataInner.md)
 - [InlineObject](docs/InlineObject.md)
 - [InputToCreateFileRef](docs/InputToCreateFileRef.md)
 - [InputToCreateFileRefData](docs/InputToCreateFileRefData.md)
 - [InputToCreatePgoTask](docs/InputToCreatePgoTask.md)
 - [InputToDeletePgoTask](docs/InputToDeletePgoTask.md)
 - [InputToPatchContractExternalId](docs/InputToPatchContractExternalId.md)
 - [InputToShieldContract](docs/InputToShieldContract.md)
 - [InputToShieldContractData](docs/InputToShieldContractData.md)
 - [InternalPeople](docs/InternalPeople.md)
 - [InternalPeopleContainer](docs/InternalPeopleContainer.md)
 - [InvitationsOfBasicContract](docs/InvitationsOfBasicContract.md)
 - [InviteLinkContainer](docs/InviteLinkContainer.md)
 - [InviteTeamMemberToSign](docs/InviteTeamMemberToSign.md)
 - [InviteToSignContractRequest](docs/InviteToSignContractRequest.md)
 - [InviteToSignContractRequestData](docs/InviteToSignContractRequestData.md)
 - [Invoice](docs/Invoice.md)
 - [InvoiceAdjustment](docs/InvoiceAdjustment.md)
 - [InvoiceAdjustmentApprover](docs/InvoiceAdjustmentApprover.md)
 - [InvoiceAdjustmentApproversContainer](docs/InvoiceAdjustmentApproversContainer.md)
 - [InvoiceAdjustmentContainer](docs/InvoiceAdjustmentContainer.md)
 - [InvoiceAdjustmentCreated](docs/InvoiceAdjustmentCreated.md)
 - [InvoiceAdjustmentCreatedContainer](docs/InvoiceAdjustmentCreatedContainer.md)
 - [InvoiceAdjustmentListContainer](docs/InvoiceAdjustmentListContainer.md)
 - [InvoiceAdjustmentPendingForApproval](docs/InvoiceAdjustmentPendingForApproval.md)
 - [InvoiceAdjustmentPendingForApprovalApproversInner](docs/InvoiceAdjustmentPendingForApprovalApproversInner.md)
 - [InvoiceAdjustmentReviewToCreate](docs/InvoiceAdjustmentReviewToCreate.md)
 - [InvoiceAdjustmentReviewToCreateContainer](docs/InvoiceAdjustmentReviewToCreateContainer.md)
 - [InvoiceAdjustmentReviewsToCreate](docs/InvoiceAdjustmentReviewsToCreate.md)
 - [InvoiceAdjustmentReviewsToCreateContainer](docs/InvoiceAdjustmentReviewsToCreateContainer.md)
 - [InvoiceAdjustmentSearchContainer](docs/InvoiceAdjustmentSearchContainer.md)
 - [InvoiceAdjustmentSearchContainerContractTypes](docs/InvoiceAdjustmentSearchContainerContractTypes.md)
 - [InvoiceAdjustmentSearchContainerStatuses](docs/InvoiceAdjustmentSearchContainerStatuses.md)
 - [InvoiceAdjustmentSearchContainerTypes](docs/InvoiceAdjustmentSearchContainerTypes.md)
 - [InvoiceAdjustmentStatusEnum](docs/InvoiceAdjustmentStatusEnum.md)
 - [InvoiceAdjustmentToCreate](docs/InvoiceAdjustmentToCreate.md)
 - [InvoiceAdjustmentToCreateContainer](docs/InvoiceAdjustmentToCreateContainer.md)
 - [InvoiceAdjustmentToCreateWithFile](docs/InvoiceAdjustmentToCreateWithFile.md)
 - [InvoiceAdjustmentToUpdate](docs/InvoiceAdjustmentToUpdate.md)
 - [InvoiceAdjustmentToUpdateContainer](docs/InvoiceAdjustmentToUpdateContainer.md)
 - [InvoiceAdjustmentTypeEnum](docs/InvoiceAdjustmentTypeEnum.md)
 - [InvoiceAdjustmentTypeToCreateEnum](docs/InvoiceAdjustmentTypeToCreateEnum.md)
 - [InvoiceContract](docs/InvoiceContract.md)
 - [InvoiceDownloadContainer](docs/InvoiceDownloadContainer.md)
 - [InvoiceDownloadLinkContainer](docs/InvoiceDownloadLinkContainer.md)
 - [InvoiceDownloadObject](docs/InvoiceDownloadObject.md)
 - [InvoiceListContainer](docs/InvoiceListContainer.md)
 - [InvoiceStatusEnum](docs/InvoiceStatusEnum.md)
 - [InvoiceTypeEnum](docs/InvoiceTypeEnum.md)
 - [JobTitle](docs/JobTitle.md)
 - [JobTitleListContainer](docs/JobTitleListContainer.md)
 - [LegalEntityListContainer](docs/LegalEntityListContainer.md)
 - [LegalEntityType](docs/LegalEntityType.md)
 - [LetterRequest](docs/LetterRequest.md)
 - [ListOnboardingTracker200Response](docs/ListOnboardingTracker200Response.md)
 - [ListOnboardingTracker200ResponseDataInner](docs/ListOnboardingTracker200ResponseDataInner.md)
 - [ListOnboardingTracker200ResponseDataInnerAppExperience](docs/ListOnboardingTracker200ResponseDataInnerAppExperience.md)
 - [ListOnboardingTracker200ResponseDataInnerContract](docs/ListOnboardingTracker200ResponseDataInnerContract.md)
 - [ListOnboardingTracker200ResponseDataInnerHrisProfile](docs/ListOnboardingTracker200ResponseDataInnerHrisProfile.md)
 - [ListOnboardingTracker200ResponseDataInnerProgress](docs/ListOnboardingTracker200ResponseDataInnerProgress.md)
 - [ListOnboardingTracker200ResponsePage](docs/ListOnboardingTracker200ResponsePage.md)
 - [ListOnboardingTrackerPaginationParameter](docs/ListOnboardingTrackerPaginationParameter.md)
 - [MaritalStatusEnum](docs/MaritalStatusEnum.md)
 - [MetaDataOfContractToCreate](docs/MetaDataOfContractToCreate.md)
 - [Milestone](docs/Milestone.md)
 - [MilestoneContainer](docs/MilestoneContainer.md)
 - [MilestoneListContainer](docs/MilestoneListContainer.md)
 - [MilestoneProperties](docs/MilestoneProperties.md)
 - [MilestoneReportedBy](docs/MilestoneReportedBy.md)
 - [MilestoneReviewToCreate](docs/MilestoneReviewToCreate.md)
 - [MilestoneReviewToCreateContainer](docs/MilestoneReviewToCreateContainer.md)
 - [MilestoneReviewedBy](docs/MilestoneReviewedBy.md)
 - [MilestoneReviewsToCreate](docs/MilestoneReviewsToCreate.md)
 - [MilestoneReviewsToCreateContainer](docs/MilestoneReviewsToCreateContainer.md)
 - [MilestoneToCreate](docs/MilestoneToCreate.md)
 - [MilestoneToCreateContainer](docs/MilestoneToCreateContainer.md)
 - [MilestoneToCreateFormWithFile](docs/MilestoneToCreateFormWithFile.md)
 - [MonthlyPayment](docs/MonthlyPayment.md)
 - [ONGOINGTIMEBASED](docs/ONGOINGTIMEBASED.md)
 - [OffCyclePayment](docs/OffCyclePayment.md)
 - [OffCyclePaymentContainer](docs/OffCyclePaymentContainer.md)
 - [OffCyclePaymentListContainer](docs/OffCyclePaymentListContainer.md)
 - [OffCyclePaymentReportedBy](docs/OffCyclePaymentReportedBy.md)
 - [OffCyclePaymentToCreate](docs/OffCyclePaymentToCreate.md)
 - [OffCyclePaymentToCreateContainer](docs/OffCyclePaymentToCreateContainer.md)
 - [OffboardingTrackerGet200Response](docs/OffboardingTrackerGet200Response.md)
 - [OffboardingTrackerGet200ResponseDataInner](docs/OffboardingTrackerGet200ResponseDataInner.md)
 - [OffboardingTrackerGet200ResponseDataInnerContract](docs/OffboardingTrackerGet200ResponseDataInnerContract.md)
 - [OffboardingTrackerGet200ResponseDataInnerHrisProfile](docs/OffboardingTrackerGet200ResponseDataInnerHrisProfile.md)
 - [OffboardingTrackerGet200ResponseDataInnerProgress](docs/OffboardingTrackerGet200ResponseDataInnerProgress.md)
 - [OffboardingTrackerGet200ResponsePage](docs/OffboardingTrackerGet200ResponsePage.md)
 - [OffboardingTrackerGetPaginationParameter](docs/OffboardingTrackerGetPaginationParameter.md)
 - [OffboardingTrackerIdGet200Response](docs/OffboardingTrackerIdGet200Response.md)
 - [OffboardingTrackerIdGet200ResponseData](docs/OffboardingTrackerIdGet200ResponseData.md)
 - [OffboardingTrackerIdGet200ResponseDataAppExperience](docs/OffboardingTrackerIdGet200ResponseDataAppExperience.md)
 - [OffboardingTrackerIdGet200ResponseDataContract](docs/OffboardingTrackerIdGet200ResponseDataContract.md)
 - [OffboardingTrackerIdGet200ResponseDataContractEor](docs/OffboardingTrackerIdGet200ResponseDataContractEor.md)
 - [OffboardingTrackerIdGet200ResponseDataContractEorProbationPeriod](docs/OffboardingTrackerIdGet200ResponseDataContractEorProbationPeriod.md)
 - [OffboardingTrackerIdGet200ResponseDataHrisProfile](docs/OffboardingTrackerIdGet200ResponseDataHrisProfile.md)
 - [OffboardingTrackerIdGet200ResponseDataProgress](docs/OffboardingTrackerIdGet200ResponseDataProgress.md)
 - [OffboardingTrackerIdGet200ResponseDataSummaryInner](docs/OffboardingTrackerIdGet200ResponseDataSummaryInner.md)
 - [OffboardingTrackerIdGet200ResponseDataSummaryInnerData](docs/OffboardingTrackerIdGet200ResponseDataSummaryInnerData.md)
 - [OffboardingTrackerIdGet200ResponseDataTermination](docs/OffboardingTrackerIdGet200ResponseDataTermination.md)
 - [OffboardingTrackerIdGet200ResponseDataTerminationInitiatedBy](docs/OffboardingTrackerIdGet200ResponseDataTerminationInitiatedBy.md)
 - [OffboardingTrackerIdGet200ResponseDataTerminationTerminationImpact](docs/OffboardingTrackerIdGet200ResponseDataTerminationTerminationImpact.md)
 - [OnboardingTrackerHrisProfileOidGet200Response](docs/OnboardingTrackerHrisProfileOidGet200Response.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseData](docs/OnboardingTrackerHrisProfileOidGet200ResponseData.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseDataChecklist](docs/OnboardingTrackerHrisProfileOidGet200ResponseDataChecklist.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseDataChecklistStepsInner](docs/OnboardingTrackerHrisProfileOidGet200ResponseDataChecklistStepsInner.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseDataContract](docs/OnboardingTrackerHrisProfileOidGet200ResponseDataContract.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseDataHrisProfile](docs/OnboardingTrackerHrisProfileOidGet200ResponseDataHrisProfile.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseDataProfile](docs/OnboardingTrackerHrisProfileOidGet200ResponseDataProfile.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseDataProgress](docs/OnboardingTrackerHrisProfileOidGet200ResponseDataProgress.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseDataStepperInner](docs/OnboardingTrackerHrisProfileOidGet200ResponseDataStepperInner.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseDataStepperInnerData](docs/OnboardingTrackerHrisProfileOidGet200ResponseDataStepperInnerData.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseDataStepperInnerDataEmailsInner](docs/OnboardingTrackerHrisProfileOidGet200ResponseDataStepperInnerDataEmailsInner.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseDataStepperInnerDataEmailsInnerMeta](docs/OnboardingTrackerHrisProfileOidGet200ResponseDataStepperInnerDataEmailsInnerMeta.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseDataSummaryInner](docs/OnboardingTrackerHrisProfileOidGet200ResponseDataSummaryInner.md)
 - [OnboardingTrackerHrisProfileOidGet200ResponseDataSummaryInnerData](docs/OnboardingTrackerHrisProfileOidGet200ResponseDataSummaryInnerData.md)
 - [OrgStructureToCreateContainer](docs/OrgStructureToCreateContainer.md)
 - [OrgStructureToCreateContainerData](docs/OrgStructureToCreateContainerData.md)
 - [OrgStructureToCreateContainerDataTeamsInner](docs/OrgStructureToCreateContainerDataTeamsInner.md)
 - [OrgStructureToUpdateContainer](docs/OrgStructureToUpdateContainer.md)
 - [OrgStructureToUpdateContainerData](docs/OrgStructureToUpdateContainerData.md)
 - [OrganizationListContainer](docs/OrganizationListContainer.md)
 - [OutputToCreateFileRef](docs/OutputToCreateFileRef.md)
 - [OutputToCreateFileRefContainer](docs/OutputToCreateFileRefContainer.md)
 - [PAYASYOUGOTIMEBASED](docs/PAYASYOUGOTIMEBASED.md)
 - [PAYASYOUGOTIMEBASEDAllOfClient](docs/PAYASYOUGOTIMEBASEDAllOfClient.md)
 - [PAYASYOUGOTIMEBASEDAllOfClientLegalEntity](docs/PAYASYOUGOTIMEBASEDAllOfClientLegalEntity.md)
 - [PAYASYOUGOTIMEBASEDAllOfClientTeam](docs/PAYASYOUGOTIMEBASEDAllOfClientTeam.md)
 - [PAYASYOUGOTIMEBASEDAllOfClientTeamId](docs/PAYASYOUGOTIMEBASEDAllOfClientTeamId.md)
 - [PAYASYOUGOTIMEBASEDAllOfCompensationDetails](docs/PAYASYOUGOTIMEBASEDAllOfCompensationDetails.md)
 - [PAYASYOUGOTIMEBASEDAllOfJobTitle](docs/PAYASYOUGOTIMEBASEDAllOfJobTitle.md)
 - [PAYASYOUGOTIMEBASEDAllOfMeta](docs/PAYASYOUGOTIMEBASEDAllOfMeta.md)
 - [PAYASYOUGOTIMEBASEDAllOfSeniority](docs/PAYASYOUGOTIMEBASEDAllOfSeniority.md)
 - [PAYASYOUGOTIMEBASEDAllOfWorker](docs/PAYASYOUGOTIMEBASEDAllOfWorker.md)
 - [PAYGMILESTONES](docs/PAYGMILESTONES.md)
 - [PAYGTASKS](docs/PAYGTASKS.md)
 - [PAYGTASKSAllOfCompensationDetails](docs/PAYGTASKSAllOfCompensationDetails.md)
 - [PageInfo](docs/PageInfo.md)
 - [PageInfoWithoutCursor](docs/PageInfoWithoutCursor.md)
 - [PageInfoWithoutCursorNew](docs/PageInfoWithoutCursorNew.md)
 - [PatchEORBankAccount201Response](docs/PatchEORBankAccount201Response.md)
 - [PatchEORBankAccount201ResponseData](docs/PatchEORBankAccount201ResponseData.md)
 - [PatchEORBankAccountRequest](docs/PatchEORBankAccountRequest.md)
 - [PatchEORBankAccountRequestDataInner](docs/PatchEORBankAccountRequestDataInner.md)
 - [PatchGpBankAccount200Response](docs/PatchGpBankAccount200Response.md)
 - [PatchGpBankAccount200ResponseData](docs/PatchGpBankAccount200ResponseData.md)
 - [PatchWebhookRequest](docs/PatchWebhookRequest.md)
 - [Payment](docs/Payment.md)
 - [PaymentBreakDown](docs/PaymentBreakDown.md)
 - [PaymentBreakDownContainer](docs/PaymentBreakDownContainer.md)
 - [PaymentListContainer](docs/PaymentListContainer.md)
 - [PaymentMethod](docs/PaymentMethod.md)
 - [PaymentMethodEnum](docs/PaymentMethodEnum.md)
 - [PaymentObject](docs/PaymentObject.md)
 - [PaymentStatementInitiatedWebhook](docs/PaymentStatementInitiatedWebhook.md)
 - [PaymentStatusEnum](docs/PaymentStatusEnum.md)
 - [PaymentWorker](docs/PaymentWorker.md)
 - [PaymentsDetailedReportContainer](docs/PaymentsDetailedReportContainer.md)
 - [PaymentsDetailedReportContainerDataInner](docs/PaymentsDetailedReportContainerDataInner.md)
 - [PaymentsDetailedReportContainerDataInnerContract](docs/PaymentsDetailedReportContainerDataInnerContract.md)
 - [PaymentsDetailedReportContainerDataInnerInvoice](docs/PaymentsDetailedReportContainerDataInnerInvoice.md)
 - [PaymentsDetailedReportContainerDataInnerLineItem](docs/PaymentsDetailedReportContainerDataInnerLineItem.md)
 - [PaymentsDetailedReportContainerDataInnerPayment](docs/PaymentsDetailedReportContainerDataInnerPayment.md)
 - [PayrollAdjustment](docs/PayrollAdjustment.md)
 - [PayslipDownloadUrl](docs/PayslipDownloadUrl.md)
 - [Payslips](docs/Payslips.md)
 - [PensionEORContractToCreate](docs/PensionEORContractToCreate.md)
 - [PensionProvider](docs/PensionProvider.md)
 - [PeopleByIdContainer](docs/PeopleByIdContainer.md)
 - [PeopleByIdContainerData](docs/PeopleByIdContainerData.md)
 - [PeopleClientLegalEntity](docs/PeopleClientLegalEntity.md)
 - [PeopleContainer](docs/PeopleContainer.md)
 - [PeopleCustomField](docs/PeopleCustomField.md)
 - [PeopleMe](docs/PeopleMe.md)
 - [PeoplePayment](docs/PeoplePayment.md)
 - [PeoplePersonalContainer](docs/PeoplePersonalContainer.md)
 - [PeoplePersonalContainerData](docs/PeoplePersonalContainerData.md)
 - [PeoplePersonalContainerDataAddressesInner](docs/PeoplePersonalContainerDataAddressesInner.md)
 - [PeoplePersonalContainerDataDemographics](docs/PeoplePersonalContainerDataDemographics.md)
 - [PeoplePersonalContainerDataDemographicsEthnicity](docs/PeoplePersonalContainerDataDemographicsEthnicity.md)
 - [PeoplePersonalContainerDataDemographicsGender](docs/PeoplePersonalContainerDataDemographicsGender.md)
 - [PeoplePersonalContainerDataEmergencyContactsInner](docs/PeoplePersonalContainerDataEmergencyContactsInner.md)
 - [PeoplePersonalContainerDataEmergencyContactsInnerPreferredLanguage](docs/PeoplePersonalContainerDataEmergencyContactsInnerPreferredLanguage.md)
 - [PeoplePersonalContainerDataKyc](docs/PeoplePersonalContainerDataKyc.md)
 - [PeoplePersonalContainerDataNationalitiesInner](docs/PeoplePersonalContainerDataNationalitiesInner.md)
 - [PeoplePersonalContainerDataOoo](docs/PeoplePersonalContainerDataOoo.md)
 - [PeoplePersonalContainerDataPhoneNumbersInner](docs/PeoplePersonalContainerDataPhoneNumbersInner.md)
 - [PeoplePersonalUpdatedContainer](docs/PeoplePersonalUpdatedContainer.md)
 - [PeopleSortByEnum](docs/PeopleSortByEnum.md)
 - [PeopleTimeOffContainer](docs/PeopleTimeOffContainer.md)
 - [PgoTask](docs/PgoTask.md)
 - [PgoTaskReviewsByIdToCreate](docs/PgoTaskReviewsByIdToCreate.md)
 - [PgoTaskReviewsToCreate](docs/PgoTaskReviewsToCreate.md)
 - [PgoTaskToCreate](docs/PgoTaskToCreate.md)
 - [PgoTaskToDelete](docs/PgoTaskToDelete.md)
 - [Policies](docs/Policies.md)
 - [Policy](docs/Policy.md)
 - [Post401kEnrollmentsDefinition200Response](docs/Post401kEnrollmentsDefinition200Response.md)
 - [Post401kEnrollmentsDefinitionRequest](docs/Post401kEnrollmentsDefinitionRequest.md)
 - [Post401kPlansDefinition200Response](docs/Post401kPlansDefinition200Response.md)
 - [Post401kPlansDefinitionRequest](docs/Post401kPlansDefinitionRequest.md)
 - [Post401kPlansDefinitionRequestContributionValueForMatchRateInner](docs/Post401kPlansDefinitionRequestContributionValueForMatchRateInner.md)
 - [Post401kSingleDeductionDefinition200Response](docs/Post401kSingleDeductionDefinition200Response.md)
 - [Post401kSingleDeductionDefinitionRequest](docs/Post401kSingleDeductionDefinitionRequest.md)
 - [PremiumResultAdded](docs/PremiumResultAdded.md)
 - [PremiumResultAddedContainer](docs/PremiumResultAddedContainer.md)
 - [PremiumResultAddedMisclassificationGuarantee](docs/PremiumResultAddedMisclassificationGuarantee.md)
 - [PremiumResultAddedPenalties](docs/PremiumResultAddedPenalties.md)
 - [PremiumResultAddedThirdPartyLiabilities](docs/PremiumResultAddedThirdPartyLiabilities.md)
 - [PremiumToAdd](docs/PremiumToAdd.md)
 - [PremiumToAddContainer](docs/PremiumToAddContainer.md)
 - [ProfileEntitlements](docs/ProfileEntitlements.md)
 - [ProfileReference](docs/ProfileReference.md)
 - [ProfileTypeEnum](docs/ProfileTypeEnum.md)
 - [Profiles200Response](docs/Profiles200Response.md)
 - [ProfilesRequest](docs/ProfilesRequest.md)
 - [ProfilesRequestData](docs/ProfilesRequestData.md)
 - [PublicToken](docs/PublicToken.md)
 - [PublicTokenCreatedContainer](docs/PublicTokenCreatedContainer.md)
 - [Put401kEnrollmentsDefinition200Response](docs/Put401kEnrollmentsDefinition200Response.md)
 - [Put401kEnrollmentsDefinitionRequest](docs/Put401kEnrollmentsDefinitionRequest.md)
 - [Put401kPlansDefinition200Response](docs/Put401kPlansDefinition200Response.md)
 - [Put401kPlansDefinitionRequest](docs/Put401kPlansDefinitionRequest.md)
 - [Put401kPlansDefinitionRequestContributionValueForMatchRateInner](docs/Put401kPlansDefinitionRequestContributionValueForMatchRateInner.md)
 - [Put401kPlansDefinitionRequestDetails](docs/Put401kPlansDefinitionRequestDetails.md)
 - [RequestBodyToCreatePgoTaskReviewsByIdReviewsContainer](docs/RequestBodyToCreatePgoTaskReviewsByIdReviewsContainer.md)
 - [RequestBodyToCreatePgoTaskReviewsReviewsContainer](docs/RequestBodyToCreatePgoTaskReviewsReviewsContainer.md)
 - [RequestCustomVerificationLetterContainer](docs/RequestCustomVerificationLetterContainer.md)
 - [RequestEorContractResignationMadeByEmployee200Response](docs/RequestEorContractResignationMadeByEmployee200Response.md)
 - [RequestEorContractResignationMadeByEmployee401ResponseInner](docs/RequestEorContractResignationMadeByEmployee401ResponseInner.md)
 - [RequestEorContractResignationMadeByEmployeeRequest](docs/RequestEorContractResignationMadeByEmployeeRequest.md)
 - [RequestExerciseEquity201Response](docs/RequestExerciseEquity201Response.md)
 - [RequestExerciseEquityRequest](docs/RequestExerciseEquityRequest.md)
 - [RequestTermination201Response](docs/RequestTermination201Response.md)
 - [RequestTermination201ResponseData](docs/RequestTermination201ResponseData.md)
 - [RequestTerminationRequest](docs/RequestTerminationRequest.md)
 - [RequestTerminationRequestData](docs/RequestTerminationRequestData.md)
 - [RequestTerminationRequestDataSeverance](docs/RequestTerminationRequestDataSeverance.md)
 - [RequestTerminationRequestDataSeveranceOneOf](docs/RequestTerminationRequestDataSeveranceOneOf.md)
 - [RequestTerminationRequestDataSeveranceOneOf1](docs/RequestTerminationRequestDataSeveranceOneOf1.md)
 - [RequesterTimeOff](docs/RequesterTimeOff.md)
 - [ResponseBodyForAdjustmentById](docs/ResponseBodyForAdjustmentById.md)
 - [RetrieveDeelInvoices200Response](docs/RetrieveDeelInvoices200Response.md)
 - [RetrieveDeelInvoices200ResponseDataInner](docs/RetrieveDeelInvoices200ResponseDataInner.md)
 - [RetrieveDeelInvoices200ResponsePage](docs/RetrieveDeelInvoices200ResponsePage.md)
 - [RoleToCreateContainer](docs/RoleToCreateContainer.md)
 - [RoleToCreateContainerData](docs/RoleToCreateContainerData.md)
 - [RoleToUpdateContainer](docs/RoleToUpdateContainer.md)
 - [RoleToUpdateContainerData](docs/RoleToUpdateContainerData.md)
 - [RootSchema](docs/RootSchema.md)
 - [RootSchema1](docs/RootSchema1.md)
 - [SalaryFrequencyScaleEnum](docs/SalaryFrequencyScaleEnum.md)
 - [Seniority](docs/Seniority.md)
 - [SeniorityListContainer](docs/SeniorityListContainer.md)
 - [SeniorityRequired](docs/SeniorityRequired.md)
 - [SignContract201Response](docs/SignContract201Response.md)
 - [SignContract201ResponseData](docs/SignContract201ResponseData.md)
 - [SignContractRequest](docs/SignContractRequest.md)
 - [SignContractRequestData](docs/SignContractRequestData.md)
 - [SignContractRequestDataContractTemplateId](docs/SignContractRequestDataContractTemplateId.md)
 - [SignaturesOfBasicContract](docs/SignaturesOfBasicContract.md)
 - [SignaturesOfContract](docs/SignaturesOfContract.md)
 - [SortDirEnum](docs/SortDirEnum.md)
 - [StateOfCountry](docs/StateOfCountry.md)
 - [TaskCreated](docs/TaskCreated.md)
 - [TaskCreatedContainer](docs/TaskCreatedContainer.md)
 - [TaskListContainer](docs/TaskListContainer.md)
 - [Team](docs/Team.md)
 - [TeamListContainer](docs/TeamListContainer.md)
 - [TeamOfBasicContract](docs/TeamOfBasicContract.md)
 - [TeamOfContract](docs/TeamOfContract.md)
 - [TerminateContract201Response](docs/TerminateContract201Response.md)
 - [TerminateContract201ResponseData](docs/TerminateContract201ResponseData.md)
 - [TerminateContractRequest](docs/TerminateContractRequest.md)
 - [TerminateContractRequestData](docs/TerminateContractRequestData.md)
 - [TheWorkerForThePayment](docs/TheWorkerForThePayment.md)
 - [TimeOffCreateResponse](docs/TimeOffCreateResponse.md)
 - [TimeOffDaily](docs/TimeOffDaily.md)
 - [TimeOffDate](docs/TimeOffDate.md)
 - [TimeOffRequestBodyCommonProperties](docs/TimeOffRequestBodyCommonProperties.md)
 - [TimeOffResponseCommon](docs/TimeOffResponseCommon.md)
 - [TimeOffType](docs/TimeOffType.md)
 - [TimeOffUpdateResponse](docs/TimeOffUpdateResponse.md)
 - [TimeOffsQueryResponseSchema](docs/TimeOffsQueryResponseSchema.md)
 - [TimeTrackingShiftCreatedContainer](docs/TimeTrackingShiftCreatedContainer.md)
 - [TimeTrackingShiftCreatedResponse](docs/TimeTrackingShiftCreatedResponse.md)
 - [TimeTrackingShiftDetailsContainer](docs/TimeTrackingShiftDetailsContainer.md)
 - [TimeTrackingShiftListContainer](docs/TimeTrackingShiftListContainer.md)
 - [TimeTrackingShiftMetaSchema](docs/TimeTrackingShiftMetaSchema.md)
 - [TimeTrackingShiftMetaSchemaBreaksInner](docs/TimeTrackingShiftMetaSchemaBreaksInner.md)
 - [TimeTrackingShiftMetaSchemaBreaksInnerEnd](docs/TimeTrackingShiftMetaSchemaBreaksInnerEnd.md)
 - [TimeTrackingShiftMetaSchemaBreaksInnerStart](docs/TimeTrackingShiftMetaSchemaBreaksInnerStart.md)
 - [TimeTrackingShiftMetaSchemaEnd](docs/TimeTrackingShiftMetaSchemaEnd.md)
 - [TimeTrackingShiftMetaSchemaStart](docs/TimeTrackingShiftMetaSchemaStart.md)
 - [TimeTrackingShiftRateCreatedContainer](docs/TimeTrackingShiftRateCreatedContainer.md)
 - [TimeTrackingShiftRateDetailsContainer](docs/TimeTrackingShiftRateDetailsContainer.md)
 - [TimeTrackingShiftRateListContainer](docs/TimeTrackingShiftRateListContainer.md)
 - [TimeTrackingShiftRateResponse](docs/TimeTrackingShiftRateResponse.md)
 - [TimeTrackingShiftRateType](docs/TimeTrackingShiftRateType.md)
 - [TimeTrackingShiftRateUpdatedContainer](docs/TimeTrackingShiftRateUpdatedContainer.md)
 - [TimeTrackingShiftSummarySchema](docs/TimeTrackingShiftSummarySchema.md)
 - [TimeTrackingShiftUpdatedContainer](docs/TimeTrackingShiftUpdatedContainer.md)
 - [TimeoffReview](docs/TimeoffReview.md)
 - [TimeoffReviewInternal](docs/TimeoffReviewInternal.md)
 - [TimeoffToReviewContainer](docs/TimeoffToReviewContainer.md)
 - [TimeoffToReviewInternalContainer](docs/TimeoffToReviewInternalContainer.md)
 - [TimeoffTypeListContainer](docs/TimeoffTypeListContainer.md)
 - [TimeoffsAttachmentsItem](docs/TimeoffsAttachmentsItem.md)
 - [TimeoffsProfile](docs/TimeoffsProfile.md)
 - [TimeoffsStatusEnum](docs/TimeoffsStatusEnum.md)
 - [TimeoffsTypeEnum](docs/TimeoffsTypeEnum.md)
 - [Timesheet](docs/Timesheet.md)
 - [TimesheetApprover](docs/TimesheetApprover.md)
 - [TimesheetApproversContainer](docs/TimesheetApproversContainer.md)
 - [TimesheetContainer](docs/TimesheetContainer.md)
 - [TimesheetIdItemsInner](docs/TimesheetIdItemsInner.md)
 - [TimesheetListContainer](docs/TimesheetListContainer.md)
 - [TimesheetReviewToCreate](docs/TimesheetReviewToCreate.md)
 - [TimesheetReviewToCreateContainer](docs/TimesheetReviewToCreateContainer.md)
 - [TimesheetReviewsToCreate](docs/TimesheetReviewsToCreate.md)
 - [TimesheetReviewsToCreateContainer](docs/TimesheetReviewsToCreateContainer.md)
 - [TimesheetSearchContainer](docs/TimesheetSearchContainer.md)
 - [TimesheetSearchContainerStatuses](docs/TimesheetSearchContainerStatuses.md)
 - [TimesheetSearchContainerTypes](docs/TimesheetSearchContainerTypes.md)
 - [TimesheetSharedProperties](docs/TimesheetSharedProperties.md)
 - [TimesheetStatusEnum](docs/TimesheetStatusEnum.md)
 - [TimesheetToCreate](docs/TimesheetToCreate.md)
 - [TimesheetToCreateContainer](docs/TimesheetToCreateContainer.md)
 - [TimesheetToCreateContainerWithFile](docs/TimesheetToCreateContainerWithFile.md)
 - [TimesheetToCreateWithFile](docs/TimesheetToCreateWithFile.md)
 - [TimesheetToUpdate](docs/TimesheetToUpdate.md)
 - [TimesheetToUpdateContainer](docs/TimesheetToUpdateContainer.md)
 - [TimesheetTypeEnum](docs/TimesheetTypeEnum.md)
 - [UninviteToSignContract200Response](docs/UninviteToSignContract200Response.md)
 - [UninviteToSignContract200ResponseData](docs/UninviteToSignContract200ResponseData.md)
 - [UpdateAdjustment200Response](docs/UpdateAdjustment200Response.md)
 - [UpdateAdjustment200ResponseData](docs/UpdateAdjustment200ResponseData.md)
 - [UpdateAdjustmentRequestData](docs/UpdateAdjustmentRequestData.md)
 - [UpdateAutoWithdrawSettingRequest](docs/UpdateAutoWithdrawSettingRequest.md)
 - [UpdateAutoWithdrawSettingRequestData](docs/UpdateAutoWithdrawSettingRequestData.md)
 - [UpdateBankTransferMethod200Response](docs/UpdateBankTransferMethod200Response.md)
 - [UpdateBankTransferMethod200ResponseData](docs/UpdateBankTransferMethod200ResponseData.md)
 - [UpdateEorContract200Response](docs/UpdateEorContract200Response.md)
 - [UpdateEorContract400Response](docs/UpdateEorContract400Response.md)
 - [UpdateEorContract400ResponseError](docs/UpdateEorContract400ResponseError.md)
 - [UpdateEorContract403Response](docs/UpdateEorContract403Response.md)
 - [UpdateEorContract403ResponseError](docs/UpdateEorContract403ResponseError.md)
 - [UpdateEorContract404Response](docs/UpdateEorContract404Response.md)
 - [UpdateEorContract404ResponseError](docs/UpdateEorContract404ResponseError.md)
 - [UpdateEorContract500Response](docs/UpdateEorContract500Response.md)
 - [UpdateEorContract500ResponseError](docs/UpdateEorContract500ResponseError.md)
 - [UpdateEorContractRequest](docs/UpdateEorContractRequest.md)
 - [UpdateEorContractRequestData](docs/UpdateEorContractRequestData.md)
 - [UpdateEorContractRequestDataBenefitsInner](docs/UpdateEorContractRequestDataBenefitsInner.md)
 - [UpdateEorContractRequestDataEmployeeAddress](docs/UpdateEorContractRequestDataEmployeeAddress.md)
 - [UpdateEorContractRequestDataQuoteAdditionalFields](docs/UpdateEorContractRequestDataQuoteAdditionalFields.md)
 - [UpdateEorContractRequestDataWorkEligibility](docs/UpdateEorContractRequestDataWorkEligibility.md)
 - [UpdateGPEmployeeAddress201Response](docs/UpdateGPEmployeeAddress201Response.md)
 - [UpdateGPEmployeeAddress201ResponseData](docs/UpdateGPEmployeeAddress201ResponseData.md)
 - [UpdateGPEmployeeAddressRequest](docs/UpdateGPEmployeeAddressRequest.md)
 - [UpdateGPEmployeeAddressRequestData](docs/UpdateGPEmployeeAddressRequestData.md)
 - [UpdateGPEmployeeCompensation200Response](docs/UpdateGPEmployeeCompensation200Response.md)
 - [UpdateGPEmployeeCompensation200ResponseData](docs/UpdateGPEmployeeCompensation200ResponseData.md)
 - [UpdateGPEmployeeCompensationRequest](docs/UpdateGPEmployeeCompensationRequest.md)
 - [UpdateGPEmployeeCompensationRequestData](docs/UpdateGPEmployeeCompensationRequestData.md)
 - [UpdateGPEmployeeInformationRequest](docs/UpdateGPEmployeeInformationRequest.md)
 - [UpdateGPEmployeeInformationRequestData](docs/UpdateGPEmployeeInformationRequestData.md)
 - [UpdateGPEmployeePto200Response](docs/UpdateGPEmployeePto200Response.md)
 - [UpdateGPEmployeePto200ResponseData](docs/UpdateGPEmployeePto200ResponseData.md)
 - [UpdateGPEmployeePtoRequest](docs/UpdateGPEmployeePtoRequest.md)
 - [UpdateGPEmployeePtoRequestData](docs/UpdateGPEmployeePtoRequestData.md)
 - [UpdateInvoiceAdjustment200Response](docs/UpdateInvoiceAdjustment200Response.md)
 - [UpdateInvoiceAdjustment200ResponseData](docs/UpdateInvoiceAdjustment200ResponseData.md)
 - [UpdateInvoiceAdjustmentByIdRequest](docs/UpdateInvoiceAdjustmentByIdRequest.md)
 - [UpdateInvoiceAdjustmentRequest](docs/UpdateInvoiceAdjustmentRequest.md)
 - [UpdateOrgStructureByExternalIdRequest](docs/UpdateOrgStructureByExternalIdRequest.md)
 - [UpdateOrgStructureByExternalIdRequestData](docs/UpdateOrgStructureByExternalIdRequestData.md)
 - [UpdateOrgStructureRequest](docs/UpdateOrgStructureRequest.md)
 - [UpdateOrgStructureRequestData](docs/UpdateOrgStructureRequestData.md)
 - [UpdateOrganizationRole200Response](docs/UpdateOrganizationRole200Response.md)
 - [UpdateOrganizationRoleRequest](docs/UpdateOrganizationRoleRequest.md)
 - [UpdateOrganizationRoleRequestData](docs/UpdateOrganizationRoleRequestData.md)
 - [UpdatePeopleDepartment200Response](docs/UpdatePeopleDepartment200Response.md)
 - [UpdatePeopleDepartment200ResponseData](docs/UpdatePeopleDepartment200ResponseData.md)
 - [UpdatePeopleDepartmentRequest](docs/UpdatePeopleDepartmentRequest.md)
 - [UpdatePeopleDepartmentRequestData](docs/UpdatePeopleDepartmentRequestData.md)
 - [UpdatePeoplePersonalInformationByExternalIdRequest](docs/UpdatePeoplePersonalInformationByExternalIdRequest.md)
 - [UpdatePeoplePersonalInformationByExternalIdRequestData](docs/UpdatePeoplePersonalInformationByExternalIdRequestData.md)
 - [UpdatePeoplePersonalInformationByIdRequest](docs/UpdatePeoplePersonalInformationByIdRequest.md)
 - [UpdatePeoplePersonalInformationByIdRequestData](docs/UpdatePeoplePersonalInformationByIdRequestData.md)
 - [UpdatePeoplePersonalInformationByIdRequestDataPhoneNumbersInner](docs/UpdatePeoplePersonalInformationByIdRequestDataPhoneNumbersInner.md)
 - [UpdatePeopleWorkingLocationRequest](docs/UpdatePeopleWorkingLocationRequest.md)
 - [UpdatePeopleWorkingLocationRequestData](docs/UpdatePeopleWorkingLocationRequestData.md)
 - [UpdateShift200Response](docs/UpdateShift200Response.md)
 - [UpdateShift200ResponseData](docs/UpdateShift200ResponseData.md)
 - [UpdateShift200ResponseDataMeta](docs/UpdateShift200ResponseDataMeta.md)
 - [UpdateShift200ResponseDataMetaBreaksInner](docs/UpdateShift200ResponseDataMetaBreaksInner.md)
 - [UpdateShift200ResponseDataMetaBreaksInnerEnd](docs/UpdateShift200ResponseDataMetaBreaksInnerEnd.md)
 - [UpdateShift200ResponseDataMetaBreaksInnerStart](docs/UpdateShift200ResponseDataMetaBreaksInnerStart.md)
 - [UpdateShift200ResponseDataMetaEnd](docs/UpdateShift200ResponseDataMetaEnd.md)
 - [UpdateShift200ResponseDataMetaStart](docs/UpdateShift200ResponseDataMetaStart.md)
 - [UpdateShift200ResponseDataSummary](docs/UpdateShift200ResponseDataSummary.md)
 - [UpdateShiftRate200Response](docs/UpdateShiftRate200Response.md)
 - [UpdateShiftRate200ResponseData](docs/UpdateShiftRate200ResponseData.md)
 - [UpdateShiftRate400Response](docs/UpdateShiftRate400Response.md)
 - [UpdateShiftRateRequest](docs/UpdateShiftRateRequest.md)
 - [UpdateShiftRateRequestData](docs/UpdateShiftRateRequestData.md)
 - [UpdateShiftRequest](docs/UpdateShiftRequest.md)
 - [UpdateShiftRequestData](docs/UpdateShiftRequestData.md)
 - [UpdateShiftRequestDataMeta](docs/UpdateShiftRequestDataMeta.md)
 - [UpdateShiftRequestDataMetaBreaksInner](docs/UpdateShiftRequestDataMetaBreaksInner.md)
 - [UpdateShiftRequestDataMetaBreaksInnerEnd](docs/UpdateShiftRequestDataMetaBreaksInnerEnd.md)
 - [UpdateShiftRequestDataMetaBreaksInnerStart](docs/UpdateShiftRequestDataMetaBreaksInnerStart.md)
 - [UpdateShiftRequestDataMetaEnd](docs/UpdateShiftRequestDataMetaEnd.md)
 - [UpdateShiftRequestDataMetaStart](docs/UpdateShiftRequestDataMetaStart.md)
 - [UpdateTimeOff200Response](docs/UpdateTimeOff200Response.md)
 - [UpdateTimeOff200ResponseTimeOff](docs/UpdateTimeOff200ResponseTimeOff.md)
 - [UpdateTimeOff200ResponseTimeOffRecipientProfile](docs/UpdateTimeOff200ResponseTimeOffRecipientProfile.md)
 - [UpdateTimeOff200ResponseTimeOffTimeOffDailiesInner](docs/UpdateTimeOff200ResponseTimeOffTimeOffDailiesInner.md)
 - [UpdateTimeOffRequest](docs/UpdateTimeOffRequest.md)
 - [UpdateTimeOffRequestBody](docs/UpdateTimeOffRequestBody.md)
 - [UpdateTimeOffRequestBodyData](docs/UpdateTimeOffRequestBodyData.md)
 - [UpdateTimeOffRequestData](docs/UpdateTimeOffRequestData.md)
 - [UpdateTimeOffRequestDataAttachmentsInner](docs/UpdateTimeOffRequestDataAttachmentsInner.md)
 - [UpdateTimeOffRequestDataDatesInner](docs/UpdateTimeOffRequestDataDatesInner.md)
 - [UpdateTimeTrackingShiftContainer](docs/UpdateTimeTrackingShiftContainer.md)
 - [UpdateTimeTrackingShiftContainerData](docs/UpdateTimeTrackingShiftContainerData.md)
 - [UpdateTimeTrackingShiftRateContainer](docs/UpdateTimeTrackingShiftRateContainer.md)
 - [UpdateTimeTrackingShiftRateContainerData](docs/UpdateTimeTrackingShiftRateContainerData.md)
 - [UpdateTimesheetByIdRequest](docs/UpdateTimesheetByIdRequest.md)
 - [UpdateTimesheetByIdRequestData](docs/UpdateTimesheetByIdRequestData.md)
 - [UpdateWorkerDepartment](docs/UpdateWorkerDepartment.md)
 - [UpdateWorkerDepartmentContainer](docs/UpdateWorkerDepartmentContainer.md)
 - [UpdateWorkerRelationType204Response](docs/UpdateWorkerRelationType204Response.md)
 - [UpdateWorkerRelationType204ResponseData](docs/UpdateWorkerRelationType204ResponseData.md)
 - [UpdateWorkerRelationTypeContainer](docs/UpdateWorkerRelationTypeContainer.md)
 - [UpdateWorkerRelationTypeContainerData](docs/UpdateWorkerRelationTypeContainerData.md)
 - [UpdateWorkerRelationTypeExternalId204Response](docs/UpdateWorkerRelationTypeExternalId204Response.md)
 - [UpdateWorkerRelationTypeExternalId204ResponseData](docs/UpdateWorkerRelationTypeExternalId204ResponseData.md)
 - [UpdateWorkerRelationTypeExternalIdContainer](docs/UpdateWorkerRelationTypeExternalIdContainer.md)
 - [UpdateWorkerRelationTypeExternalIdResponseContainer](docs/UpdateWorkerRelationTypeExternalIdResponseContainer.md)
 - [UpdateWorkerRelationTypeExternalIdResponseContainerData](docs/UpdateWorkerRelationTypeExternalIdResponseContainerData.md)
 - [UpdateWorkerRelationTypeRequest](docs/UpdateWorkerRelationTypeRequest.md)
 - [UpdateWorkerRelationTypeRequestData](docs/UpdateWorkerRelationTypeRequestData.md)
 - [UpdateWorkerRelationTypeResponseContainer](docs/UpdateWorkerRelationTypeResponseContainer.md)
 - [UpdateWorkerWorkingLocation](docs/UpdateWorkerWorkingLocation.md)
 - [UpdateWorkerWorkingLocationContainer](docs/UpdateWorkerWorkingLocationContainer.md)
 - [UpdatedExerciseEquityContainer](docs/UpdatedExerciseEquityContainer.md)
 - [UpdatedRoleContainer](docs/UpdatedRoleContainer.md)
 - [UploadEmployeeComplianceDocumentContainer](docs/UploadEmployeeComplianceDocumentContainer.md)
 - [UploadEmployeeComplianceDocumentContainerData](docs/UploadEmployeeComplianceDocumentContainerData.md)
 - [UpsertChildWorkerRelationsContainer](docs/UpsertChildWorkerRelationsContainer.md)
 - [UpsertChildWorkerRelationsContainerData](docs/UpsertChildWorkerRelationsContainerData.md)
 - [UpsertChildWorkerRelationsExternalIdContainer](docs/UpsertChildWorkerRelationsExternalIdContainer.md)
 - [UpsertChildWorkerRelationsExternalIdContainerData](docs/UpsertChildWorkerRelationsExternalIdContainerData.md)
 - [UpsertChildWorkerRelationsExternalIdContainerDataChildHrisProfileIdsInner](docs/UpsertChildWorkerRelationsExternalIdContainerDataChildHrisProfileIdsInner.md)
 - [UpsertChildWorkerRelationsExternalIdContainerDataChildHrisProfileIdsInnerOneOf](docs/UpsertChildWorkerRelationsExternalIdContainerDataChildHrisProfileIdsInnerOneOf.md)
 - [UpsertChildWorkerRelationsExternalIdRequest](docs/UpsertChildWorkerRelationsExternalIdRequest.md)
 - [UpsertChildWorkerRelationsExternalIdRequestData](docs/UpsertChildWorkerRelationsExternalIdRequestData.md)
 - [UpsertChildWorkerRelationsExternalIdRequestDataChildHrisProfileIdsInner](docs/UpsertChildWorkerRelationsExternalIdRequestDataChildHrisProfileIdsInner.md)
 - [UpsertChildWorkerRelationsExternalIdRequestDataChildHrisProfileIdsInnerOneOf](docs/UpsertChildWorkerRelationsExternalIdRequestDataChildHrisProfileIdsInnerOneOf.md)
 - [UpsertChildWorkerRelationsRequest](docs/UpsertChildWorkerRelationsRequest.md)
 - [UpsertChildWorkerRelationsRequestData](docs/UpsertChildWorkerRelationsRequestData.md)
 - [UpsertCustomFieldValueFromContractsRequest](docs/UpsertCustomFieldValueFromContractsRequest.md)
 - [UpsertCustomFieldValueFromContractsRequestData](docs/UpsertCustomFieldValueFromContractsRequestData.md)
 - [UpsertCustomFieldValueFromContractsRequestDataAnyOf](docs/UpsertCustomFieldValueFromContractsRequestDataAnyOf.md)
 - [UpsertCustomFieldValueFromContractsRequestDataAnyOf1](docs/UpsertCustomFieldValueFromContractsRequestDataAnyOf1.md)
 - [UpsertCustomFieldValueFromContractsRequestDataAnyOf2](docs/UpsertCustomFieldValueFromContractsRequestDataAnyOf2.md)
 - [UpsertCustomFieldValueFromContractsRequestDataAnyOf3](docs/UpsertCustomFieldValueFromContractsRequestDataAnyOf3.md)
 - [UpsertCustomFieldValueFromContractsRequestDataAnyOf4](docs/UpsertCustomFieldValueFromContractsRequestDataAnyOf4.md)
 - [UpsertCustomFieldValueFromWorkerRequest](docs/UpsertCustomFieldValueFromWorkerRequest.md)
 - [UpsertCustomFieldValueFromWorkerRequestData](docs/UpsertCustomFieldValueFromWorkerRequestData.md)
 - [UpsertCustomFieldValueFromWorkerRequestDataAnyOf](docs/UpsertCustomFieldValueFromWorkerRequestDataAnyOf.md)
 - [UpsertCustomFieldValueFromWorkerRequestDataAnyOf1](docs/UpsertCustomFieldValueFromWorkerRequestDataAnyOf1.md)
 - [UpsertCustomFieldValueFromWorkerRequestDataAnyOf2](docs/UpsertCustomFieldValueFromWorkerRequestDataAnyOf2.md)
 - [UpsertCustomFieldValueFromWorkerRequestDataAnyOf3](docs/UpsertCustomFieldValueFromWorkerRequestDataAnyOf3.md)
 - [UpsertCustomFieldValueFromWorkerRequestDataAnyOf4](docs/UpsertCustomFieldValueFromWorkerRequestDataAnyOf4.md)
 - [UpsertCustomFieldValueFromWorkerRequestDataAnyOf5](docs/UpsertCustomFieldValueFromWorkerRequestDataAnyOf5.md)
 - [UpsertCustomFieldValueFromWorkerRequestDataAnyOf6](docs/UpsertCustomFieldValueFromWorkerRequestDataAnyOf6.md)
 - [UpsertParentWorkerRelationsContainer](docs/UpsertParentWorkerRelationsContainer.md)
 - [UpsertParentWorkerRelationsContainerData](docs/UpsertParentWorkerRelationsContainerData.md)
 - [UpsertParentWorkerRelationsExternalIdContainer](docs/UpsertParentWorkerRelationsExternalIdContainer.md)
 - [UpsertParentWorkerRelationsExternalIdContainerData](docs/UpsertParentWorkerRelationsExternalIdContainerData.md)
 - [UpsertParentWorkerRelationsRequest](docs/UpsertParentWorkerRelationsRequest.md)
 - [UpsertParentWorkerRelationsRequestData](docs/UpsertParentWorkerRelationsRequestData.md)
 - [UserPersonalInformationToUpdateContainer](docs/UserPersonalInformationToUpdateContainer.md)
 - [UserPersonalInformationToUpdateContainerData](docs/UserPersonalInformationToUpdateContainerData.md)
 - [ValidationType](docs/ValidationType.md)
 - [ValidationTypeEnum](docs/ValidationTypeEnum.md)
 - [ValidationTypeValue](docs/ValidationTypeValue.md)
 - [WebhookEventTypeListResponse](docs/WebhookEventTypeListResponse.md)
 - [WebhookEventTypeResponse](docs/WebhookEventTypeResponse.md)
 - [WebhookItem](docs/WebhookItem.md)
 - [WebhookItemResponse](docs/WebhookItemResponse.md)
 - [WebhookListResponse](docs/WebhookListResponse.md)
 - [WeekDaysEnum](docs/WeekDaysEnum.md)
 - [WorkStatementCycleEndTypeEnum](docs/WorkStatementCycleEndTypeEnum.md)
 - [WorkStatementCycleScaleEnum](docs/WorkStatementCycleScaleEnum.md)
 - [WorkStatementPaymentDueTypeEnum](docs/WorkStatementPaymentDueTypeEnum.md)
 - [WorkStatementScaleEnum](docs/WorkStatementScaleEnum.md)
 - [WorkStatementScaleEnumOptional](docs/WorkStatementScaleEnumOptional.md)
 - [WorkerBankAccountInfo](docs/WorkerBankAccountInfo.md)
 - [WorkerBankAccountToAdd](docs/WorkerBankAccountToAdd.md)
 - [WorkerBankAccountsInfoContainer](docs/WorkerBankAccountsInfoContainer.md)
 - [WorkerDocument](docs/WorkerDocument.md)
 - [WorkerDocumentDownloadLink](docs/WorkerDocumentDownloadLink.md)
 - [WorkerDocumentsByIdContainer](docs/WorkerDocumentsByIdContainer.md)
 - [WorkerLegalEntity](docs/WorkerLegalEntity.md)
 - [WorkerOfBasicContract](docs/WorkerOfBasicContract.md)
 - [WorkerOfContract](docs/WorkerOfContract.md)
 - [WorkerRelations](docs/WorkerRelations.md)
 - [WorkerRelationsDataInner](docs/WorkerRelationsDataInner.md)
 - [WorkerRelationsDataInnerChildRelationshipsInner](docs/WorkerRelationsDataInnerChildRelationshipsInner.md)
 - [WorkerRelationsDataInnerParentRelationship](docs/WorkerRelationsDataInnerParentRelationship.md)
 - [WorkerTermination](docs/WorkerTermination.md)
 - [WorkerTerminationBody](docs/WorkerTerminationBody.md)
 - [WorkerTerminationBodyContainer](docs/WorkerTerminationBodyContainer.md)
 - [WorkerTerminationBodySeverance](docs/WorkerTerminationBodySeverance.md)
 - [WorkerTerminationBodySeveranceOneOf](docs/WorkerTerminationBodySeveranceOneOf.md)
 - [WorkerTerminationBodySeveranceOneOf1](docs/WorkerTerminationBodySeveranceOneOf1.md)
 - [WorkerTerminationContainer](docs/WorkerTerminationContainer.md)
 - [WorkingLocationsContainer](docs/WorkingLocationsContainer.md)
 - [WorkingLocationsInner](docs/WorkingLocationsInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="deelToken"></a>
### deelToken

- **Type**: Bearer authentication (JWT)

<a id="oauth2"></a>
### oauth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://auth.deel.com/authorize
- **Scopes**: 
 - **accounting:read**: View payments and invoices in your organization.
 - **accounting:write**: Create and edit payments and invoices.
 - **candidates:read**: View candidates in your organization.
 - **candidates:write**: Create, edit and delete candidates in your organization.
 - **contracts:read**: View contracts in your organization.
 - **contracts:write**: Create and amend contracts.
 - **people:write**: Write worker’s information such as profile, time-off and expense.
 - **people:read**: Read worker’s information such as profile, time-off and expenses.
 - **profile:read**: Read Profile information such as name, email, phone
 - **Users:read**: View information about people in Deel HR.
 - **webhooks:read**: View webhooks in your organization.
 - **webhooks:write**: Create and edit webhooks in your organization.
 - **global-payroll:read**: View global payroll information about your employees.
 - **global-payroll:write**: Write global payroll information about your employees.
 - **adjustments:write**: Create / update adjustments of your employee.
 - **adjustments:read**: View adjustments of your employee.
 - **invoice-adjustments:read**: View invoices of your workforce.
 - **invoice-adjustments:write**: Create, edit, review, and delete invoice adjustments.
 - **milestones:read**: View milestones of your contractors.
 - **milestones:write**: Create, edit, review, and delete milestones.
 - **organizations:read**: View basic information about your organizations, teams, legal entities and agreements.
 - **organizations:write**: Modify information in your organization. Create, edit, delete admin users or managers.
 - **off-cycle-payments:read**: View your off-cycle payments.
 - **off-cycle-payments:write**: Create, edit, review your off-cycle payments.
 - **timesheets:read**: View work submitted for time-based contracts.
 - **timesheets:write**: Create, edit, review, and delete timesheets.
 - **tasks:read**: View your pay-as-you-go tasks.
 - **tasks:write**: Create, edit, review and delete your pay-as-you-go tasks.
 - **payslips:read**: View employee payslips.
 - **payslips:write**: Create, edit, review and delete employee payslips.
 - **public-token:write**: Create, edit, review and delete public tokens.
 - **profile:write**: Write Profile information such as name, email, phone

<a id="public"></a>
### public

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: 
- **Scopes**: 
 - **contracts:read**: View contracts in your organization.


## Author

apiteam@deel.com


